@@ -12,16 +12,20 @@ made to reuse, not duplicate, as many functions as possible */
 #include "ccx_decoders_708.h"
 #include "ccx_decoders_xds.h"
 #include "ccx_decoders_vbi.h"
+#include "ccx_encoders_mcc.h"
 #include "ccx_dtvcc.h"
 
+#ifndef DISABLE_RUST
+extern int ccxr_process_cc_data(struct lib_cc_decode *dec_ctx, unsigned char *cc_data, int cc_count);
+extern void ccxr_flush_decoder(struct dtvcc_ctx *dtvcc, struct dtvcc_service_decoder *decoder);
+#endif
 
-uint64_t utc_refvalue = UINT64_MAX;  /* _UI64_MAX means don't use UNIX, 0 = use current system time as reference, +1 use a specific reference */
+uint64_t utc_refvalue = UINT64_MAX; /* _UI64_MAX/UINT64_MAX means don't use UNIX, 0 = use current system time as reference, +1 use a specific reference */
 extern int in_xds_mode;
 
-
 /* This function returns a FTS that is guaranteed to be at least 1 ms later than the end of the previous screen. It shouldn't be needed
    obviously but it guarantees there's no timing overlap */
-LLONG get_visible_start (struct ccx_common_timing_ctx *ctx, int current_field)
+LLONG get_visible_start(struct ccx_common_timing_ctx *ctx, int current_field)
 {
 	LLONG fts = get_fts(ctx, current_field);
 	if (fts <= ctx->minimum_fts)
@@ -31,7 +35,7 @@ LLONG get_visible_start (struct ccx_common_timing_ctx *ctx, int current_field)
 }
 
 /* This function returns the current FTS and saves it so it can be used by ctxget_visible_start */
-LLONG get_visible_end (struct ccx_common_timing_ctx *ctx, int current_field)
+LLONG get_visible_end(struct ccx_common_timing_ctx *ctx, int current_field)
 {
 	LLONG fts = get_fts(ctx, current_field);
 	if (fts > ctx->minimum_fts)
@@ -40,28 +44,39 @@ LLONG get_visible_end (struct ccx_common_timing_ctx *ctx, int current_field)
 	return fts;
 }
 
-int process_cc_data (struct lib_cc_decode *ctx, unsigned char *cc_data, int cc_count, struct cc_subtitle *sub)
+int process_cc_data(struct encoder_ctx *enc_ctx, struct lib_cc_decode *dec_ctx, unsigned char *cc_data, int cc_count, struct cc_subtitle *sub)
 {
 	int ret = -1;
+
+	if (dec_ctx->write_format == CCX_OF_MCC)
+	{
+		mcc_encode_cc_data(enc_ctx, dec_ctx, cc_data, cc_count);
+		return 0;
+	}
+
+#ifndef DISABLE_RUST
+	ret = ccxr_process_cc_data(dec_ctx, cc_data, cc_count);
+#endif
+
 	for (int j = 0; j < cc_count * 3; j = j + 3)
 	{
-		if (validate_cc_data_pair( cc_data + j ) )
+		if (validate_cc_data_pair(cc_data + j))
 			continue;
-		ret = do_cb(ctx, cc_data + j, sub);
+		ret = do_cb(dec_ctx, cc_data + j, sub);
 		if (ret == 1) //1 means success here
 			ret = 0;
 	}
 	return ret;
 }
-int validate_cc_data_pair (unsigned char *cc_data_pair)
+int validate_cc_data_pair(unsigned char *cc_data_pair)
 {
-	unsigned char cc_valid = (*cc_data_pair & 4) >>2;
+	unsigned char cc_valid = (*cc_data_pair & 4) >> 2;
 	unsigned char cc_type = *cc_data_pair & 3;
 
 	if (!cc_valid)
 		return -1;
 
-	if (cc_type==0 || cc_type==1)
+	if (cc_type == 0 || cc_type == 1)
 	{
 		// For EIA-608 data we verify parity.
 		if (!cc608_parity_table[cc_data_pair[2]])
@@ -73,38 +88,35 @@ int validate_cc_data_pair (unsigned char *cc_data_pair)
 		{
 			// The first byte doesn't pass parity, we replace it with a solid blank
 			// and process the pair.
-			cc_data_pair[1]=0x7F;
+			cc_data_pair[1] = 0x7F;
 		}
 	}
 	return 0;
-
 }
-int do_cb (struct lib_cc_decode *ctx, unsigned char *cc_block, struct cc_subtitle *sub)
+int do_cb(struct lib_cc_decode *ctx, unsigned char *cc_block, struct cc_subtitle *sub)
 {
-	unsigned char cc_valid = (*cc_block & 4) >>2;
+	unsigned char cc_valid = (*cc_block & 4) >> 2;
 	unsigned char cc_type = *cc_block & 3;
 
 	int timeok = 1;
 
-	if ( ctx->fix_padding
-		&& cc_valid==0 && cc_type <= 1 // Only fix NTSC packets
-		&& cc_block[1]==0 && cc_block[2]==0 )
+	if (ctx->fix_padding && cc_valid == 0 && cc_type <= 1 // Only fix NTSC packets
+	    && cc_block[1] == 0 && cc_block[2] == 0)
 	{
 		/* Padding */
-		cc_valid=1;
-		cc_block[1]=0x80;
-		cc_block[2]=0x80;
+		cc_valid = 1;
+		cc_block[1] = 0x80;
+		cc_block[2] = 0x80;
 	}
 
-	if ( ctx->write_format!=CCX_OF_RAW && // In raw we cannot skip padding because timing depends on it
-		 ctx->write_format!=CCX_OF_DVDRAW &&
-		(cc_block[0]==0xFA || cc_block[0]==0xFC || cc_block[0]==0xFD )
-		&& (cc_block[1]&0x7F)==0 && (cc_block[2]&0x7F)==0) // CFS: Skip non-data, makes debugging harder.
+	if (ctx->write_format != CCX_OF_RAW && // In raw we cannot skip padding because timing depends on it
+	    ctx->write_format != CCX_OF_DVDRAW &&
+	    (cc_block[0] == 0xFA || cc_block[0] == 0xFC || cc_block[0] == 0xFD) && (cc_block[1] & 0x7F) == 0 && (cc_block[2] & 0x7F) == 0) // CFS: Skip non-data, makes debugging harder.
 		return 1;
 
 	// Print raw data with FTS.
-	dbg_print(CCX_DMT_CBRAW, "%s   %d   %02X:%c%c:%02X", print_mstime_static(ctx->timing->fts_now + ctx->timing->fts_global),in_xds_mode,
-			cc_block[0], cc_block[1]&0x7f,cc_block[2]&0x7f, cc_block[2]);
+	dbg_print(CCX_DMT_CBRAW, "%s   %d   %02X:%c%c:%02X", print_mstime_static(ctx->timing->fts_now + ctx->timing->fts_global), in_xds_mode,
+		  cc_block[0], cc_block[1] & 0x7f, cc_block[2] & 0x7f, cc_block[2]);
 
 	/* In theory the writercwtdata() function could return early and not
 	 * go through the 608/708 cases below.  We do that to get accurate
@@ -112,55 +124,55 @@ int do_cb (struct lib_cc_decode *ctx, unsigned char *cc_block, struct cc_subtitl
 	 * Note that printdata() and dtvcc_process_data() must not be called for
 	 * the CCX_OF_RCWT case. */
 
-	if (cc_valid || cc_type==3)
+	if (cc_valid || cc_type == 3)
 	{
 		ctx->cc_stats[cc_type]++;
 
 		switch (cc_type)
 		{
 			case 0:
-				dbg_print(CCX_DMT_CBRAW, "    %s   ..   ..\n",  debug_608_to_ASC( cc_block, 0));
+				dbg_print(CCX_DMT_CBRAW, "    %s   ..   ..\n", debug_608_to_ASC(cc_block, 0));
 
 				ctx->current_field = 1;
 				ctx->saw_caption_block = 1;
 
 				if (ctx->extraction_start.set &&
-						get_fts(ctx->timing, ctx->current_field) < ctx->extraction_start.time_in_ms)
+				    get_fts(ctx->timing, ctx->current_field) < ctx->extraction_start.time_in_ms)
 					timeok = 0;
 				if (ctx->extraction_end.set &&
-						get_fts(ctx->timing, ctx->current_field) > ctx->extraction_end.time_in_ms)
+				    get_fts(ctx->timing, ctx->current_field) > ctx->extraction_end.time_in_ms)
 				{
 					timeok = 0;
-					ctx->processed_enough=1;
+					ctx->processed_enough = 1;
 				}
 				if (timeok)
 				{
-					if(ctx->write_format!=CCX_OF_RCWT)
-						printdata (ctx, cc_block+1,2,0,0, sub);
+					if (ctx->write_format != CCX_OF_RCWT)
+						printdata(ctx, cc_block + 1, 2, 0, 0, sub);
 					else
 						writercwtdata(ctx, cc_block, sub);
 				}
 				cb_field1++;
 				break;
 			case 1:
-				dbg_print(CCX_DMT_CBRAW, "    ..   %s   ..\n",  debug_608_to_ASC( cc_block, 1));
+				dbg_print(CCX_DMT_CBRAW, "    ..   %s   ..\n", debug_608_to_ASC(cc_block, 1));
 
 				ctx->current_field = 2;
 				ctx->saw_caption_block = 1;
 
 				if (ctx->extraction_start.set &&
-						get_fts(ctx->timing, ctx->current_field) < ctx->extraction_start.time_in_ms)
+				    get_fts(ctx->timing, ctx->current_field) < ctx->extraction_start.time_in_ms)
 					timeok = 0;
 				if (ctx->extraction_end.set &&
-						get_fts(ctx->timing, ctx->current_field) > ctx->extraction_end.time_in_ms)
+				    get_fts(ctx->timing, ctx->current_field) > ctx->extraction_end.time_in_ms)
 				{
 					timeok = 0;
-					ctx->processed_enough=1;
+					ctx->processed_enough = 1;
 				}
 				if (timeok)
 				{
-					if(ctx->write_format!=CCX_OF_RCWT)
-						printdata (ctx, 0,0,cc_block+1,2, sub);
+					if (ctx->write_format != CCX_OF_RCWT)
+						printdata(ctx, 0, 0, cc_block + 1, 2, sub);
 					else
 						writercwtdata(ctx, cc_block, sub);
 				}
@@ -176,23 +188,27 @@ int do_cb (struct lib_cc_decode *ctx, unsigned char *cc_block, struct cc_subtitl
 				ctx->current_field = 3;
 
 				if (ctx->extraction_start.set &&
-						get_fts(ctx->timing, ctx->current_field) < ctx->extraction_start.time_in_ms)
+				    get_fts(ctx->timing, ctx->current_field) < ctx->extraction_start.time_in_ms)
 					timeok = 0;
 				if (ctx->extraction_end.set &&
-						get_fts(ctx->timing, ctx->current_field) > ctx->extraction_end.time_in_ms)
+				    get_fts(ctx->timing, ctx->current_field) > ctx->extraction_end.time_in_ms)
 				{
 					timeok = 0;
-					ctx->processed_enough=1;
+					ctx->processed_enough = 1;
 				}
-				char temp[4];
-				temp[0]=cc_valid;
-				temp[1]=cc_type;
-				temp[2]=cc_block[1];
-				temp[3]=cc_block[2];
 				if (timeok)
 				{
 					if (ctx->write_format != CCX_OF_RCWT)
-						ccx_dtvcc_process_data(ctx, (const unsigned char *) temp, 4);
+					{
+#ifdef DISABLE_RUST
+						char temp[4];
+						temp[0] = cc_valid;
+						temp[1] = cc_type;
+						temp[2] = cc_block[1];
+						temp[3] = cc_block[2];
+						dtvcc_process_data(ctx->dtvcc, (const unsigned char *)temp);
+#endif
+					}
 					else
 						writercwtdata(ctx, cc_block, sub);
 				}
@@ -203,7 +219,7 @@ int do_cb (struct lib_cc_decode *ctx, unsigned char *cc_block, struct cc_subtitl
 			default:
 				fatal(CCX_COMMON_EXIT_BUG_BUG, "In do_cb: Impossible value for cc_type, Please file a bug report on GitHub.\n");
 		} // switch (cc_type)
-	} // cc_valid
+	}	  // cc_valid
 	else
 	{
 		dbg_print(CCX_DMT_CBRAW, "    ..   ..   ..\n");
@@ -216,7 +232,7 @@ int do_cb (struct lib_cc_decode *ctx, unsigned char *cc_block, struct cc_subtitl
 void dinit_cc_decode(struct lib_cc_decode **ctx)
 {
 	struct lib_cc_decode *lctx = *ctx;
-	ccx_dtvcc_free(&lctx->dtvcc);
+	dtvcc_free(&lctx->dtvcc);
 	dinit_avc(&lctx->avc_ctx);
 	ccx_decoder_608_dinit_library(&lctx->context_cc608_field_1);
 	ccx_decoder_608_dinit_library(&lctx->context_cc608_field_2);
@@ -226,12 +242,12 @@ void dinit_cc_decode(struct lib_cc_decode **ctx)
 	freep(ctx);
 }
 
-struct lib_cc_decode* init_cc_decode (struct ccx_decoders_common_settings_t *setting)
+struct lib_cc_decode *init_cc_decode(struct ccx_decoders_common_settings_t *setting)
 {
 	struct lib_cc_decode *ctx = NULL;
 
 	ctx = malloc(sizeof(struct lib_cc_decode));
-	if(!ctx)
+	if (!ctx)
 		return NULL;
 
 	ctx->avc_ctx = init_avc();
@@ -245,30 +261,28 @@ struct lib_cc_decode* init_cc_decode (struct ccx_decoders_common_settings_t *set
 	ctx->no_rollup = setting->no_rollup;
 	ctx->noscte20 = setting->noscte20;
 
-	ctx->dtvcc = ccx_dtvcc_init(setting->settings_dtvcc);
+	ctx->dtvcc = dtvcc_init(setting->settings_dtvcc);
 	ctx->dtvcc->is_active = setting->settings_dtvcc->enabled;
 
-	if(setting->codec == CCX_CODEC_ATSC_CC)
+	if (setting->codec == CCX_CODEC_ATSC_CC)
 	{
 		// Prepare 608 context
 		ctx->context_cc608_field_1 = ccx_decoder_608_init_library(
-				setting->settings_608,
-				setting->cc_channel,
-				1,
-				&ctx->processed_enough,
-				setting->cc_to_stdout,
-				setting->output_format,
-				ctx->timing
-				);
+		    setting->settings_608,
+		    setting->cc_channel,
+		    1,
+		    &ctx->processed_enough,
+		    setting->cc_to_stdout,
+		    setting->output_format,
+		    ctx->timing);
 		ctx->context_cc608_field_2 = ccx_decoder_608_init_library(
-				setting->settings_608,
-				setting->cc_channel,
-				2,
-				&ctx->processed_enough,
-				setting->cc_to_stdout,
-				setting->output_format,
-				ctx->timing
-				);
+		    setting->settings_608,
+		    setting->cc_channel,
+		    2,
+		    &ctx->processed_enough,
+		    setting->cc_to_stdout,
+		    setting->output_format,
+		    ctx->timing);
 	}
 	else
 	{
@@ -278,8 +292,8 @@ struct lib_cc_decode* init_cc_decode (struct ccx_decoders_common_settings_t *set
 	ctx->current_field = 1;
 	ctx->private_data = setting->private_data;
 	ctx->fix_padding = setting->fix_padding;
-	ctx->write_format =  setting->output_format;
-	ctx->subs_delay =  setting->subs_delay;
+	ctx->write_format = setting->output_format;
+	ctx->subs_delay = setting->subs_delay;
 	ctx->extract = setting->extract;
 	ctx->fullbin = setting->fullbin;
 	ctx->hauppauge_mode = setting->hauppauge_mode;
@@ -289,44 +303,58 @@ struct lib_cc_decode* init_cc_decode (struct ccx_decoders_common_settings_t *set
 	ctx->max_gop_length = 0;
 	ctx->has_ccdata_buffered = 0;
 	ctx->in_bufferdatatype = CCX_UNKNOWN;
-	ctx->frames_since_last_gop  = 0;
-	ctx->total_pulldownfields   = 0;
-	ctx->total_pulldownframes   = 0;
-	ctx->stat_numuserheaders    = 0;
-	ctx->stat_dvdccheaders      = 0;
-	ctx->stat_scte20ccheaders   = 0;
+	ctx->frames_since_last_gop = 0;
+	ctx->total_pulldownfields = 0;
+	ctx->total_pulldownframes = 0;
+	ctx->stat_numuserheaders = 0;
+	ctx->stat_dvdccheaders = 0;
+	ctx->stat_scte20ccheaders = 0;
 	ctx->stat_replay5000headers = 0;
 	ctx->stat_replay4000headers = 0;
-	ctx->stat_dishheaders       = 0;
-	ctx->stat_hdtv              = 0;
-	ctx->stat_divicom           = 0;
+	ctx->stat_dishheaders = 0;
+	ctx->stat_hdtv = 0;
+	ctx->stat_divicom = 0;
 	ctx->false_pict_header = 0;
+	ctx->is_alloc = 0;
 
-	memcpy(&ctx->extraction_start, &setting->extraction_start,sizeof(struct ccx_boundary_time));
-	memcpy(&ctx->extraction_end, &setting->extraction_end,sizeof(struct ccx_boundary_time));
+	memcpy(&ctx->extraction_start, &setting->extraction_start, sizeof(struct ccx_boundary_time));
+	memcpy(&ctx->extraction_end, &setting->extraction_end, sizeof(struct ccx_boundary_time));
 
 	if (setting->send_to_srv)
 		ctx->writedata = net_send_cc;
-	else if (setting->output_format==CCX_OF_RAW ||
-		setting->output_format==CCX_OF_DVDRAW ||
-		setting->output_format==CCX_OF_RCWT )
-		ctx->writedata = writeraw;
-	else if (setting->output_format==CCX_OF_SMPTETT ||
-		setting->output_format==CCX_OF_SAMI ||
-		setting->output_format==CCX_OF_SRT ||
-		setting->output_format==CCX_OF_SSA ||
-		setting->output_format == CCX_OF_WEBVTT ||
-		setting->output_format==CCX_OF_TRANSCRIPT ||
-		setting->output_format==CCX_OF_SPUPNG ||
-		setting->output_format==CCX_OF_SIMPLE_XML ||
-		setting->output_format==CCX_OF_G608 ||
-		setting->output_format==CCX_OF_NULL ||
-		setting->output_format==CCX_OF_CURL)
-		ctx->writedata = process608;
 	else
-		fatal(CCX_COMMON_EXIT_BUG_BUG, "Invalid Write Format Selected");
+	{
+		// TODO: Add function to test this
+		switch (setting->output_format)
+		{
+			case CCX_OF_RAW:
+			case CCX_OF_DVDRAW:
+			case CCX_OF_RCWT:
+				ctx->writedata = writeraw;
+				break;
+			case CCX_OF_CCD:
+			case CCX_OF_SCC:
+			case CCX_OF_SMPTETT:
+			case CCX_OF_SAMI:
+			case CCX_OF_SRT:
+			case CCX_OF_SSA:
+			case CCX_OF_WEBVTT:
+			case CCX_OF_TRANSCRIPT:
+			case CCX_OF_SPUPNG:
+			case CCX_OF_SIMPLE_XML:
+			case CCX_OF_G608:
+			case CCX_OF_NULL:
+			case CCX_OF_MCC:
+			case CCX_OF_CURL:
+				ctx->writedata = process608;
+				break;
+			default:
+				fatal(CCX_COMMON_EXIT_BUG_BUG, "Invalid Write Format Selected");
+				break;
+		}
+	}
 
-	memset (&ctx->dec_sub, 0,sizeof(ctx->dec_sub));
+	memset(&ctx->dec_sub, 0, sizeof(ctx->dec_sub));
 
 	// Initialize HDTV caption buffer
 	init_hdcc(ctx);
@@ -336,7 +364,7 @@ struct lib_cc_decode* init_cc_decode (struct ccx_decoders_common_settings_t *set
 	ctx->current_aspect_ratio = 0;
 	ctx->current_frame_rate = 4; // Assume standard fps, 29.97
 
-        //Variables used while parsing elementary stream
+	// Variables used while parsing elementary stream
 	ctx->no_bitstream_error = 0;
 	ctx->saw_seqgoppic = 0;
 	ctx->in_pic_data = 0;
@@ -353,13 +381,13 @@ struct lib_cc_decode* init_cc_decode (struct ccx_decoders_common_settings_t *set
 	ctx->repeat_first_field = 0;
 	ctx->progressive_frame = 0;
 	ctx->pulldownfields = 0;
-        //es parser related variable ends here
+	// es parser related variable ends here
 
 	memset(ctx->cc_stats, 0, 4 * sizeof(int));
 
 	ctx->anchor_seq_number = -1;
 	// Init XDS buffers
-	if(setting->output_format!=CCX_OF_TRANSCRIPT)
+	if (setting->output_format != CCX_OF_TRANSCRIPT)
 	{
 		setting->xds_write_to_file = 0;
 	}
@@ -372,29 +400,42 @@ struct lib_cc_decode* init_cc_decode (struct ccx_decoders_common_settings_t *set
 
 void flush_cc_decode(struct lib_cc_decode *ctx, struct cc_subtitle *sub)
 {
-	if(ctx->codec == CCX_CODEC_ATSC_CC)
+	if (ctx->codec == CCX_CODEC_ATSC_CC)
 	{
 		if (ctx->extract != 2)
 		{
-			if (ctx->write_format==CCX_OF_SMPTETT || ctx->write_format==CCX_OF_SAMI ||
-					ctx->write_format==CCX_OF_SRT || ctx->write_format==CCX_OF_TRANSCRIPT ||
-					ctx->write_format == CCX_OF_WEBVTT || ctx->write_format == CCX_OF_SPUPNG ||
-					ctx->write_format == CCX_OF_SSA)
+			if (ctx->write_format == CCX_OF_CCD ||
+			    ctx->write_format == CCX_OF_SCC ||
+			    ctx->write_format == CCX_OF_SMPTETT ||
+			    ctx->write_format == CCX_OF_SAMI ||
+			    ctx->write_format == CCX_OF_SRT ||
+			    ctx->write_format == CCX_OF_TRANSCRIPT ||
+			    ctx->write_format == CCX_OF_WEBVTT ||
+			    ctx->write_format == CCX_OF_SPUPNG ||
+			    ctx->write_format == CCX_OF_SSA ||
+			    ctx->write_format == CCX_OF_MCC)
 			{
 				flush_608_context(ctx->context_cc608_field_1, sub);
 			}
-			else if(ctx->write_format == CCX_OF_RCWT)
+			else if (ctx->write_format == CCX_OF_RCWT)
 			{
 				// Write last header and data
-				writercwtdata (ctx, NULL, sub);
+				writercwtdata(ctx, NULL, sub);
 			}
 		}
 		if (ctx->extract != 1)
 		{
-			if (ctx->write_format == CCX_OF_SMPTETT || ctx->write_format == CCX_OF_SAMI ||
-					ctx->write_format == CCX_OF_SRT || ctx->write_format == CCX_OF_TRANSCRIPT ||
-					ctx->write_format == CCX_OF_WEBVTT || ctx->write_format == CCX_OF_SPUPNG ||
-					ctx->write_format == CCX_OF_SSA)
+			// TODO: Use a function to prevent repeating these lines
+			if (ctx->write_format == CCX_OF_CCD ||
+			    ctx->write_format == CCX_OF_SCC ||
+			    ctx->write_format == CCX_OF_SMPTETT ||
+			    ctx->write_format == CCX_OF_SAMI ||
+			    ctx->write_format == CCX_OF_SRT ||
+			    ctx->write_format == CCX_OF_TRANSCRIPT ||
+			    ctx->write_format == CCX_OF_WEBVTT ||
+			    ctx->write_format == CCX_OF_SPUPNG ||
+			    ctx->write_format == CCX_OF_SSA ||
+			    ctx->write_format == CCX_OF_MCC)
 			{
 				flush_608_context(ctx->context_cc608_field_2, sub);
 			}
@@ -404,18 +445,22 @@ void flush_cc_decode(struct lib_cc_decode *ctx, struct cc_subtitle *sub)
 	{
 		for (int i = 0; i < CCX_DTVCC_MAX_SERVICES; i++)
 		{
-			ccx_dtvcc_service_decoder *decoder = &ctx->dtvcc->decoders[i];
+			dtvcc_service_decoder *decoder = &ctx->dtvcc->decoders[i];
 			if (!ctx->dtvcc->services_active[i])
 				continue;
 			if (decoder->cc_count > 0)
 			{
 				ctx->current_field = 3;
-				ccx_dtvcc_decoder_flush(ctx->dtvcc, decoder);
+#ifndef DISABLE_RUST
+				ccxr_flush_decoder(ctx->dtvcc, decoder);
+#else
+				dtvcc_decoder_flush(ctx->dtvcc, decoder);
+#endif
 			}
 		}
 	}
 }
-struct encoder_ctx* copy_encoder_context(struct encoder_ctx *ctx)
+struct encoder_ctx *copy_encoder_context(struct encoder_ctx *ctx)
 {
 	struct encoder_ctx *ctx_copy = NULL;
 	ctx_copy = malloc(sizeof(struct encoder_ctx));
@@ -463,7 +508,7 @@ struct encoder_ctx* copy_encoder_context(struct encoder_ctx *ctx)
 	}
 	return ctx_copy;
 }
-struct lib_cc_decode* copy_decoder_context(struct lib_cc_decode *ctx)
+struct lib_cc_decode *copy_decoder_context(struct lib_cc_decode *ctx)
 {
 	struct lib_cc_decode *ctx_copy = NULL;
 	ctx_copy = malloc(sizeof(struct lib_cc_decode));
@@ -492,8 +537,8 @@ struct lib_cc_decode* copy_decoder_context(struct lib_cc_decode *ctx)
 	ctx_copy->private_data = NULL;
 	if (ctx->dtvcc)
 	{
-		ctx_copy->dtvcc = malloc(sizeof(struct ccx_dtvcc_ctx));
-		memcpy(ctx_copy->dtvcc, ctx->dtvcc, sizeof(struct ccx_dtvcc_ctx));
+		ctx_copy->dtvcc = malloc(sizeof(struct dtvcc_ctx));
+		memcpy(ctx_copy->dtvcc, ctx->dtvcc, sizeof(struct dtvcc_ctx));
 	}
 	if (ctx->xds_ctx)
 	{
@@ -507,7 +552,7 @@ struct lib_cc_decode* copy_decoder_context(struct lib_cc_decode *ctx)
 	}
 	return ctx_copy;
 }
-struct cc_subtitle* copy_subtitle(struct cc_subtitle *sub)
+struct cc_subtitle *copy_subtitle(struct cc_subtitle *sub)
 {
 	struct cc_subtitle *sub_copy = NULL;
 	sub_copy = malloc(sizeof(struct cc_subtitle));
@@ -535,7 +580,7 @@ void free_encoder_context(struct encoder_ctx *ctx)
 	freep(&ctx->start_credits_text);
 	freep(&ctx->end_credits_text);
 	freep(&ctx->prev);
-    freep(&ctx->last_string);
+	freep(&ctx->last_string);
 	freep(&ctx);
 }
 void free_decoder_context(struct lib_cc_decode *ctx)
@@ -553,14 +598,14 @@ void free_decoder_context(struct lib_cc_decode *ctx)
 	freep(&ctx->vbi_decoder);
 	freep(&ctx);
 }
-void free_subtitle(struct cc_subtitle* sub)
+void free_subtitle(struct cc_subtitle *sub)
 {
 	if (!sub)
 		return;
 
 	if (sub->datatype == CC_DATATYPE_DVB)
 	{
-		struct cc_bitmap *bitmap=(struct cc_bitmap *) sub->data;
+		struct cc_bitmap *bitmap = (struct cc_bitmap *)sub->data;
 		if (bitmap)
 		{
 			freep(&bitmap->data0);
