@@ -2,7 +2,7 @@
 #define _CC_ENCODER_COMMON_H
 
 #ifdef WIN32
-	#include "..\\win_iconv\\iconv.h"
+	#include "..\\thirdparty\\win_iconv\\iconv.h"
 #else
 	#include "iconv.h"
 #endif
@@ -21,12 +21,18 @@ if (ctx->buffer == NULL) { fatal(EXIT_NOT_ENOUGH_MEMORY, "Not enough memory for
 #define ROWS                    15
 #define COLUMNS                 32
 
-typedef struct ccx_dtvcc_writer_ctx
+typedef struct dtvcc_writer_ctx
 {
 	int fd;
+#ifndef DISABLE_RUST
+	// File handle used to work with files on windows
+	void *fhandle;
+	// Charset of the subtitle
+	char *charset;
+#endif
 	char *filename;
 	iconv_t cd;
-} ccx_dtvcc_writer_ctx;
+} dtvcc_writer_ctx;
 
 typedef struct ccx_sbs_utf8_character
 {
@@ -36,6 +42,15 @@ typedef struct ccx_sbs_utf8_character
 	int enc_len;
 } ccx_sbs_utf8_character;
 
+struct ccx_mcc_caption_time
+{
+    unsigned int hour;
+    unsigned int minute;
+    unsigned int second;
+    unsigned int millisecond;
+    unsigned int frame;
+};
+
 /**
  * Context of encoder, This structure gives single interface
  * to all encoder
@@ -53,6 +68,7 @@ struct encoder_ctx
 
 	/* Did we write the WebVTT header already? */
 	unsigned int wrote_webvtt_header;
+	char wrote_ccd_channel_header;
 
 	/* Input outputs */
 	/* Flag giving hint that output is send to server through network */
@@ -73,6 +89,8 @@ struct encoder_ctx
 	int force_flush;
 	/* Keep track of whether -UCLA used */
 	int ucla;
+	/* Disable timestamps for WebVTT */
+	int no_timestamp_map;
 
 	struct ccx_common_timing_ctx *timing; /* Some encoders need access to PTS, such as WebVTT */
 
@@ -82,7 +100,8 @@ struct encoder_ctx
 	int generates_file;
 	struct ccx_encoders_transcript_format *transcript_settings; // Keeps the settings for generating transcript output files.
 	int no_bom;
-	int sentence_cap ;                                          // FIX CASE? = Fix case?
+	int sentence_cap;                                           // FIX CASE? = Fix case?
+	int filter_profanity;
 
 	int trim_subs;                                              // "    Remove spaces at sides?    "
 	int autodash;                                               // Add dashes (-) before each speaker automatically?
@@ -93,7 +112,7 @@ struct encoder_ctx
 	int extract;
 
 	int dtvcc_extract;                                          // 1 or 0 depending if we have to handle dtvcc
-	ccx_dtvcc_writer_ctx dtvcc_writers[CCX_DTVCC_MAX_SERVICES];
+	dtvcc_writer_ctx dtvcc_writers[CCX_DTVCC_MAX_SERVICES];
 
 	/* Timing related variables*/
 	/* start time of previous sub */
@@ -117,6 +136,12 @@ struct encoder_ctx
 	unsigned char encoded_br[16];
 	unsigned int encoded_br_length;
 
+	// MCC File
+	int header_printed_flag;
+    struct ccx_mcc_caption_time next_caption_time;
+    unsigned int cdp_hdr_seq;
+    int force_dropframe;
+
 	int new_sentence; // Capitalize next letter?
 
 	int program_number;
@@ -172,6 +197,8 @@ void dinit_encoder(struct encoder_ctx **arg, LLONG current_fts);
  */
 int encode_sub(struct encoder_ctx *ctx,struct cc_subtitle *sub);
 
+int write_cc_buffer_as_ccd            (const struct eia608_screen *data, struct encoder_ctx *context);
+int write_cc_buffer_as_scc            (const struct eia608_screen *data, struct encoder_ctx *context);
 int write_cc_buffer_as_srt            (struct eia608_screen *data, struct encoder_ctx *context);
 int write_cc_buffer_as_ssa            (struct eia608_screen *data, struct encoder_ctx *context);
 int write_cc_buffer_as_webvtt         (struct eia608_screen *data, struct encoder_ctx *context);
@@ -222,7 +249,7 @@ void set_encoder_rcwt_fileformat(struct encoder_ctx *ctx, short int format);
 
 int reset_output_ctx(struct encoder_ctx *ctx, struct encoder_cfg *cfg);
 
-void find_limit_characters(unsigned char *line, int *first_non_blank, int *last_non_blank, int max_len);
+void find_limit_characters(const unsigned char *line, int *first_non_blank, int *last_non_blank, int max_len);
 int get_str_basic(unsigned char *out_buffer, unsigned char *in_buffer, int trim_subs,
 	enum ccx_encoding_type in_enc, enum ccx_encoding_type out_enc, int max_len);
 
@@ -230,7 +257,6 @@ int get_str_basic(unsigned char *out_buffer, unsigned char *in_buffer, int trim_
 unsigned int get_line_encoded(struct encoder_ctx *ctx, unsigned char *buffer, int line_num, struct eia608_screen *data);
 unsigned int get_color_encoded(struct encoder_ctx *ctx, unsigned char *buffer, int line_num, struct eia608_screen *data);
 unsigned int get_font_encoded(struct encoder_ctx *ctx, unsigned char *buffer, int line_num, struct eia608_screen *data);
-int pass_cc_buffer_to_python(struct eia608_screen *data, struct encoder_ctx *context);
 
 struct lib_ccx_ctx;
 void switch_output_file(struct lib_ccx_ctx *ctx, struct encoder_ctx *enc_ctx, int track_id);
