@@ -24,14 +24,13 @@
 #ifdef DEBUG_SBS
 #define LOG_DEBUG(...) fprintf(stdout, __VA_ARGS__)
 #else
-#define LOG_DEBUG ;
+#define LOG_DEBUG(...)
 #endif
 
 #ifdef ENABLE_SHARING
 #include "ccx_share.h"
 #endif //ENABLE_SHARING
 
-
 //---------------------------
 // BEGIN of #BUG639
 // HACK: this is workaround for https://github.com/CCExtractor/ccextractor/issues/639
@@ -39,10 +38,11 @@
 // as result SBS loses it internal state...
 
 // #BUG639
-typedef struct {
+typedef struct
+{
 
-	unsigned char * buffer; /// Storage for sentence-split buffer
-	size_t handled_len; /// The length of the string in the SBS-buffer, already handled, but preserved for DUP-detection.
+	unsigned char *buffer; /// Storage for sentence-split buffer
+	size_t handled_len;    /// The length of the string in the SBS-buffer, already handled, but preserved for DUP-detection.
 
 	//ccx_sbs_utf8_character *sbs_newblock;
 	LLONG time_from; // Used by the split-by-sentence code to know when the current block starts...
@@ -54,29 +54,32 @@ typedef struct {
 // DO NOT USE IT DIRECTLY!
 // The only one exceptions:
 // 1. init_sbs_context
-sbs_context_t * ____sbs_context = NULL;
+sbs_context_t *____sbs_context = NULL;
 
 /**
  * Initializes SBS settings for encoder context
  */
 
-void sbs_reset_context() {
-	if (NULL != ____sbs_context) {
+void sbs_reset_context()
+{
+	if (NULL != ____sbs_context)
+	{
 		free(____sbs_context);
 		____sbs_context = NULL;
 	}
 }
 
 //void init_encoder_sbs(struct encoder_ctx * ctx, const int splitbysentence);
-sbs_context_t * sbs_init_context() {
+sbs_context_t *sbs_init_context()
+{
 
 	LOG_DEBUG("SBS: init_sbs_context\n\
 ____sbs_context:   [%p]\n\
 ",
-		____sbs_context
-	);
+		  ____sbs_context);
 
-	if (NULL == ____sbs_context) {
+	if (NULL == ____sbs_context)
+	{
 
 		LOG_DEBUG("SBS: init_sbs_context: INIT\n");
 
@@ -92,8 +95,7 @@ ____sbs_context:   [%p]\n\
 	LOG_DEBUG("SBS: init_sbs_context: DONE\n\
 ____sbs_context:   [%p]\n\
 ",
-		____sbs_context
-	);
+		  ____sbs_context);
 
 	return ____sbs_context;
 }
@@ -101,13 +103,12 @@ ____sbs_context:   [%p]\n\
 // END of #BUG639
 //---------------------------
 
-void sbs_str_autofix(unsigned char * str)
+void sbs_str_autofix(unsigned char *str)
 {
 	LOG_DEBUG("SBS: sbs_str_autofix\n\
 \t old str:  [%s]\n\
 ",
-		str
-	);
+		  str);
 
 	int i;
 	int j;
@@ -119,27 +120,28 @@ void sbs_str_autofix(unsigned char * str)
 	while (str[i] != 0)
 	{
 
-		if (isspace(str[i])) {
+		if (isspace(str[i]))
+		{
 			// \n
 			// \t
 			// \r
 			// <WHITESPACES>
 			// =>
 			// <SPACE>
-			while (isspace(str[i])) {
+			while (isspace(str[i]))
+			{
 				i++;
 			}
 
-			if (j > 0) {
+			if (j > 0)
+			{
 				str[j] = ' ';
 				j++;
 			}
-
-		} else if (
-			str[i] == '|'
-			&& (i==0 || isspace(str[i-1]))
-			&& (str[i+1] == 0 || isspace(str[i+1]) || str[i+1]=='\'')
-		) {
+		}
+		else if (
+		    str[i] == '|' && (i == 0 || isspace(str[i - 1])) && (str[i + 1] == 0 || isspace(str[i + 1]) || str[i + 1] == '\''))
+		{
 			// <SPACE>|'
 			// <SPACE>|<SPACE>
 			// =>
@@ -147,7 +149,9 @@ void sbs_str_autofix(unsigned char * str)
 			str[j] = 'I';
 			i++;
 			j++;
-		} else {
+		}
+		else
+		{
 			str[j] = str[i];
 			i++;
 			j++;
@@ -159,30 +163,20 @@ void sbs_str_autofix(unsigned char * str)
 	LOG_DEBUG("SBS: sbs_str_autofix\n\
 \t old str:  [%s]\n\
 ",
-		str
-	);
+		  str);
 }
 
-int sbs_is_pointer_on_sentence_breaker(char * start, char * current)
+int sbs_is_pointer_on_sentence_breaker(char *start, char *current)
 {
 	char c = *current;
 	char n = *(current + 1);
-	char p = *(current - 1);
 
-	if (0 == c) n = 0;
-	if (current == start) p = 0;
+	if (0 == c)
+		return 1;
 
-	if (0 == c) return 1;
-
-	if ('.' == c
-		|| '!' == c
-		|| '?' == c
-	)
+	if ('.' == c || '!' == c || '?' == c)
 	{
-		if ('.' == n
-			|| '!' == n
-			|| '?' == n
-		)
+		if ('.' == n || '!' == n || '?' == n)
 		{
 			return 0;
 		}
@@ -193,15 +187,19 @@ int sbs_is_pointer_on_sentence_breaker(char * start, char * current)
 	return 0;
 }
 
-int sbs_char_equal_CI(const char A, const char B) {
+int sbs_char_equal_CI(const char A, const char B)
+{
 	char a = tolower(A);
 	char b = tolower(B);
-	if (a > b) return 1;
-	if (a < b) return -1;
+	if (a > b)
+		return 1;
+	if (a < b)
+		return -1;
 	return 0;
 }
 
-char * sbs_find_insert_point_partial(char * old_tail, const char * new_start, size_t n, const int maxerr, int *errcount) {
+char *sbs_find_insert_point_partial(char *old_tail, const char *new_start, size_t n, const int maxerr, int *errcount)
+{
 
 	const int PARTIAL_CHANGE_LENGTH_MIN = 7;
 	const int FEW_ERRORS_RATE = 10;
@@ -210,67 +208,72 @@ char * sbs_find_insert_point_partial(char * old_tail, const char * new_start, si
 	char fmtbuf[20000];
 #endif
 
-	int few_errors = maxerr/FEW_ERRORS_RATE;
+	int few_errors = maxerr / FEW_ERRORS_RATE;
 
-	size_t len_r = n/2;
+	size_t len_r = n / 2;
 	size_t len_l = n - len_r;
 
 	int dist_l = -1;
 	int dist_r = -1;
 	int partial_shift;
 
-	int i; // top level indexer for strings
-
 	dist_l = levenshtein_dist_char(old_tail, new_start, len_l, len_l);
 	dist_r = levenshtein_dist_char(old_tail + len_l, new_start + len_l, len_r, len_r);
 
 	*errcount = dist_r + dist_l;
 
-	if (dist_l + dist_r > maxerr) {
-// #ifdef DEBUG_SBS
-// 		sprintf(fmtbuf, "SBS: sbs_find_insert_point_partial: compare\n\
-// \tnot EQ:          [TRUE]\n\
-// \tmaxerr:          [%%d]\n\
-// \tL buffer:          [%%.%zus]\n\
-// \tL string:          [%%.%zus]\n\
-// \tL dist_l:          [%%d]\n\
-// \tR buffer:          [%%.%zus]\n\
-// \tR string:          [%%.%zus]\n\
-// \tR dist_r:          [%%d]\n\
-// ",
-// 			len_l,
-// 			len_l,
-// 			len_r,
-// 			len_r
-// 		);
-// 		LOG_DEBUG(fmtbuf,
-// 			maxerr,
-// 			old_tail,
-// 			new_start,
-// 			dist_l,
-// 			old_tail + len_l,
-// 			new_start + len_l,
-// 			dist_r
-// 		);
-// #endif
+	if (dist_l + dist_r > maxerr)
+	{
+		/*
+#ifdef DEBUG_SBS
+		sprintf(fmtbuf, "SBS: sbs_find_insert_point_partial: compare\n\
+\tnot EQ:          [TRUE]\n\
+\tmaxerr:          [%%d]\n\
+\tL buffer:          [%%.%zus]\n\
+\tL string:          [%%.%zus]\n\
+\tL dist_l:          [%%d]\n\
+\tR buffer:          [%%.%zus]\n\
+\tR string:          [%%.%zus]\n\
+\tR dist_r:          [%%d]\n\
+",
+			len_l,
+			len_l,
+			len_r,
+			len_r
+		);
+		LOG_DEBUG(fmtbuf,
+			maxerr,
+			old_tail,
+			new_start,
+			dist_l,
+			old_tail + len_l,
+			new_start + len_l,
+			dist_r
+		);
+#endif
+		*/
 		return NULL;
 	};
 
 	if (
-		dist_r <= few_errors               // right part almost the same
-		&& n > PARTIAL_CHANGE_LENGTH_MIN   // the sentence is long enough for analysis
-	) {
-// 		LOG_DEBUG("SBS: sbs_find_insert_point_partial: LEFT CHANGED,\n\tbuf:[%s]\n\tstr:[%s]\n\
-// \tmaxerr:[%d]\n\
-// \tdist_l:[%d]\n\
-// \tdist_r:[%d]\n\
-// ",
-// 			old_tail,
-// 			new_start,
-// 			maxerr,
-// 			dist_l,
-// 			dist_r
-// 		);
+	    dist_r <= few_errors	     // right part almost the same
+	    && n > PARTIAL_CHANGE_LENGTH_MIN // the sentence is long enough for analysis
+	)
+	{
+		/*
+		LOG_DEBUG("SBS: sbs_find_insert_point_partial: LEFT CHANGED,\n\tbuf:[%s]\n\tstr:[%s]\n\
+\tmaxerr:[%d]\n\
+\tdist_l:[%d]\n\
+\tdist_r:[%d]\n\
+",
+			old_tail,
+			new_start,
+			maxerr,
+			dist_l,
+			dist_r
+		);
+		*/
+
 		// searching for first mismatched symbol at the end of buf
 		// This is a naive implementation of error detection
 		//
@@ -278,10 +281,8 @@ char * sbs_find_insert_point_partial(char * old_tail, const char * new_start, si
 		// compare OLD value (from buffer) and new value (new STR)
 		partial_shift = 0;
 		while (
-			old_tail[partial_shift] != 0
-			&& old_tail[partial_shift+1] != 0
-			&& (0 != sbs_char_equal_CI(old_tail[partial_shift], new_start[partial_shift]))
-		) {
+		    old_tail[partial_shift] != 0 && old_tail[partial_shift + 1] != 0 && (0 != sbs_char_equal_CI(old_tail[partial_shift], new_start[partial_shift])))
+		{
 			partial_shift += 1;
 		}
 
@@ -292,50 +293,52 @@ char * sbs_find_insert_point_partial(char * old_tail, const char * new_start, si
 		return old_tail + partial_shift;
 	}
 
-// #ifdef DEBUG_SBS
-
-// 		sprintf(fmtbuf, "SBS: sbs_find_insert_point_partial: REPLACE ENTIRE TAIL !!\n\
-// \tmaxerr:          [%%d]\n\
-// \tL buffer:        [%%.%zus]\n\
-// \tL string:        [%%.%zus]\n\
-// \tL dist_l:        [%%d]\n\
-// \tR buffer:        [%%.%zus]\n\
-// \tR string:        [%%.%zus]\n\
-// \tR dist_r:        [%%d]\n\
-// ",
-// 			len_l,
-// 			len_l,
-// 			len_r,
-// 			len_r
-// 		);
-// 		LOG_DEBUG(fmtbuf,
-// 			maxerr,
-// 			old_tail,
-// 			new_start,
-// 			dist_l,
-// 			old_tail + len_l,
-// 			new_start + len_l,
-// 			dist_r
-// 		);
-// #endif
+	/*
+#ifdef DEBUG_SBS
+		sprintf(fmtbuf, "SBS: sbs_find_insert_point_partial: REPLACE ENTIRE TAIL !!\n\
+\tmaxerr:          [%%d]\n\
+\tL buffer:        [%%.%zus]\n\
+\tL string:        [%%.%zus]\n\
+\tL dist_l:        [%%d]\n\
+\tR buffer:        [%%.%zus]\n\
+\tR string:        [%%.%zus]\n\
+\tR dist_r:        [%%d]\n\
+",
+			len_l,
+			len_l,
+			len_r,
+			len_r
+		);
+		LOG_DEBUG(fmtbuf,
+			maxerr,
+			old_tail,
+			new_start,
+			dist_l,
+			old_tail + len_l,
+			new_start + len_l,
+			dist_r
+		);
+#endif
+	*/
 
 	return old_tail;
 }
 
-char * sbs_find_insert_point(char * buf, const char * str, int * ilen) {
+char *sbs_find_insert_point(char *buf, const char *str, int *ilen)
+{
 
 	int maxerr;
 	size_t buf_len;
-	unsigned char * buffer_tail;
-	const unsigned char * prefix = str;
+	unsigned char *buffer_tail;
+	const unsigned char *prefix = str;
 
-	int             cur_err = 0;
-	unsigned char * cur_ptr;
-	int             cur_len;
+	int cur_err = 0;
+	unsigned char *cur_ptr;
+	int cur_len;
 
-	int             best_err;
-	unsigned char * best_ptr;
-	int             best_len;
+	int best_err;
+	unsigned char *best_ptr;
+	int best_len;
 
 	buf_len = strlen(buf);
 	cur_len = strlen(str);
@@ -356,7 +359,8 @@ char * sbs_find_insert_point(char * buf, const char * str, int * ilen) {
 		cur_ptr = sbs_find_insert_point_partial(buffer_tail, prefix, cur_len, maxerr, &cur_err);
 		if (NULL != cur_ptr)
 		{
-			if ((cur_len-cur_err) >= (best_len-best_err)) {
+			if ((cur_len - cur_err) >= (best_len - best_err))
+			{
 				best_err = cur_err;
 				best_len = cur_len;
 				best_ptr = cur_ptr;
@@ -369,24 +373,22 @@ char * sbs_find_insert_point(char * buf, const char * str, int * ilen) {
 	return best_ptr;
 }
 
-void sbs_strcpy_without_dup(const unsigned char * str, sbs_context_t * context)
+void sbs_strcpy_without_dup(const unsigned char *str, sbs_context_t *context)
 {
 	int intersect_len;
-	unsigned char * buffer_insert_point;
+	unsigned char *buffer_insert_point;
 
 	unsigned long sbs_len;
 
 	sbs_len = strlen(context->buffer);
 
-
 	LOG_DEBUG("SBS: sbs_strcpy_without_dup: going to append, looking for common part\n\
 \tbuffer:          [%p][%s]\n\
 \tstring:          [%s]\n\
 ",
-		context->buffer,
-		context->buffer,
-		str
-	);
+		  context->buffer,
+		  context->buffer,
+		  str);
 
 	buffer_insert_point = sbs_find_insert_point(context->buffer, str, &intersect_len);
 
@@ -398,13 +400,12 @@ void sbs_strcpy_without_dup(const unsigned char * str, sbs_context_t * context)
 \t sbslen          [%4ld]\n\
 \t handled len     [%4zu]\n\
 ",
-		context->buffer,
-		str,
-		buffer_insert_point,
-		intersect_len,
-		sbs_len,
-		context->handled_len
-	);
+		  context->buffer,
+		  str,
+		  buffer_insert_point,
+		  intersect_len,
+		  sbs_len,
+		  context->handled_len);
 
 	if (intersect_len > 0)
 	{
@@ -421,7 +422,7 @@ void sbs_strcpy_without_dup(const unsigned char * str, sbs_context_t * context)
 
 	// check, that new string does not contain data, from
 	// already handled sentence:
-	if ( (sbs_len - intersect_len) >= context->handled_len)
+	if ((sbs_len - intersect_len) >= context->handled_len)
 	{
 		// there is no intersection.
 		// It is time to clean the buffer. Excepting the last uncomplete sentence
@@ -430,15 +431,15 @@ void sbs_strcpy_without_dup(const unsigned char * str, sbs_context_t * context)
 \t handled len     [%4zu]\n\
 \t new start at  ->[%s]\n\
 ",
-			context->buffer,
-			context->handled_len,
-			context->buffer + context->handled_len
-		);
+			  context->buffer,
+			  context->handled_len,
+			  context->buffer + context->handled_len);
 
 		// skip leading whitespaces:
 		int skip_ws = context->handled_len;
-		while (isspace(context->buffer[skip_ws])) {
-			skip_ws ++;
+		while (isspace(context->buffer[skip_ws]))
+		{
+			skip_ws++;
 		}
 
 		strcpy(context->buffer, context->buffer + skip_ws);
@@ -448,10 +449,10 @@ void sbs_strcpy_without_dup(const unsigned char * str, sbs_context_t * context)
 	sbs_len = strlen(context->buffer);
 
 	if (
-		!isspace(str[0])                // not a space char in the beginning of new str
-		//&& context->handled_len >0  // buffer is not empty (there is uncomplete sentence)
-		&& sbs_len > 0  // buffer is not empty (there is uncomplete sentence)
-		&& !isspace(context->buffer[sbs_len-1])  // not a space char at the end of existing buf
+	    !isspace(str[0]) // not a space char in the beginning of new str
+	    //&& context->handled_len >0  // buffer is not empty (there is uncomplete sentence)
+	    && sbs_len > 0			      // buffer is not empty (there is uncomplete sentence)
+	    && !isspace(context->buffer[sbs_len - 1]) // not a space char at the end of existing buf
 	)
 	{
 		strcat(context->buffer, " ");
@@ -469,14 +470,14 @@ void sbs_strcpy_without_dup(const unsigned char * str, sbs_context_t * context)
  * @param  context   Encoder context
  * @return           New <struct cc_subtitle *> subtitle, or NULL, if <str> doesn't contain the ending part of the sentence. If there are more than one sentence, the remaining sentences will be chained using <result->next> reference.
  */
-struct cc_subtitle * sbs_append_string(unsigned char * str, const LLONG time_from, const LLONG time_trim, sbs_context_t * context)
+struct cc_subtitle *sbs_append_string(unsigned char *str, const LLONG time_from, const LLONG time_trim, sbs_context_t *context)
 {
-	struct cc_subtitle * resub;
-	struct cc_subtitle * tmpsub;
+	struct cc_subtitle *resub;
+	struct cc_subtitle *tmpsub;
 
-	unsigned char * bp_current;
-	unsigned char * bp_last_break;
-	unsigned char * sbs_undone_start;
+	unsigned char *bp_current;
+	unsigned char *bp_last_break;
+	unsigned char *sbs_undone_start;
 
 	int required_capacity;
 	int new_capacity;
@@ -491,23 +492,21 @@ struct cc_subtitle * sbs_append_string(unsigned char * str, const LLONG time_fro
 	LLONG available_time;
 	int use_alphanum_counters;
 
-	if (! str)
+	if (!str)
 		return NULL;
 
 	LOG_DEBUG("SBS: sbs_append_string: after sbs init:\n\
 \tsbs ptr:   [%p]\n\
 ",
-		context
-	);
+		  context);
 
 	LOG_DEBUG("SBS: sbs_append_string: after sbs init:\n\
 \tsbs ptr:   [%p][%s]\n\
 \tcur cap:   [%zu]\n\
 ",
-		context->buffer,
-		context->buffer,
-		context->capacity
-	);
+		  context->buffer,
+		  context->buffer,
+		  context->capacity);
 
 	sbs_str_autofix(str);
 
@@ -515,11 +514,11 @@ struct cc_subtitle * sbs_append_string(unsigned char * str, const LLONG time_fro
 	// grow sentence buffer
 	// ===============================
 	required_capacity =
-		strlen(context->buffer)    // existing data in buf
-		+ strlen(str)     // length of new string
-		+ 1               // trailing \0
-		+ 1               // space control (will add one space , if required)
-	;
+	    strlen(context->buffer) // existing data in buf
+	    + strlen(str)	    // length of new string
+	    + 1			    // trailing \0
+	    + 1			    // space control (will add one space , if required)
+	    ;
 
 	if (required_capacity >= context->capacity)
 	{
@@ -528,10 +527,9 @@ struct cc_subtitle * sbs_append_string(unsigned char * str, const LLONG time_fro
 \tcur cap:   [%zu]\n\
 \treq cap:   [%d]\n\
 ",
-			context->buffer,
-			context->capacity,
-			required_capacity
-		);
+			  context->buffer,
+			  context->capacity,
+			  required_capacity);
 
 		new_capacity = context->capacity;
 
@@ -541,14 +539,13 @@ struct cc_subtitle * sbs_append_string(unsigned char * str, const LLONG time_fro
 			// is less than 8 Mb. Because 8Mb - it is a lot
 			// for a TEXT buffer. It is weird...
 			new_capacity += (new_capacity > 1048576 * 8)
-				? 1048576 * 8
-				: new_capacity;
+					    ? 1048576 * 8
+					    : new_capacity;
 		}
 
 		context->buffer = (unsigned char *)realloc(
-			context->buffer,
-			new_capacity * sizeof(/*unsigned char*/ context->buffer[0] )
-		);
+		    context->buffer,
+		    new_capacity * sizeof(/*unsigned char*/ context->buffer[0]));
 
 		if (!context->buffer)
 			fatal(EXIT_NOT_ENOUGH_MEMORY, "In sbs_append_string: Not enough memory to append buffer");
@@ -561,11 +558,10 @@ struct cc_subtitle * sbs_append_string(unsigned char * str, const LLONG time_fro
 \treq cap:   [%d]\n\
 \tbuf:       [%s]\n\
 ",
-			context->buffer,
-			context->capacity,
-			required_capacity,
-			context->buffer
-		);
+			  context->buffer,
+			  context->capacity,
+			  required_capacity,
+			  context->buffer);
 	}
 
 	// ===============================
@@ -595,16 +591,15 @@ struct cc_subtitle * sbs_append_string(unsigned char * str, const LLONG time_fro
 \tsbs_undone_start: [%zu]\n\
 \tsbs_undone: [%s]\n\
 ",
-		bp_last_break,
-		context->handled_len,
-		sbs_undone_start
-	);
+		  bp_last_break,
+		  context->handled_len,
+		  sbs_undone_start);
 
 	for (bp_current = sbs_undone_start; bp_current && *bp_current; bp_current++)
 	{
 		if (
-			0 < anychar_cur	// skip empty!
-			&& sbs_is_pointer_on_sentence_breaker(bp_last_break, bp_current) )
+		    0 < anychar_cur // skip empty!
+		    && sbs_is_pointer_on_sentence_breaker(bp_last_break, bp_current))
 		{
 			// it is new sentence!
 			tmpsub = malloc(sizeof(struct cc_subtitle));
@@ -612,10 +607,9 @@ struct cc_subtitle * sbs_append_string(unsigned char * str, const LLONG time_fro
 			tmpsub->type = CC_TEXT;
 			// length of new string:
 			tmpsub->nb_data =
-				bp_current - bp_last_break
-				+ 1	 // terminating '\0'
-				+ 1  // skip '.'
-			;
+			    bp_current - bp_last_break + 1 // terminating '\0'
+			    + 1				   // skip '.'
+			    ;
 			tmpsub->data = strndup(bp_last_break, tmpsub->nb_data - 1);
 			tmpsub->datatype = CC_DATATYPE_GENERIC;
 			tmpsub->got_output = 1;
@@ -629,9 +623,7 @@ struct cc_subtitle * sbs_append_string(unsigned char * str, const LLONG time_fro
 
 			// tune last break:
 			while (
-				*bp_last_break
-				&& isspace(*bp_last_break)
-			)
+			    *bp_last_break && isspace(*bp_last_break))
 			{
 				bp_last_break++;
 			}
@@ -677,12 +669,11 @@ struct cc_subtitle * sbs_append_string(unsigned char * str, const LLONG time_fro
 \n\tSTRING:[%s]\
 \n\tBUFFER:[%s]\
 \n",
-		context->handled_len,
-		alphanum_total,
-		anychar_total,
-		str,
-		context->buffer
-	);
+		  context->handled_len,
+		  alphanum_total,
+		  anychar_total,
+		  str,
+		  context->buffer);
 
 	// ===============================
 	// Calculate time spans
@@ -721,18 +712,16 @@ struct cc_subtitle * sbs_append_string(unsigned char * str, const LLONG time_fro
 	return resub;
 }
 
-struct cc_subtitle * reformat_cc_bitmap_through_sentence_buffer(struct cc_subtitle *sub, struct encoder_ctx * context)
+struct cc_subtitle *reformat_cc_bitmap_through_sentence_buffer(struct cc_subtitle *sub, struct encoder_ctx *context)
 {
-	struct cc_bitmap* rect;
-	LLONG ms_start, ms_end;
-	int used;
-	int i = 0;
-	char *str;
-
 	// this is a sub with a full sentence (or chain of such subs)
-	struct cc_subtitle * resub = NULL;
+	struct cc_subtitle *resub = NULL;
 
 #ifdef ENABLE_OCR
+	struct cc_bitmap *rect;
+	LLONG ms_start, ms_end;
+	int i = 0;
+	char *str;
 
 	if (sub->flags & SUB_EOD_MARKER)
 	{
@@ -762,7 +751,7 @@ struct cc_subtitle * reformat_cc_bitmap_through_sentence_buffer(struct cc_subtit
 	if (sub->flags & SUB_EOD_MARKER)
 		context->prev_start = sub->start_time;
 
-	str = paraof_ocrtext(sub, context->encoded_crlf, context->encoded_crlf_length);
+	str = paraof_ocrtext(sub, context);
 
 	if (str)
 	{
@@ -775,7 +764,7 @@ struct cc_subtitle * reformat_cc_bitmap_through_sentence_buffer(struct cc_subtit
 		freep(&str);
 	}
 
-	for(i = 0, rect = sub->data; i < sub->nb_data; i++, rect++)
+	for (i = 0, rect = sub->data; i < sub->nb_data; i++, rect++)
 	{
 		freep(&rect->data0);
 		freep(&rect->data1);
