@@ -3,6 +3,7 @@
 #include "ccx_encoders_common.h"
 #include "png.h"
 #include <ft2build.h>
+#include <math.h>
 #include FT_FREETYPE_H
 #include "lib_ccx.h"
 #include "ccx_encoders_helpers.h"
@@ -20,16 +21,21 @@
 #define FONT_SIZE 20
 #define CANVAS_WIDTH 600
 
-FT_Library  ft_library = NULL;
-FT_Face	 face = NULL;
+FT_Library ft_library = NULL;
+
+// The FT_Face object handles typographical information
+// The different face variables are for the regular and italics
+FT_Face face_regular = NULL;
+FT_Face face_italics = NULL;
+FT_Face face = NULL;
 
 struct spupng_t
 {
-	FILE* fpxml;
-	FILE* fppng;
-	char* dirname;
-	char* pngfile;
-	char* relative_path_png;
+	FILE *fpxml;
+	FILE *fppng;
+	char *dirname;
+	char *pngfile;
+	char *relative_path_png;
 	int fileIndex;
 	int xOffset;
 	int yOffset;
@@ -45,20 +51,20 @@ void spupng_init_font()
 	int i, j;
 
 	/* de-interleave font image (puts all chars in row 0) */
-	if (!(t = (uint8_t*)malloc(ccfont2_width * ccfont2_height / 8)))
+	if (!(t = (uint8_t *)malloc(ccfont2_width * ccfont2_height / 8)))
 		ccx_common_logging.fatal_ftn(EXIT_NOT_ENOUGH_MEMORY, "spupng_init_font: Memory allocation failed");
 
 	for (p = t, i = 0; i < CCH; i++)
 		for (j = 0; j < ccfont2_height; p += ccfont2_width / 8, j += CCH)
 			memcpy(p, ccfont2_bits + (j + i) * ccfont2_width / 8,
-				ccfont2_width / 8);
+			       ccfont2_width / 8);
 
 	memcpy(ccfont2_bits, t, ccfont2_width * ccfont2_height / 8);
 	free(t);
 }
 struct spupng_t *spunpg_init(struct ccx_s_write *out)
 {
-	struct spupng_t *sp = (struct spupng_t *) malloc(sizeof(struct spupng_t));
+	struct spupng_t *sp = (struct spupng_t *)malloc(sizeof(struct spupng_t));
 	if (NULL == sp)
 		ccx_common_logging.fatal_ftn(EXIT_NOT_ENOUGH_MEMORY, "spunpg_init: Memory allocation failed (sp)");
 
@@ -71,15 +77,15 @@ struct spupng_t *spunpg_init(struct ccx_s_write *out)
 	if ((sp->fpxml = fdopen(out->fh, "w")) == NULL)
 	{
 		ccx_common_logging.fatal_ftn(CCX_COMMON_EXIT_FILE_CREATION_FAILED, "Cannot open %s: %s\n",
-			out->filename, strerror(errno));
+					     out->filename, strerror(errno));
 	}
 	sp->dirname = (char *)malloc(
-		sizeof(char) * (strlen(out->filename) + 3));
+	    sizeof(char) * (strlen(out->filename) + 3));
 	if (NULL == sp->dirname)
 		ccx_common_logging.fatal_ftn(EXIT_NOT_ENOUGH_MEMORY, "spunpg_init: Memory allocation failed (sp->dirname)");
 
 	strcpy(sp->dirname, out->filename);
-	char* p = strrchr(sp->dirname, '.');
+	char *p = strrchr(sp->dirname, '.');
 	if (NULL == p)
 		p = sp->dirname + strlen(sp->dirname);
 	*p = '\0';
@@ -89,7 +95,7 @@ struct spupng_t *spunpg_init(struct ccx_s_write *out)
 		if (errno != EEXIST)
 		{
 			ccx_common_logging.fatal_ftn(CCX_COMMON_EXIT_FILE_CREATION_FAILED, "Cannot create %s: %s\n",
-				sp->dirname, strerror(errno));
+						     sp->dirname, strerror(errno));
 		}
 		// If dirname isn't a directory or if we don't have write permission,
 		// the first attempt to create a .png file will fail and we'll XXxit.
@@ -105,8 +111,9 @@ struct spupng_t *spunpg_init(struct ccx_s_write *out)
 	sprintf(sp->pngfile, "%s/sub%04d.png", sp->dirname, sp->fileIndex);
 
 	// Make relative path
-	char* last_slash = strrchr(sp->dirname, '/');
-	if (last_slash == NULL) last_slash = strrchr(sp->dirname, '\\');
+	char *last_slash = strrchr(sp->dirname, '/');
+	if (last_slash == NULL)
+		last_slash = strrchr(sp->dirname, '\\');
 	if (last_slash != NULL)
 		sprintf(sp->relative_path_png, "%s/sub%04d.png", last_slash + 1, sp->fileIndex);
 	else // do NOT do sp->relative_path_png = sp->pngfile (to avoid double free).
@@ -152,9 +159,10 @@ void write_spumux_header(struct encoder_ctx *ctx, struct ccx_s_write *out)
 	if (0 == out->spupng_data)
 		out->spupng_data = spunpg_init(out);
 
-	spupng_write_header((struct spupng_t*)out->spupng_data, ctx->multiple_files, ctx->first_input_file);
+	spupng_write_header((struct spupng_t *)out->spupng_data, ctx->multiple_files, ctx->first_input_file);
 
-	if (ctx->write_format == CCX_OF_RAW) {		// WARN: Memory leak with this flag, free by hand. Maybe bug.
+	if (ctx->write_format == CCX_OF_RAW)
+	{ // WARN: Memory leak with this flag, free by hand. Maybe bug.
 		spupng_write_footer(out->spupng_data);
 		spunpg_free(out->spupng_data);
 	}
@@ -164,7 +172,7 @@ void write_spumux_footer(struct ccx_s_write *out)
 {
 	if (0 != out->spupng_data)
 	{
-		struct spupng_t *sp = (struct spupng_t *) out->spupng_data;
+		struct spupng_t *sp = (struct spupng_t *)out->spupng_data;
 
 		spupng_write_footer(sp);
 		spunpg_free(sp);
@@ -193,7 +201,7 @@ void write_spucomment(struct spupng_t *sp, const char *str)
 	fprintf(sp->fpxml, "<!--\n%s\n-->\n", str);
 }
 
-char* get_spupng_filename(void *ctx)
+char *get_spupng_filename(void *ctx)
 {
 	struct spupng_t *sp = (struct spupng_t *)ctx;
 	return sp->pngfile;
@@ -204,8 +212,9 @@ void inc_spupng_fileindex(struct spupng_t *sp)
 	sprintf(sp->pngfile, "%s/sub%04d.png", sp->dirname, sp->fileIndex);
 
 	// Make relative path
-	char* last_slash = strrchr(sp->dirname, '/');
-	if (last_slash == NULL) last_slash = strrchr(sp->dirname, '\\');
+	char *last_slash = strrchr(sp->dirname, '/');
+	if (last_slash == NULL)
+		last_slash = strrchr(sp->dirname, '\\');
 	if (last_slash != NULL)
 		sprintf(sp->relative_path_png, "%s/sub%04d.png", last_slash + 1, sp->fileIndex);
 	else // do NOT do sp->relative_path_png = sp->pngfile (to avoid double free).
@@ -218,12 +227,12 @@ void set_spupng_offset(void *ctx, int x, int y)
 	sp->yOffset = y;
 }
 int save_spupng(const char *filename, uint8_t *bitmap, int w, int h,
-	png_color *palette, png_byte *alpha, int nb_color)
+		png_color *palette, png_byte *alpha, int nb_color)
 {
 	FILE *f = NULL;
 	png_structp png_ptr = NULL;
 	png_infop info_ptr = NULL;
-	png_bytep* row_pointer = NULL;
+	png_bytep *row_pointer = NULL;
 	int i, j, ret = 0;
 	int k = 0;
 	if (!h)
@@ -252,7 +261,7 @@ int save_spupng(const char *filename, uint8_t *bitmap, int w, int h,
 		goto end;
 	}
 
-	row_pointer = (png_bytep*)malloc(sizeof(png_bytep) * h);
+	row_pointer = (png_bytep *)malloc(sizeof(png_bytep) * h);
 	if (!row_pointer)
 	{
 		ccx_common_logging.log_ftn("DVB: unable to allocate row_pointer\n");
@@ -263,19 +272,19 @@ int save_spupng(const char *filename, uint8_t *bitmap, int w, int h,
 	png_init_io(png_ptr, f);
 
 	png_set_IHDR(png_ptr, info_ptr, w, h,
-		/* bit_depth */8,
-		PNG_COLOR_TYPE_PALETTE,
-		PNG_INTERLACE_NONE,
-		PNG_COMPRESSION_TYPE_DEFAULT,
-		PNG_FILTER_TYPE_DEFAULT);
+		     /* bit_depth */ 8,
+		     PNG_COLOR_TYPE_PALETTE,
+		     PNG_INTERLACE_NONE,
+		     PNG_COMPRESSION_TYPE_DEFAULT,
+		     PNG_FILTER_TYPE_DEFAULT);
 
 	png_set_PLTE(png_ptr, info_ptr, palette, nb_color);
 	png_set_tRNS(png_ptr, info_ptr, alpha, nb_color, NULL);
 
 	for (i = 0; i < h; i++)
 	{
-		row_pointer[i] = (png_byte*)malloc(
-			png_get_rowbytes(png_ptr, info_ptr));
+		row_pointer[i] = (png_byte *)malloc(
+		    png_get_rowbytes(png_ptr, info_ptr));
 		if (row_pointer[i] == NULL)
 			break;
 	}
@@ -301,17 +310,17 @@ int save_spupng(const char *filename, uint8_t *bitmap, int w, int h,
 	png_write_image(png_ptr, row_pointer);
 
 	png_write_end(png_ptr, info_ptr);
-end: if (row_pointer)
-{
-	for (i = 0; i < h; i++)
-		freep(&row_pointer[i]);
-	freep(&row_pointer);
-}
-	 png_destroy_write_struct(&png_ptr, &info_ptr);
-	 if (f)
-		 fclose(f);
-	 return ret;
-
+end:
+	if (row_pointer)
+	{
+		for (i = 0; i < h; i++)
+			freep(&row_pointer[i]);
+		freep(&row_pointer);
+	}
+	png_destroy_write_struct(&png_ptr, &info_ptr);
+	if (f)
+		fclose(f);
+	return ret;
 }
 /**
 * alpha value 255 means completely opaque
@@ -320,7 +329,7 @@ end: if (row_pointer)
 * r g b all 255 means white
 */
 int mapclut_paletee(png_color *palette, png_byte *alpha, uint32_t *clut,
-	uint8_t depth)
+		    uint8_t depth)
 {
 	for (int i = 0; i < depth; i++)
 	{
@@ -334,7 +343,7 @@ int mapclut_paletee(png_color *palette, png_byte *alpha, uint32_t *clut,
 	for (int i = 0; i < depth; i++)
 	{
 		ccx_common_logging.log_ftn("%02d)r %03d g %03d b %03d a %03d\n",
-			i, palette[i].red, palette[i].green, palette[i].blue, alpha[i]);
+					   i, palette[i].red, palette[i].green, palette[i].blue, alpha[i]);
 	}
 #endif
 	return 0;
@@ -347,7 +356,7 @@ int write_cc_bitmap_as_spupng(struct cc_subtitle *sub, struct encoder_ctx *conte
 	int x, y, y_off, x_off, ret = 0;
 	uint8_t *pbuf;
 	char *filename;
-	struct cc_bitmap* rect;
+	struct cc_bitmap *rect;
 	png_color *palette = NULL;
 	png_byte *alpha = NULL;
 	int wrote_opentag = 1;
@@ -403,14 +412,13 @@ int write_cc_bitmap_as_spupng(struct cc_subtitle *sub, struct encoder_ctx *conte
 			{
 				height = rect[i].y + rect[i].h - y_pos;
 			}
-
 		}
 	}
 	filename = get_spupng_filename(sp);
 	set_spupng_offset(sp, x_pos, y_pos);
 	if (sub->flags & SUB_EOD_MARKER)
 		context->prev_start = sub->start_time;
-	pbuf = (uint8_t*)malloc(width * height);
+	pbuf = (uint8_t *)malloc(width * height);
 	memset(pbuf, 0x0, width * height);
 
 	for (i = 0; i < sub->nb_data; i++)
@@ -421,16 +429,15 @@ int write_cc_bitmap_as_spupng(struct cc_subtitle *sub, struct encoder_ctx *conte
 		{
 			for (x = 0; x < rect[i].w; x++)
 				pbuf[((y + y_off) * width) + x_off + x] = rect[i].data0[y * rect[i].w + x];
-
 		}
 	}
-	palette = (png_color*)malloc(rect[0].nb_colors * sizeof(png_color));
+	palette = (png_color *)malloc(rect[0].nb_colors * sizeof(png_color));
 	if (!palette)
 	{
 		ret = -1;
 		goto end;
 	}
-	alpha = (png_byte*)malloc(rect[0].nb_colors * sizeof(png_byte));
+	alpha = (png_byte *)malloc(rect[0].nb_colors * sizeof(png_byte));
 	if (!alpha)
 	{
 		ret = -1;
@@ -439,11 +446,11 @@ int write_cc_bitmap_as_spupng(struct cc_subtitle *sub, struct encoder_ctx *conte
 
 	/* TODO do rectangle wise, one color table should not be used for all rectangles */
 	mapclut_paletee(palette, alpha, (uint32_t *)rect[0].data1, rect[0].nb_colors);
-#ifdef ENABLE_OCR	
+#ifdef ENABLE_OCR
 	if (!context->nospupngocr)
 	{
 		char *str;
-		str = paraof_ocrtext(sub, context->encoded_crlf, context->encoded_crlf_length);
+		str = paraof_ocrtext(sub, context);
 		if (str)
 		{
 			write_spucomment(sp, str);
@@ -454,7 +461,6 @@ int write_cc_bitmap_as_spupng(struct cc_subtitle *sub, struct encoder_ctx *conte
 	save_spupng(filename, pbuf, width, height, palette, alpha, rect[0].nb_colors);
 	freep(&pbuf);
 
-
 end:
 	if (wrote_opentag)
 		write_sputag_close(sp);
@@ -472,25 +478,28 @@ end:
 	return ret;
 }
 
-struct pixel_t {
+struct pixel_t
+{
 	unsigned char r, g, b, a;
 };
 
 // Write the buffer to a file named filename
 // Return 1 on success.
-int write_image(struct pixel_t *buffer, FILE* fp, int width, int height)
+int write_image(struct pixel_t *buffer, FILE *fp, int width, int height)
 {
 	int ret_code = 1;
 	png_structp png_ptr = NULL;
 	png_infop info_ptr = NULL;
 	png_bytep row = NULL;
 
-	if (!(png_ptr = png_create_write_struct(PNG_LIBPNG_VER_STRING, NULL, NULL, NULL))) {
+	if (!(png_ptr = png_create_write_struct(PNG_LIBPNG_VER_STRING, NULL, NULL, NULL)))
+	{
 		mprint("\nUnknown error encountered!\n");
 		ret_code = 0;
 		goto finalise;
 	}
-	if (!(info_ptr = png_create_info_struct(png_ptr))) {
+	if (!(info_ptr = png_create_info_struct(png_ptr)))
+	{
 		mprint("\nUnknown error encountered!\n");
 		ret_code = 0;
 		goto finalise;
@@ -500,8 +509,8 @@ int write_image(struct pixel_t *buffer, FILE* fp, int width, int height)
 
 	// Write header
 	png_set_IHDR(png_ptr, info_ptr, width, height,
-		8, PNG_COLOR_TYPE_RGB_ALPHA, PNG_INTERLACE_NONE,
-		PNG_COMPRESSION_TYPE_BASE, PNG_FILTER_TYPE_BASE);
+		     8, PNG_COLOR_TYPE_RGB_ALPHA, PNG_INTERLACE_NONE,
+		     PNG_COMPRESSION_TYPE_BASE, PNG_FILTER_TYPE_BASE);
 
 	png_write_info(png_ptr, info_ptr);
 
@@ -510,12 +519,14 @@ int write_image(struct pixel_t *buffer, FILE* fp, int width, int height)
 
 	// Write image data
 	int x, y;
-	for (y = 0; y<height; y++) {
-		for (x = 0; x<width; x++) {
-			row[x * 4 + 0] = buffer[y*width + x].r;
-			row[x * 4 + 1] = buffer[y*width + x].g;
-			row[x * 4 + 2] = buffer[y*width + x].b;
-			row[x * 4 + 3] = buffer[y*width + x].a;
+	for (y = 0; y < height; y++)
+	{
+		for (x = 0; x < width; x++)
+		{
+			row[x * 4 + 0] = buffer[y * width + x].r;
+			row[x * 4 + 1] = buffer[y * width + x].g;
+			row[x * 4 + 2] = buffer[y * width + x].b;
+			row[x * 4 + 3] = buffer[y * width + x].a;
 		}
 		png_write_row(png_ptr, row);
 	}
@@ -524,9 +535,12 @@ int write_image(struct pixel_t *buffer, FILE* fp, int width, int height)
 	png_write_end(png_ptr, NULL);
 
 finalise:
-	if (info_ptr != NULL) png_free_data(png_ptr, info_ptr, PNG_FREE_ALL, -1);
-	if (png_ptr != NULL) png_destroy_write_struct(&png_ptr, (png_infopp)NULL);
-	if (row != NULL) free(row);
+	if (info_ptr != NULL)
+		png_free_data(png_ptr, info_ptr, PNG_FREE_ALL, -1);
+	if (png_ptr != NULL)
+		png_destroy_write_struct(&png_ptr, (png_infopp)NULL);
+	if (row != NULL)
+		free(row);
 
 	return ret_code;
 }
@@ -534,16 +548,28 @@ finalise:
 // Draw a FT_Bitmap to the target surface
 // Dest: target - an array which stores image data (ARGB), row by row.
 // Src: bitmap.buffer - 8bit grayscale image, row by row, with the size of bitmap.rows*bitmap.width
-void draw_to_buffer(struct pixel_t *target, int target_width, FT_Bitmap bitmap, int x_pos, int y_pos) {
+void draw_to_buffer(struct pixel_t *target, int target_width, FT_Bitmap bitmap, int x_pos, int y_pos, int color)
+{
 	int height = bitmap.rows;
 	int width = bitmap.width;
 
 	// The x, y here is based on the `bitmap` argument (i.e. the input bitmap)
-	for (int y = 0; y < height; ++y) {
-		for (int x = 0; x < width; ++x) {
+	for (int y = 0; y < height; ++y)
+	{
+		for (int x = 0; x < width; ++x)
+		{
 			struct pixel_t p;
-			p.a = p.r = p.g = p.b = bitmap.buffer[x + y * width];
-			target[(x_pos+x) + (y_pos+y) * target_width] = p;
+			unsigned char shade_factor = bitmap.buffer[x + y * width];
+			p.a = shade_factor;
+			p.r = (unsigned char)(((color >> (8 * 2)) & 0xff) * (shade_factor / 255.0));
+			p.g = (unsigned char)(((color >> (8 * 1)) & 0xff) * (shade_factor / 255.0));
+			p.b = (unsigned char)(((color >> (8 * 0)) & 0xff) * (shade_factor / 255.0));
+
+			//mprint("Red: %d\n", p.r);
+			//mprint("Green: %d\n", p.g);
+			//mprint("Blue: %d\n", p.b);
+
+			target[(x_pos + x) + (y_pos + y) * target_width] = p;
 		}
 	}
 }
@@ -554,30 +580,35 @@ void draw_to_buffer(struct pixel_t *target, int target_width, FT_Bitmap bitmap,
 // The function will move the subtitle to (target_w/2 + valid_w/2, valid_y),
 //   and erase anything else in the line.
 void center_justify(struct pixel_t *target, int target_w,
-					int valid_y, int valid_w, int valid_h) {
+		    int valid_y, int valid_w, int valid_h)
+{
 	// 1. Make a copy of the line, to avoid overriding.
 	// Note that the copy is smaller than the line:
 	//   its width is set to just enough to contain the valid area
-	struct pixel_t* temp_buffer = malloc(valid_w*valid_h*sizeof(struct pixel_t));
+	struct pixel_t *temp_buffer = malloc(valid_w * valid_h * sizeof(struct pixel_t));
 
 	// x,y here is input-based (i.e. `buffer`)
-	for (int x = 0; x < valid_w; ++x) {
-		for (int y = valid_y; y < valid_y + valid_h; ++y) {
-			temp_buffer[x + (y - valid_y)*valid_w] = target[x + y * target_w];
+	for (int x = 0; x < valid_w; ++x)
+	{
+		for (int y = valid_y; y < valid_y + valid_h; ++y)
+		{
+			temp_buffer[x + (y - valid_y) * valid_w] = target[x + y * target_w];
 		}
 	}
 
 	// 2. Clean up the original subtitle
-	memset(target + valid_y * target_w, 0, target_w*valid_h * sizeof(struct pixel_t));
+	memset(target + valid_y * target_w, 0, target_w * valid_h * sizeof(struct pixel_t));
 
 	// 3. Center justify
 	int move_to = target_w / 2 - valid_w / 2; // the target x
 
 	// x,y here is output-based (i.e. `buffer`)
 	// valid_y is also output_y since we are printing to the same line.
-	for (int y = valid_y; y < valid_y + valid_h; ++y) {
-		for (int x = move_to; x < move_to + valid_w; ++x) {
-			target[x + y * target_w] = temp_buffer[(x - move_to) + (y - valid_y)*valid_w];
+	for (int y = valid_y; y < valid_y + valid_h; ++y)
+	{
+		for (int x = move_to; x < move_to + valid_w; ++x)
+		{
+			target[x + y * target_w] = temp_buffer[(x - move_to) + (y - valid_y) * valid_w];
 		}
 	}
 
@@ -588,53 +619,121 @@ void center_justify(struct pixel_t *target, int target_w,
 // Draw black background for the subtitle
 // Will not override the text
 // target_w is the width of the canvas
-void black_background(struct pixel_t *target, int target_w, int x, int y, int w, int h) {
-	for (int _x = x; _x < x + w; ++_x) {
-		for (int _y = y; _y < y + h; ++_y) {
+void black_background(struct pixel_t *target, int target_w, int x, int y, int w, int h)
+{
+	for (int _x = x; _x < x + w; ++_x)
+	{
+		for (int _y = y; _y < y + h; ++_y)
+		{
 			target[_x + _y * target_w].a = 255;
 		}
 	}
 }
 
-// Convert big-endian and little-endian
-#define BigtoLittle32(A)   ((( (uint32_t)(A) & 0xff000000) >> 24)\
- | (((uint32_t)(A) & 0x00ff0000) >> 8)\
- | (((uint32_t)(A) & 0x0000ff00) << 8)\
- | (((uint32_t)(A) & 0x000000ff) << 24))
+// Draws an underline starting at x and y
+void underline_text(struct pixel_t *target, int target_w, int x, int y, int w, int h, int color)
+{
+	for (int _x = x; _x < x + w; ++_x)
+	{
+		for (int _y = y; _y < y + h; ++_y)
+		{
+			struct pixel_t p;
+			p.a = 255;
+			p.r = (unsigned char)((color >> (8 * 2)) & 0xff);
+			p.g = (unsigned char)((color >> (8 * 1)) & 0xff);
+			p.b = (unsigned char)((color >> (8 * 0)) & 0xff);
 
-// Generate PNG file from an UTF-32 string (str)
-// Convert first if it is UTF-8 string!
+			target[_x + _y * target_w] = p;
+		}
+	}
+}
+
+// Converts font units to pixels
+// Uses the y PPEM for conversions
+int fu_to_ypixels(FT_Face face, int fu)
+{
+	return round(fu * face->size->metrics.y_ppem / (double)face->units_per_EM);
+}
+
+// Initialize face object for typographical fonts
+// Return 0 for success
+int init_face(FT_Face *face, char *font)
+{
+	int error;
+
+	// Init regular font
+	if ((error = FT_New_Face(ft_library, font, 0, face)))
+	{
+		mprint("\n\nFailed to init freetype when trying to init face, error code: %d\n", error);
+		mprint("It's usually caused by the specified font is not found: %s \n", font);
+		mprint("If this is the case, please use -font or -italics to manually specify a font that exists. \n\n");
+		return 1;
+	}
+	if ((error = FT_Set_Pixel_Sizes(*face, 0, FONT_SIZE)))
+	{
+		mprint("\nFailed to init freetype when trying to set size, error code: %d\n", error);
+		return 1;
+	}
+
+	return 0;
+}
+
+// The function will NOT free src.
+// You need to free the src and return value yourself!
+uint32_t *utf8_to_utf32(char *src)
+{
+	// Convert UTF-8 to UTF-32 for generating bitmap.
+	size_t len_src, len_dst;
+
+	len_src = strlen(src);
+	len_dst = (len_src + 2) * 4; // one for FEFF and one for \0
+
+	uint32_t *string_utf32 = (uint32_t *)calloc(len_dst, 1);
+	size_t inbufbytesleft = len_src;
+	size_t outbufbytesleft = len_dst;
+	char *inbuf = src;
+	char *outbuf = (char *)string_utf32;
+
+	iconv_t cd = iconv_open("UTF-32", "UTF-8");
+	int result = iconv(cd, &inbuf, &inbufbytesleft, &outbuf, &outbufbytesleft);
+	if (result == -1)
+		mprint("iconv failed to convert UTF-8 to UTF-32. errno is %d\n", errno);
+	iconv_close(cd);
+
+	return string_utf32;
+}
+
+// Convert big-endian and little-endian
+#define BigtoLittle32(A) ((((uint32_t)(A)&0xff000000) >> 24) | (((uint32_t)(A)&0x00ff0000) >> 8) | (((uint32_t)(A)&0x0000ff00) << 8) | (((uint32_t)(A)&0x000000ff) << 24))
+
+// Generate PNG file from an UTF-8 string (str)
 // PNG file will be stored at output
 // Return 1 on success.
-int spupng_export_string2png(struct spupng_t *sp, uint32_t *str, FILE* output)
+int spupng_export_string2png(struct spupng_t *sp, char *str, FILE *output)
 {
+	int error;
 	// Init FreeType if it hasn't been inited yet.
-	if (ft_library==NULL){
-		int error;
-		if (error = FT_Init_FreeType(&ft_library))
+	if (ft_library == NULL)
+	{
+
+		if ((error = FT_Init_FreeType(&ft_library)))
 		{
 			mprint("\nFailed to init freetype, error code: %d\n", error);
 			return 0;
 		}
-		if (error = FT_New_Face(ft_library, ccx_options.enc_cfg.render_font, 0, &face))
-		{
-			mprint("\n\nFailed to init freetype when trying to init face, error code: %d\n", error);
-			mprint("It's usually caused by the specified font is not found: %s \n", ccx_options.enc_cfg.render_font);
-			mprint("If this is the case, please use -font to manually specify a font that exists. \n\n");
-			return 0;
-		}
-		if (error = FT_Set_Pixel_Sizes(face, 0, FONT_SIZE))
-		{
-			mprint("\nFailed to init freetype when trying to set size, error code: %d\n", error);
-			return 0;
-		}
 	}
 
+	// Init FreeType typographical face objects
+	if ((error = init_face(&face_regular, ccx_options.enc_cfg.render_font)))
+		return 0;
+	if ((error = init_face(&face_italics, ccx_options.enc_cfg.render_font_italics)))
+		return 0;
+
 	int canvas_width = CANVAS_WIDTH;
 	int canvas_height = FONT_SIZE * 3.5;
 	int line_height = FONT_SIZE * 1.0;
-	int extender = FONT_SIZE * 0.2; // to prevent characters like $ (exceed baseline) from being cut
-	int line_spacing = FONT_SIZE * 0.3;
+	int extender = FONT_SIZE * 0.4; // to prevent characters like $ and _ (exceed baseline) from being cut and to add room for underlining
+	int line_spacing = FONT_SIZE * 0.8;
 
 	int cursor_x = 0;
 	int cursor_y = line_height * 2;
@@ -642,78 +741,195 @@ int spupng_export_string2png(struct spupng_t *sp, uint32_t *str, FILE* output)
 	// Allocate buffer
 	// Note: (0, 0) of buffer is at the top left corner.
 	struct pixel_t *buffer = malloc(canvas_width * canvas_height * sizeof(struct pixel_t));
-	if (buffer == NULL) {
-		mprint("\nFailed to alloc memory for buffer. Need %d bytes.\n",
-			canvas_width * canvas_height * sizeof(struct pixel_t));
-	}
-	memset(buffer, 0, canvas_width*canvas_height * sizeof(struct pixel_t));
-	
-	FT_GlyphSlot slot = face->glyph;
-
-	// Render characters to image
-	for (uint32_t *iter = str; *iter; ++iter)
+	if (buffer == NULL)
 	{
-		uint32_t current_char_code = BigtoLittle32(*iter); // Convert big-endian and little-endian
+		mprint("\nFailed to alloc memory for buffer. Need %d bytes.\n",
+		       canvas_width * canvas_height * sizeof(struct pixel_t));
+	}
+	memset(buffer, 0, canvas_width * canvas_height * sizeof(struct pixel_t));
 
-		if (FT_Load_Char(face, current_char_code, FT_LOAD_RENDER)) continue; // ignore errors
-		unsigned char* bitmap = slot->bitmap.buffer;
+	//str = "<font color=\"#66CDAA\"> __ This should be aquamarine </font> Regular <i> Italics font</i> <font color=\"#00ff00\">This should be green.</font> <u> Underlining __ testing </u> Regular text. Even more text. Random text. More text."; // Test string
+	char *tmp = strdup(str);
 
-		// Handle '\n'
-		if (current_char_code == '\n') {
-//			mprint("\n'\\n' line break");
-			black_background(buffer, canvas_width, 0, cursor_y - line_height - extender, cursor_x, line_height + extender * 2);
-			center_justify(buffer, canvas_width, cursor_y - line_height - extender, cursor_x, line_height + extender * 2);
-			cursor_x = 0;
-			cursor_y += line_height + line_spacing;
+	if (!tmp)
+		return -1;
+
+	char *token = strtok(tmp, "<>");
+
+	int color = 0xffffff;
+	int prev_color = 0xffffff;
+	int underline = 0;
+	int font = 0;
+	face = face_regular;
+
+	while (token != NULL)
+	{
+		if (strlen(token) == 1 && strncmp("i", token, 1) == 0)
+		{
+			token = strtok(NULL, "<>");
+			face = face_italics;
+			continue;
+		}
+		else if (strlen(token) == 2 && strncmp("/i", token, 2) == 0)
+		{
+			face = face_regular;
+			token = strtok(NULL, "<>");
+			continue;
+		}
+		if (strlen(token) == 1 && strncmp("u", token, 1) == 0)
+		{
+			underline = 1;
+			token = strtok(NULL, "<>");
+			continue;
+		}
+		else if (strlen(token) == 2 && strncmp("/u", token, 2) == 0)
+		{
+			underline = 0;
+			token = strtok(NULL, "<>");
 			continue;
 		}
 
-		// Expand canvas if needed
-		while (cursor_y - slot->bitmap_top + line_height + line_spacing + extender * 2 >= canvas_height) {
-			int old_height = canvas_height;
-			canvas_height += line_height + line_spacing + extender * 2;
-			struct pixel_t* new_buffer = realloc(buffer, canvas_width * canvas_height * sizeof(struct pixel_t));
-			if (new_buffer == NULL) {
-				mprint("\nFailed to alloc memory for buffer. Need %d bytes.\n",
-					canvas_width * canvas_height * sizeof(struct pixel_t));
-				return 0;
+		else if (strlen(token) > 9 && strncmp("font color", token, 10) == 0)
+		{
+			// If the font element is already nested in another font element
+			if (font)
+			{
+				prev_color = color;
 			}
-			memset(new_buffer + old_height * canvas_width, 0, (canvas_height-old_height) * canvas_width * sizeof(struct pixel_t));
-			buffer = new_buffer;
-			
+
+			font = 1;
+			char color_value[7];
+
+			// Isolate the hex color value
+			int start = 0;
+			for (int i = 0; i < strlen(token); i++)
+			{
+				if (token[i] == '#')
+				{
+					start = i + 1;
+					break;
+				}
+			}
+			strncpy(color_value, &token[start], 6);
+			color_value[6] = 0; // For null termination of string
+			color = (int)strtol(color_value, NULL, 16);
+
+			//mprint("Color: 0x%x\n", color);
+			token = strtok(NULL, "<>");
+			continue;
 		}
+		else if (strlen(token) > 4 && strncmp("/font", token, 5) == 0)
+		{
+			font = 0;
+			token = strtok(NULL, "<>");
+			color = prev_color;
+			continue;
+		}
+		//mprint("%s\n", token);
 
-		// Characters such as ' ' don't have bitmap.
-		if (bitmap != NULL) {
+		FT_GlyphSlot slot = face->glyph;
+		;
 
-			int width = slot->bitmap.width;
-			int height = slot->bitmap.rows;
+		uint32_t *string_utf32 = utf8_to_utf32(token);
 
-			// TODO: this kind of line break may break characters in the middle!
-			if ((cursor_x + (slot->advance.x >> 6)) > canvas_width) { // Time for a line-break!
-				// But before that, let's center justify the subtitle.
-				// Valid subtitle area: (0, cursor_y) to (cursor_x, cursor_y + line_height)
+		// Render characters to image
+		for (uint32_t *iter = string_utf32; *iter; ++iter)
+		{
+			uint32_t current_char_code = BigtoLittle32(*iter); // Convert big-endian and little-endian
+
+			if (FT_Load_Char(face, current_char_code, FT_LOAD_RENDER))
+				continue; // ignore errors
+
+			unsigned char *bitmap = slot->bitmap.buffer;
+
+			// Handle '\n'
+			if (current_char_code == '\n')
+			{
+				//			mprint("\n'\\n' line break");
 				black_background(buffer, canvas_width, 0, cursor_y - line_height - extender, cursor_x, line_height + extender * 2);
 				center_justify(buffer, canvas_width, cursor_y - line_height - extender, cursor_x, line_height + extender * 2);
-				
-				// Set the cursor
 				cursor_x = 0;
 				cursor_y += line_height + line_spacing;
+				continue;
 			}
-			
-			draw_to_buffer(buffer, canvas_width, slot->bitmap, cursor_x, cursor_y - slot->bitmap_top);
 
+			// Expand canvas if needed
+			while (cursor_y - slot->bitmap_top + line_height + line_spacing + extender * 2 >= canvas_height)
+			{
+				int old_height = canvas_height;
+				canvas_height += line_height + line_spacing + extender * 2;
+				struct pixel_t *new_buffer = realloc(buffer, canvas_width * canvas_height * sizeof(struct pixel_t));
+				if (new_buffer == NULL)
+				{
+					mprint("\nFailed to alloc memory for buffer. Need %d bytes.\n",
+					       canvas_width * canvas_height * sizeof(struct pixel_t));
+					return 0;
+				}
+				memset(new_buffer + old_height * canvas_width, 0, (canvas_height - old_height) * canvas_width * sizeof(struct pixel_t));
+				buffer = new_buffer;
+			}
+
+			// Characters such as ' ' don't have bitmap.
+			if (bitmap != NULL)
+			{
+				// TODO: this kind of line break may break characters in the middle!
+				if ((cursor_x + (slot->advance.x >> 6)) > canvas_width)
+				{ // Time for a line-break!
+					// But before that, let's center justify the subtitle.
+					// Valid subtitle area: (0, cursor_y) to (cursor_x, cursor_y + line_height)
+					black_background(buffer, canvas_width, 0, cursor_y - line_height - extender, cursor_x, line_height + extender * 2);
+					center_justify(buffer, canvas_width, cursor_y - line_height - extender, cursor_x, line_height + extender * 2);
+
+					// Set the cursor
+					cursor_x = 0;
+					cursor_y += line_height + line_spacing;
+				}
+
+				draw_to_buffer(buffer, canvas_width, slot->bitmap, cursor_x, cursor_y - slot->bitmap_top, color);
+
+				if (underline)
+				{
+					// Converts underline offset from font units to pixels
+					int pixel_offset = fu_to_ypixels(face, face->underline_position);
+
+					// Calculates how wide a character is
+					int glyph_width = slot->advance.x >> 6;
+					//mprint("Glyph Width: %d\n", glyph_width);
+
+					int underline_thickness = fu_to_ypixels(face, face->underline_thickness);
+					underline_text(buffer, canvas_width, cursor_x, cursor_y - pixel_offset, glyph_width, underline_thickness, color);
+				}
+			}
+			// For all the characters without bitmaps like spaces ' '
+			else
+			{
+
+				if (underline)
+				{
+					// Converts underline offset from font units to pixels
+					int pixel_offset = fu_to_ypixels(face, face->underline_position);
+					// Calculates how wide a character is
+					int glyph_width = (slot->advance.x >> 6);
+
+					//mprint("Glyph Width: %d\n", glyph_width);
+					int underline_thickness = fu_to_ypixels(face, face->underline_thickness);
+					underline_text(buffer, canvas_width, cursor_x, cursor_y - pixel_offset, glyph_width, underline_thickness, color);
+				}
+			}
+
+			/*
+			mprint("\nDrawing [%c] (%d), advance %d,%d, at %d,%d. bitmap_top=%d",
+				current_char_code, current_char_code, slot->advance.x >> 6, slot->advance.y >> 6, cursor_x, cursor_y, slot->bitmap_top);
+			*/
+
+			// Increase pen position
+			cursor_x += slot->advance.x >> 6;
+			cursor_y += slot->advance.y >> 6;
 		}
-
-		/*
-		mprint("\nDrawing [%c] (%d), advance %d,%d, at %d,%d. bitmap_top=%d",
-			current_char_code, current_char_code, slot->advance.x >> 6, slot->advance.y >> 6, cursor_x, cursor_y, slot->bitmap_top);
-		*/
-
-		// Increase pen position
-		cursor_x += slot->advance.x >> 6;
-		cursor_y += slot->advance.y >> 6;
+		token = strtok(NULL, "<>");
+		free(string_utf32);
 	}
+
 	// Draw black background
 	black_background(buffer, canvas_width, 0, cursor_y - line_height - extender, cursor_x, line_height + extender * 2);
 	// Center justify the last line.
@@ -730,15 +946,18 @@ int spupng_export_string2png(struct spupng_t *sp, uint32_t *str, FILE* output)
 
 	// Save image
 	write_image(buffer, output, canvas_width, canvas_height);
-
+	free(tmp);
 	free(buffer);
+	FT_Done_Face(face_regular);
+	FT_Done_Face(face_italics);
 	return 1;
 }
 
 // Convert EIA608 Data(buffer) to string
 // out must have at least 256 characters' space
 // Return value is the length of the output string
-int eia608_to_str(struct encoder_ctx *context, struct eia608_screen *data, char *out) {
+int eia608_to_str(struct encoder_ctx *context, struct eia608_screen *data, char *out)
+{
 
 	int str_len = 0;
 	int first = 1;
@@ -748,43 +967,48 @@ int eia608_to_str(struct encoder_ctx *context, struct eia608_screen *data, char
 		{
 			size_t len = get_decoder_line_encoded(context, context->subline, row, data);
 
-			unsigned char* start = context->subline;
+			unsigned char *start = context->subline;
 
-			if (start!=NULL) {
+			if (start != NULL)
+			{
 				// Remove the space at the beginning of the subtitle
-				while ((*start == ' ' || *start == '\n') && len-->0)
+				while ((*start == ' ' || *start == '\n') && len-- > 0)
 					start++;
 			}
 
 			// Check for characters that spumux won't parse
 			// null chars will be changed to space
 			// pairs of dashes will be changed to underscores
-			for (unsigned char* ptr = start; ptr < start + len; ptr++)
+			for (unsigned char *ptr = start; ptr < start + len; ptr++)
 			{
 				switch (*ptr)
 				{
-				case 0:
-					*ptr = ' ';
-					break;
-				case '-':
-					if (*(ptr + 1) == '-')
-					{
-						*ptr++ = '_';
-						*ptr = '_';
-					}
-					break;
+					case 0:
+						*ptr = ' ';
+						break;
+					case '-':
+						if (*(ptr + 1) == '-')
+						{
+							*ptr++ = '_';
+							*ptr = '_';
+						}
+						break;
 				}
 			}
-			
+
 			// Remove the space at the end of the subtitle
-			if (start != NULL) {
+			if (start != NULL)
+			{
 				unsigned char *end = start;
-				while (*end && end - start < len && end - start >= 0) end++; // Find the end
-				while ((*end==' '||*end=='\n'||*end=='\0')&&len-->0) end--; // `len` is changed
+				while (*end && end - start < len && end - start >= 0)
+					end++; // Find the end
+				while ((*end == ' ' || *end == '\n' || *end == '\0') && len-- > 0)
+					end--; // `len` is changed
 				len++;
 			}
 
-			if (!first) { // Add '\n' if it is not the first line.
+			if (!first)
+			{ // Add '\n' if it is not the first line.
 				strcat(out, "\n");
 				str_len += 2;
 			}
@@ -796,60 +1020,27 @@ int eia608_to_str(struct encoder_ctx *context, struct eia608_screen *data, char
 	return str_len;
 }
 
-// The function will NOT free src.
-// You need to free the src and return value yourself!
-uint32_t* utf8_to_utf32(char* src) {
-	// Convert UTF-8 to UTF-32 for generating bitmap.
-	size_t len_src, len_dst;
-
-	len_src = strlen(src);
-	len_dst = (len_src + 2) * 4; // one for FEFF and one for \0
-
-	uint32_t* string_utf32 = (uint32_t *) calloc(len_dst, 1);
-	size_t inbufbytesleft = len_src;
-	size_t outbufbytesleft = len_dst;
-	char* inbuf = src;
-	char* outbuf = (char*) string_utf32;
-
-	iconv_t cd = iconv_open("UTF-32", "UTF-8");
-	int result = iconv(cd, &inbuf, &inbufbytesleft, &outbuf, &outbufbytesleft);
-	if (result == -1) mprint("iconv failed to convert UTF-8 to UTF-32. errno is %d\n", errno);
-	iconv_close(cd);
-
-	return string_utf32;
-}
-
 // string needs to be in UTF-8 encoding.
 // This function will take care of encoding.
 int spupng_write_string(struct spupng_t *sp, char *string, LLONG start_time, LLONG end_time,
-	struct encoder_ctx *context)
+			struct encoder_ctx *context)
 {
-	LLONG ms_start = start_time + context->subs_delay;
-	if (ms_start < 0)
-	{
-		dbg_print(CCX_DMT_VERBOSE, "Negative start\n");
-		return 0;
-	}
-
-	LLONG ms_end = end_time + context->subs_delay;
-
 	inc_spupng_fileindex(sp);
 	if ((sp->fppng = fopen(sp->pngfile, "wb")) == NULL)
 	{
 		fatal(CCX_COMMON_EXIT_FILE_CREATION_FAILED, "Cannot open %s: %s\n",
-			sp->pngfile, strerror(errno));
+		      sp->pngfile, strerror(errno));
 	}
 
-	uint32_t* string_utf32 = utf8_to_utf32(string);
-	if (!spupng_export_string2png(sp, string_utf32, sp->fppng))
+	if (!spupng_export_string2png(sp, string, sp->fppng))
 	{
-		free(string_utf32);
+		//free(string_utf32);
 		fatal(CCX_COMMON_EXIT_FILE_CREATION_FAILED, "Cannot write %s: %s\n",
-			sp->pngfile, strerror(errno));
+		      sp->pngfile, strerror(errno));
 	}
-	free(string_utf32);
+	//free(string_utf32);
 	fclose(sp->fppng);
-	write_sputag_open(sp, ms_start, ms_end);
+	write_sputag_open(sp, start_time, end_time);
 	write_spucomment(sp, string);
 	write_sputag_close(sp);
 	return 1;
@@ -857,7 +1048,7 @@ int spupng_write_string(struct spupng_t *sp, char *string, LLONG start_time, LLO
 
 int write_cc_subtitle_as_spupng(struct cc_subtitle *sub, struct encoder_ctx *context)
 {
-	struct spupng_t *sp = (struct spupng_t *) context->out->spupng_data;
+	struct spupng_t *sp = (struct spupng_t *)context->out->spupng_data;
 	if (!sp)
 		return -1;
 
@@ -869,22 +1060,14 @@ int write_cc_subtitle_as_spupng(struct cc_subtitle *sub, struct encoder_ctx *con
 	return 0;
 }
 
-int spupng_write_ccbuffer(struct spupng_t *sp, struct eia608_screen* data,
-	struct encoder_ctx *context)
+int spupng_write_ccbuffer(struct spupng_t *sp, struct eia608_screen *data,
+			  struct encoder_ctx *context)
 {
 
 	int row;
 	int empty_buf = 1;
 	char str[512] = "";
 
-	// Check if it has negative start.
-	LLONG ms_start = data->start_time + context->subs_delay;
-	if (ms_start < 0)
-	{
-		dbg_print(CCX_DMT_VERBOSE, "Negative start\n");
-		return 0;
-	}
-
 	// Check if it is blank page.
 	for (row = 0; row < 15; row++)
 	{
@@ -908,7 +1091,7 @@ int spupng_write_ccbuffer(struct spupng_t *sp, struct eia608_screen* data,
 
 int write_cc_buffer_as_spupng(struct eia608_screen *data, struct encoder_ctx *context)
 {
-	struct spupng_t *sp = (struct spupng_t *) context->out->spupng_data;
+	struct spupng_t *sp = (struct spupng_t *)context->out->spupng_data;
 	if (NULL != sp)
 	{
 		return spupng_write_ccbuffer(sp, data, context);
