@@ -20,48 +20,47 @@
 #include "file_buffer.h"
 
 #define STR_LEN 256u
-#define MIN(a, b) ( (a < b) ? a : b)
 
-#define CLOSED_CAP_DID  0x61
+#define CLOSED_CAP_DID 0x61
 #define CLOSED_C708_SDID 0x01
 #define CLOSED_C608_SDID 0x02
 
-#define debug(fmt, ...) ccx_common_logging.debug_ftn(CCX_DMT_PARSE, "GXF:%s:%d: "fmt , __FUNCTION__ ,__LINE__ , ##__VA_ARGS__)
-#define log(fmt, ...) ccx_common_logging.log_ftn("GXF:%d: "fmt , __LINE__ , ##__VA_ARGS__)
+#define debug(fmt, ...) ccx_common_logging.debug_ftn(CCX_DMT_PARSE, "GXF:%s:%d: " fmt, __FUNCTION__, __LINE__, ##__VA_ARGS__)
+#define log(fmt, ...) ccx_common_logging.log_ftn("GXF:%d: " fmt, __LINE__, ##__VA_ARGS__)
 
 #undef CCX_GXF_ENABLE_AD_VBI
 typedef enum
 {
-	PKT_MAP         = 0xbc,
-	PKT_MEDIA       = 0xbf,
-	PKT_EOS         = 0xfb,
-	PKT_FLT         = 0xfc,
-	PKT_UMF         = 0xfd,
+	PKT_MAP = 0xbc,
+	PKT_MEDIA = 0xbf,
+	PKT_EOS = 0xfb,
+	PKT_FLT = 0xfc,
+	PKT_UMF = 0xfd,
 } GXFPktType;
 
 typedef enum
 {
-	MAT_NAME        = 0x40,
+	MAT_NAME = 0x40,
 	MAT_FIRST_FIELD = 0x41,
-	MAT_LAST_FIELD  = 0x42,
-	MAT_MARK_IN     = 0x43,
-	MAT_MARK_OUT    = 0x44,
-	MAT_SIZE        = 0x45,
+	MAT_LAST_FIELD = 0x42,
+	MAT_MARK_IN = 0x43,
+	MAT_MARK_OUT = 0x44,
+	MAT_SIZE = 0x45,
 } GXFMatTag;
 
 typedef enum
 {
 	/* Media file name */
-	TRACK_NAME      = 0x4c,
+	TRACK_NAME = 0x4c,
 
 	/*Auxiliary Information. The exact meaning depends on the track type. */
-	TRACK_AUX       = 0x4d,
+	TRACK_AUX = 0x4d,
 
 	/* Media file system version */
-	TRACK_VER       = 0x4e,
+	TRACK_VER = 0x4e,
 
 	/* MPEG auxiliary information */
-	TRACK_MPG_AUX   = 0x4f,
+	TRACK_MPG_AUX = 0x4f,
 
 	/**
 	 * Frame rate
@@ -76,28 +75,28 @@ typedef enum
 	 * -1 = Not applicable for this track type
 	 * -2 = Not available
 	 */
-	TRACK_FPS       = 0x50,
+	TRACK_FPS = 0x50,
 
 	/**
-	 * Lines per frame
-	 * 1 = 525
-	 * 2 = 625
-	 * 4 = 1080
-	 * 5 = Reserved
-	 * 6 = 720
-	 * -1 = Not applicable
-	 * -2 = Not available
-	 */
-	 TRACK_LINES     = 0x51,
+	  * Lines per frame
+	  * 1 = 525
+	  * 2 = 625
+	  * 4 = 1080
+	  * 5 = Reserved
+	  * 6 = 720
+	  * -1 = Not applicable
+	  * -2 = Not available
+	  */
+	TRACK_LINES = 0x51,
 
 	/**
-	 * Fields per frame
-	 * 1 = Progressive
-	 * 2 = Interlaced
-	 * -1 = Not applicable
-	 * -2 = Not available
-	 */
-	 TRACK_FPF       = 0x52,
+	   * Fields per frame
+	   * 1 = Progressive
+	   * 2 = Interlaced
+	   * -1 = Not applicable
+	   * -2 = Not available
+	   */
+	TRACK_FPF = 0x52,
 
 } GXFTrackTag;
 
@@ -113,7 +112,7 @@ typedef enum
 	TRACK_TYPE_MOTION_JPEG_625 = 4,
 
 	/* SMPTE 12M time code tracks */
-	TRACK_TYPE_TIME_CODE_525  = 7,
+	TRACK_TYPE_TIME_CODE_525 = 7,
 
 	/* SMPTE 12M time code tracks */
 	TRACK_TYPE_TIME_CODE_625 = 8,
@@ -143,14 +142,14 @@ typedef enum
 	TRACK_TYPE_DV_BASED_25MB_625 = 14,
 
 	/**
-	 * A video track encoded using SMPTE 314M DV encoding at 50Mb/s
-	 * for 525/50i.
-	 */
+	  * A video track encoded using SMPTE 314M DV encoding at 50Mb/s
+	  * for 525/50i.
+	  */
 	TRACK_TYPE_DV_BASED_50MB_525 = 15,
 
 	/**
-	 * A video track encoded using SMPTE 314M DV encoding at 50Mb/s for 625/50i
-	 */
+	   * A video track encoded using SMPTE 314M DV encoding at 50Mb/s for 625/50i
+	   */
 	TRACK_TYPE_DV_BASED_50_MB_625 = 16,
 
 	/* An AC-3 audio track */
@@ -163,9 +162,9 @@ typedef enum
 	TRACK_TYPE_RESERVED = 19,
 
 	/**
-	 * A video track encoded using ISO/IEC 13818-2 (MPEG-2) main profile at main
-	 * level or high level, or 4:2:2 profile at main level or high level.
-	 */
+		* A video track encoded using ISO/IEC 13818-2 (MPEG-2) main profile at main
+		* level or high level, or 4:2:2 profile at main level or high level.
+		*/
 	TRACK_TYPE_MPEG2_HD = 20,
 
 	/* SMPTE 291M 10-bit type 2 component ancillary data. */
@@ -180,18 +179,18 @@ typedef enum
 	/* SMPTE 12M time codes For HD material. */
 	TRACK_TYPE_TIME_CODE_HD = 24,
 
-}GXFTrackType;
+} GXFTrackType;
 
 typedef enum ccx_ad_pres_format
 {
 	PRES_FORMAT_SD = 1,
 	PRES_FORMAT_HD = 2,
 
-}GXFAncDataPresFormat;
+} GXFAncDataPresFormat;
 
 enum mpeg_picture_coding
 {
-	CCX_MPC_NONE    = 0,
+	CCX_MPC_NONE = 0,
 	CCX_MPC_I_FRAME = 1,
 	CCX_MPC_P_FRAME = 2,
 	CCX_MPC_B_FRAME = 3,
@@ -199,10 +198,10 @@ enum mpeg_picture_coding
 
 enum mpeg_picture_struct
 {
-	CCX_MPS_NONE         = 0,
-	CCX_MPS_TOP_FIELD    = 1,
+	CCX_MPS_NONE = 0,
+	CCX_MPS_TOP_FIELD = 1,
 	CCX_MPS_BOTTOM_FIELD = 2,
-	CCX_MPS_FRAME        = 3,
+	CCX_MPS_FRAME = 3,
 };
 
 struct ccx_gxf_video_track
@@ -301,7 +300,7 @@ struct ccx_gxf
 
 	/**
 	 * The mark in field number shall represent the position on a playout
-         *  time line of the first field to be played from a track.
+		 *  time line of the first field to be played from a track.
 	 */
 	int32_t mark_in;
 
@@ -398,10 +397,10 @@ static int parse_material_sec(struct ccx_demuxer *demux, int len)
 
 	while (len > 2)
 	{
-		unsigned char tag     = buffered_get_byte(demux);
+		unsigned char tag = buffered_get_byte(demux);
 		unsigned char tag_len = buffered_get_byte(demux);
 		len -= 2;
-		if(len < tag_len)
+		if (len < tag_len)
 			break;
 
 		if (len < tag_len)
@@ -413,37 +412,35 @@ static int parse_material_sec(struct ccx_demuxer *demux, int len)
 		{
 			len -= tag_len;
 		}
-		switch(tag)
+		switch (tag)
 		{
-	        	case MAT_NAME:
-				result = buffered_read(demux, (unsigned char*)ctx->media_name, MIN(tag_len, STR_LEN));
+			case MAT_NAME:
+				result = buffered_read(demux, (unsigned char *)ctx->media_name, tag_len);
 				demux->past += tag_len;
-				if (result != MIN(tag_len, STR_LEN) )
+				if (result != tag_len)
 				{
 					ret = CCX_EOF;
 					goto error;
 				}
-				if (tag_len > STR_LEN)
-					buffered_skip(demux, tag_len - STR_LEN);
 				break;
-		        case MAT_FIRST_FIELD:
+			case MAT_FIRST_FIELD:
 				ctx->first_field_nb = buffered_get_be32(demux);
 				break;
-		        case MAT_LAST_FIELD:
+			case MAT_LAST_FIELD:
 				ctx->last_field_nb = buffered_get_be32(demux);
 				break;
-		        case MAT_MARK_IN:
+			case MAT_MARK_IN:
 				ctx->mark_in = buffered_get_be32(demux);
 				break;
-		        case MAT_MARK_OUT:
+			case MAT_MARK_OUT:
 				ctx->mark_out = buffered_get_be32(demux);
 				break;
-		        case MAT_SIZE:
+			case MAT_SIZE:
 				ctx->stream_size = buffered_get_be32(demux);
 				break;
 			default:
-			/* Not Supported */
-				result =  buffered_skip(demux, tag_len);
+				/* Not Supported */
+				result = buffered_skip(demux, tag_len);
 				demux->past += result;
 				break;
 		}
@@ -453,13 +450,13 @@ error:
 	result = buffered_skip(demux, len);
 	demux->past += result;
 	if (result != len)
-		ret =  CCX_EOF;
+		ret = CCX_EOF;
 	return ret;
 }
 
 static void set_track_frame_rate(struct ccx_gxf_video_track *vid_track, int8_t val)
 {
-	switch(val)
+	switch (val)
 	{
 		case 1:
 			vid_track->frame_rate.num = 60;
@@ -494,11 +491,11 @@ static void set_track_frame_rate(struct ccx_gxf_video_track *vid_track, int8_t v
 			vid_track->frame_rate.den = 1001;
 			break;
 		case -1:
-		/* Not applicable for this track type */
+			/* Not applicable for this track type */
 		case -2:
-		/*  Not available */
+			/*  Not available */
 		default:
-		/* Do nothing in case of no frame rate */
+			/* Do nothing in case of no frame rate */
 			break;
 	}
 }
@@ -511,14 +508,14 @@ static int parse_mpeg525_track_desc(struct ccx_demuxer *demux, int len)
 
 	/* Auxiliary Information */
 	// char auxi_info[8];
-	debug("Mpeg 525 %d\n",len);
+	debug("Mpeg 525 %d\n", len);
 	while (len > 2)
 	{
-		unsigned char tag     = buffered_get_byte(demux);
+		unsigned char tag = buffered_get_byte(demux);
 		unsigned char tag_len = buffered_get_byte(demux);
 		int val;
 		len -= 2;
-		if(len < tag_len)
+		if (len < tag_len)
 			break;
 
 		if (len < tag_len)
@@ -530,18 +527,16 @@ static int parse_mpeg525_track_desc(struct ccx_demuxer *demux, int len)
 		{
 			len -= tag_len;
 		}
-		switch(tag)
+		switch (tag)
 		{
 			case TRACK_NAME:
-				result = buffered_read(demux, (unsigned char*)vid_track->track_name, MIN(tag_len, STR_LEN));
+				result = buffered_read(demux, (unsigned char *)vid_track->track_name, tag_len);
 				demux->past += tag_len;
-				if (result != MIN(tag_len, STR_LEN) )
+				if (result != tag_len)
 				{
 					ret = CCX_EOF;
 					goto error;
 				}
-				if (tag_len > STR_LEN)
-					buffered_skip(demux, tag_len - STR_LEN);
 				break;
 			case TRACK_VER:
 				vid_track->fs_version = buffered_get_be32(demux);
@@ -559,8 +554,8 @@ static int parse_mpeg525_track_desc(struct ccx_demuxer *demux, int len)
 			case TRACK_AUX:
 			case TRACK_MPG_AUX:
 			default:
-			/* Not Supported */
-				result =  buffered_skip(demux, tag_len);
+				/* Not Supported */
+				result = buffered_skip(demux, tag_len);
 				demux->past += result;
 				break;
 		}
@@ -569,7 +564,7 @@ error:
 	result = buffered_skip(demux, len);
 	demux->past += result;
 	if (result != len)
-		ret =  CCX_EOF;
+		ret = CCX_EOF;
 	return ret;
 }
 
@@ -581,7 +576,7 @@ static int parse_ad_track_desc(struct ccx_demuxer *demux, int len)
 	int ret = CCX_OK;
 	/* Auxiliary Information */
 	char auxi_info[8];
-	debug("Ancillary Data %d\n",len);
+	debug("Ancillary Data %d\n", len);
 
 	if (!ctx->ad_track)
 		goto error;
@@ -590,10 +585,10 @@ static int parse_ad_track_desc(struct ccx_demuxer *demux, int len)
 
 	while (len > 2)
 	{
-		unsigned char tag     = buffered_get_byte(demux);
+		unsigned char tag = buffered_get_byte(demux);
 		unsigned char tag_len = buffered_get_byte(demux);
 		len -= 2;
-		if(len < tag_len)
+		if (len < tag_len)
 			break;
 
 		if (len < tag_len)
@@ -605,23 +600,21 @@ static int parse_ad_track_desc(struct ccx_demuxer *demux, int len)
 		{
 			len -= tag_len;
 		}
-		switch(tag)
+		switch (tag)
 		{
 			case TRACK_NAME:
-				result = buffered_read(demux, (unsigned char*)ad_track->track_name, MIN(tag_len, STR_LEN));
+				result = buffered_read(demux, (unsigned char *)ad_track->track_name, tag_len);
 				demux->past += tag_len;
-				if (result != MIN(tag_len, STR_LEN) )
+				if (result != tag_len)
 				{
 					ret = CCX_EOF;
 					goto error;
 				}
-				if (tag_len > STR_LEN)
-					buffered_skip(demux, tag_len - STR_LEN);
 				break;
 			case TRACK_AUX:
-				result = buffered_read(demux, (unsigned char*)auxi_info, 8);
+				result = buffered_read(demux, (unsigned char *)auxi_info, 8);
 				demux->past += 8;
-				if (result != 8 )
+				if (result != 8)
 				{
 					ret = CCX_EOF;
 					goto error;
@@ -633,10 +626,10 @@ static int parse_ad_track_desc(struct ccx_demuxer *demux, int len)
 				}
 				ad_track->ad_format = auxi_info[2];
 				ad_track->nb_field = auxi_info[3];
-				ad_track->field_size = *((int16_t*)(auxi_info+4));//RB16(auxi_info + 4);
-				ad_track->packet_size = *((int16_t*)(auxi_info+6)) * 256;//RB16(auxi_info + 6);
+				ad_track->field_size = *((int16_t *)(auxi_info + 4));	     //RB16(auxi_info + 4);
+				ad_track->packet_size = *((int16_t *)(auxi_info + 6)) * 256; //RB16(auxi_info + 6);
 				debug("ad_format %d nb_field %d field_size %d packet_size %d track id %d\n",
-				ad_track->ad_format, ad_track->nb_field, ad_track->field_size, ad_track->packet_size, ad_track->id);
+				      ad_track->ad_format, ad_track->nb_field, ad_track->field_size, ad_track->packet_size, ad_track->id);
 				break;
 			case TRACK_VER:
 				ad_track->fs_version = buffered_get_be32(demux);
@@ -652,8 +645,8 @@ static int parse_ad_track_desc(struct ccx_demuxer *demux, int len)
 				break;
 			case TRACK_MPG_AUX:
 			default:
-			/* Not Supported */
-				result =  buffered_skip(demux, tag_len);
+				/* Not Supported */
+				result = buffered_skip(demux, tag_len);
 				demux->past += result;
 				break;
 		}
@@ -663,7 +656,7 @@ error:
 	result = buffered_skip(demux, len);
 	demux->past += result;
 	if (result != len)
-		ret =  CCX_EOF;
+		ret = CCX_EOF;
 	return ret;
 }
 
@@ -679,8 +672,8 @@ static int parse_track_sec(struct ccx_demuxer *demux, int len, struct demuxer_da
 	while (len > 4)
 	{
 		GXFTrackType track_type = buffered_get_byte(demux);
-		unsigned char track_id   = buffered_get_byte(demux);
-		unsigned char track_len  = buffered_get_be16(demux);
+		unsigned char track_id = buffered_get_byte(demux);
+		unsigned char track_len = buffered_get_be16(demux);
 		len -= 4;
 		if (len < track_len)
 		{
@@ -688,14 +681,14 @@ static int parse_track_sec(struct ccx_demuxer *demux, int len, struct demuxer_da
 			goto error;
 		}
 
-		if ( (track_type & 0x80) != 0x80)
+		if ((track_type & 0x80) != 0x80)
 		{
 			len -= track_len;
 			result = buffered_skip(demux, track_len);
 			demux->past += result;
 			if (result != track_len)
 			{
-				ret =  CCX_EOF;
+				ret = CCX_EOF;
 				goto error;
 			}
 			else
@@ -703,14 +696,14 @@ static int parse_track_sec(struct ccx_demuxer *demux, int len, struct demuxer_da
 		}
 		track_type &= 0x7f;
 
-		if( (track_id & 0xc0) != 0xc0)
+		if ((track_id & 0xc0) != 0xc0)
 		{
 			len -= track_len;
 			result = buffered_skip(demux, track_len);
 			demux->past += result;
 			if (result != track_len)
 			{
-				ret =  CCX_EOF;
+				ret = CCX_EOF;
 				goto error;
 			}
 			else
@@ -718,7 +711,7 @@ static int parse_track_sec(struct ccx_demuxer *demux, int len, struct demuxer_da
 		}
 		track_id &= 0xcf;
 
-		if ( track_type == TRACK_TYPE_ANCILLARY_DATA)
+		if (track_type == TRACK_TYPE_ANCILLARY_DATA)
 		{
 			if (!ctx->ad_track)
 				ctx->ad_track = malloc(sizeof(struct ccx_gxf_ancillary_data_track));
@@ -735,7 +728,7 @@ static int parse_track_sec(struct ccx_demuxer *demux, int len, struct demuxer_da
 			len -= track_len;
 		}
 		/* if already have ad_track context then not parse mpeg for cc*/
-		else if ( track_type == TRACK_TYPE_MPEG2_525)
+		else if (track_type == TRACK_TYPE_MPEG2_525)
 		{
 			if (!ctx->vid_track)
 				ctx->vid_track = malloc(sizeof(struct ccx_gxf_ancillary_data_track));
@@ -756,23 +749,21 @@ static int parse_track_sec(struct ccx_demuxer *demux, int len, struct demuxer_da
 			len -= track_len;
 			if (result != track_len)
 			{
-				ret =  CCX_EOF;
+				ret = CCX_EOF;
 				goto error;
 			}
 			else
 				continue;
-
 		}
 	}
 error:
 	result = buffered_skip(demux, len);
 	demux->past += result;
 	if (result != len)
-		ret =  CCX_EOF;
+		ret = CCX_EOF;
 	return ret;
 }
 
-
 /**
  * Parse Caption Distribution Packet
  * General Syntax of cdp
@@ -788,37 +779,36 @@ error:
  * @return CCX_EINVAL if cdp data fields are not valid
  */
 
-int parse_ad_cdp (unsigned char*cdp, size_t len, struct demuxer_data *data)
+int parse_ad_cdp(unsigned char *cdp, size_t len, struct demuxer_data *data)
 {
 
 	int ret = CCX_OK;
-        uint16_t cdp_length;
-        uint16_t cdp_framerate;
-        uint16_t cc_data_present;
-        uint16_t caption_service_active;
+	uint16_t cdp_length;
+	uint16_t cdp_framerate;
+	uint16_t cc_data_present;
+	uint16_t caption_service_active;
 	uint16_t cdp_header_sequence_counter;
 
-
 	/* Do not accept packet whose length does not fit header and footer */
 	if (len < 11)
 	{
-                log("Short packet cant accommodate header and footer\n");
-                return CCX_EINVAL;
+		log("Short packet cant accommodate header and footer\n");
+		return CCX_EINVAL;
 	}
 
 	/* Verify cdp header identifier */
-	if ( (cdp[0] != 0x96) || (cdp[1] != 0x69) )
-        {
-                log(" could not find CDP identifier of 0x96 0x69\n");
-                return CCX_EINVAL;
-        }
+	if ((cdp[0] != 0x96) || (cdp[1] != 0x69))
+	{
+		log(" could not find CDP identifier of 0x96 0x69\n");
+		return CCX_EINVAL;
+	}
 	cdp += 2;
 
-        cdp_length = *cdp++;
-	if(cdp_length != len)
+	cdp_length = *cdp++;
+	if (cdp_length != len)
 	{
 		log("Cdp length is not valid\n");
-                return CCX_EINVAL;
+		return CCX_EINVAL;
 	}
 
 	/**
@@ -836,10 +826,10 @@ int parse_ad_cdp (unsigned char*cdp, size_t len, struct demuxer_data *data)
 	 * 7     |    ~59.94
 	 * 8     |     60
 	 */
-        cdp_framerate = (*cdp++ & 0xf0) >> 4 ;
-        cc_data_present = (*cdp & 0x40) >> 6;
-        caption_service_active = (*cdp++ & 0x02) >> 1;
-        cdp_header_sequence_counter = RB16(cdp);
+	cdp_framerate = (*cdp++ & 0xf0) >> 4;
+	cc_data_present = (*cdp & 0x40) >> 6;
+	caption_service_active = (*cdp++ & 0x02) >> 1;
+	cdp_header_sequence_counter = RB16(cdp);
 	cdp += 2;
 
 	debug(" CDP length: %d words\n", cdp_length);
@@ -848,7 +838,6 @@ int parse_ad_cdp (unsigned char*cdp, size_t len, struct demuxer_data *data)
 	debug("caption service active: %d\n", caption_service_active);
 	debug("header sequence counter: %d  (0x%x)\n", cdp_header_sequence_counter, cdp_header_sequence_counter);
 
-
 	/**
 	 * CDP spec does not allow to have multiple section in single packet
 	 * therefor if else if ladder does not require switch with while
@@ -856,36 +845,37 @@ int parse_ad_cdp (unsigned char*cdp, size_t len, struct demuxer_data *data)
 	if (*cdp == 0x71)
 	{
 		cdp++;
-	        log("Ignore Time code section\n");
+		log("Ignore Time code section\n");
 		return -1;
 	}
-        else if (*cdp == 0x72)
-        {
+	else if (*cdp == 0x72)
+	{
 		uint16_t cc_count;
 
 		cdp++;
 		cc_count = *cdp++ & 0x1f;
-	        debug("cc_count: %d\n", cc_count);
+		debug("cc_count: %d\n", cc_count);
 
-	        for (int i = 0; i < cc_count * 3;i++)
-	        {
-	                data->buffer[data->len+i] = cdp[i];
-        	}
-	        data->len += cc_count * 3;
-	        cdp += cc_count * 3;
-        }
+		for (int i = 0; i < cc_count * 3; i++)
+		{
+			data->buffer[data->len + i] = cdp[i];
+		}
+		data->len += cc_count * 3;
+		cdp += cc_count * 3;
+	}
 	else if (*cdp == 0x73)
 	{
 		cdp++;
-	        log("Ignore service information section\n");
+		log("Ignore service information section\n");
 		return -1;
 	}
 	else if (*cdp >= 0x75 && *cdp <= 0xEF)
 	{
-                log(" Please share sample, newer version of SMPTE-334 specification are followed\n"
-			"New section id 0x%x\n", *cdp);
+		log(" Please share sample, newer version of SMPTE-334 specification are followed\n"
+		    "New section id 0x%x\n",
+		    *cdp);
 		cdp++;
-                return -1;
+		return -1;
 	}
 
 	/* check cdp footer */
@@ -903,11 +893,9 @@ int parse_ad_cdp (unsigned char*cdp, size_t len, struct demuxer_data *data)
 		 * packet_checksum – This 8-bit field shall contain the 8-bit value necessary to make the arithmetic sum of the
 		 * entire packet (first byte of cdp_identifier to packet_checksum, inclusive) modulo 256 equal zero.
 		 */
-
 	}
 
-
-        return ret;
+	return ret;
 }
 
 /**
@@ -931,23 +919,23 @@ static int parse_ad_pyld(struct ccx_demuxer *demux, int len, struct demuxer_data
 	dc = buffered_get_le16(demux);
 	dc = (dc & 0xFF);
 
-	if(ctx->cdp_len < len/2 )
+	if (ctx->cdp_len < len / 2)
 	{
-		ctx->cdp = realloc(ctx->cdp, len/2);
-		if(ctx->cdp == NULL)
+		ctx->cdp = realloc(ctx->cdp, len / 2);
+		if (ctx->cdp == NULL)
 		{
-			log("Could not allocate buffer %d\n", len/2);
+			log("Could not allocate buffer %d\n", len / 2);
 			ret = CCX_ENOMEM;
 			goto error;
 		}
 		/* exclude did sdid bytes in cdp_len */
-		ctx->cdp_len = ( ( len-2 ) / 2 );
+		ctx->cdp_len = ((len - 2) / 2);
 	}
 
-	if( ( (d_id & 0xff) == CLOSED_CAP_DID ) && ( (sd_id & 0xff) == CLOSED_C708_SDID ) )
+	if (((d_id & 0xff) == CLOSED_CAP_DID) && ((sd_id & 0xff) == CLOSED_C708_SDID))
 	{
 		/* leaving 2 byte of checksum */
-		for (i = 0; len > 2; i++, len-=2)
+		for (i = 0; len > 2; i++, len -= 2)
 		{
 			unsigned short dat = buffered_get_le16(demux);
 			/**
@@ -966,10 +954,9 @@ static int parse_ad_pyld(struct ccx_demuxer *demux, int len, struct demuxer_data
 		parse_ad_cdp(ctx->cdp, ctx->cdp_len, data);
 		//TODO check checksum
 	}
-	else if (( (d_id & 0xff) == CLOSED_CAP_DID ) && ( (sd_id & 0xff) == CLOSED_C608_SDID ))
+	else if (((d_id & 0xff) == CLOSED_CAP_DID) && ((sd_id & 0xff) == CLOSED_C608_SDID))
 	{
 		log("Need Sample\n");
-
 	}
 	else
 	{
@@ -985,10 +972,9 @@ error:
 	result = buffered_skip(demux, len);
 	demux->past += result;
 	if (result != len)
-		ret =  CCX_EOF;
+		ret = CCX_EOF;
 
 	return ret;
-
 }
 
 /**
@@ -1012,7 +998,7 @@ static int parse_ad_vbi(struct ccx_demuxer *demux, int len, struct demuxer_data
 #endif
 	demux->past += result;
 	if (result != len)
-		ret =  CCX_EOF;
+		ret = CCX_EOF;
 	return ret;
 }
 
@@ -1028,11 +1014,11 @@ static int parse_ad_field(struct ccx_demuxer *demux, int len, struct demuxer_dat
 	len -= 4;
 	result = buffered_read(demux, (unsigned char *)tag, 4);
 	demux->past += result;
-	if(strncmp(tag, "finf", 4))
+	if (strncmp(tag, "finf", 4))
 		log("Warning: No finf tag\n");
 
 	len -= 4;
-	if(buffered_get_le32(demux) != 4)
+	if (buffered_get_le32(demux) != 4)
 		log("Warning: expected 4 acc GXF specs\n");
 
 	len -= 4;
@@ -1042,18 +1028,18 @@ static int parse_ad_field(struct ccx_demuxer *demux, int len, struct demuxer_dat
 	len -= 4;
 	result = buffered_read(demux, (unsigned char *)tag, 4);
 	demux->past += result;
-	if(strncmp(tag, "LIST", 4))
+	if (strncmp(tag, "LIST", 4))
 		log("Warning: No List tag\n");
 
 	len -= 4;
 	/* Read Byte size of the ancillary data field section vector */
-	if(buffered_get_le32(demux) != len)
+	if (buffered_get_le32(demux) != len)
 		log("Warning: Unexpected sample size (!=%d)\n", len);
 
 	len -= 4;
 	result = buffered_read(demux, (unsigned char *)tag, 4);
 	demux->past += result;
-	if(strncmp(tag, "anc ", 4))
+	if (strncmp(tag, "anc ", 4))
 		log("Warning: No anc tag\n");
 
 	while (len > 28)
@@ -1071,48 +1057,45 @@ static int parse_ad_field(struct ccx_demuxer *demux, int len, struct demuxer_dat
 		len -= 4;
 		hdr_len = buffered_get_le32(demux);
 
-
 		/**
 		 * IN GXF video there are 2 pad but if I ignore first pad tag then there is data inside it
 		 * There must be data that time but it was not there
 		 * or it may be the consequence of pad tag inserted later and data is still present
 		 */
-		if(!strncmp(tag, "pad ", 4))
+		if (!strncmp(tag, "pad ", 4))
 		{
-			if(hdr_len != len)
+			if (hdr_len != len)
 				log("Warning: expected %d got %d\n", len, hdr_len);
 
 			len -= hdr_len;
 			result = buffered_skip(demux, hdr_len);
 			demux->past += result;
 			if (result != hdr_len)
-				ret =  CCX_EOF;
+				ret = CCX_EOF;
 			continue;
-
 		}
-		else if(!strncmp(tag, "pos ", 4))
+		else if (!strncmp(tag, "pos ", 4))
 		{
-			if(hdr_len != 12)
+			if (hdr_len != 12)
 				log("Warning: expected 4 got %d\n", hdr_len);
-
 		}
 		else
 		{
 			log("Warning: Instead pos tag got %s tag\n", tag);
-			if(hdr_len != 12)
+			if (hdr_len != 12)
 				log("Warning: expected 4 got %d\n", hdr_len);
 		}
 
 		len -= 4;
-		line_nb	= buffered_get_le32(demux);
+		line_nb = buffered_get_le32(demux);
 		debug("Line nb: %d\n", line_nb);
 
 		len -= 4;
-		luma_flag= buffered_get_le32(demux);
+		luma_flag = buffered_get_le32(demux);
 		debug("luma color diff flag: %d\n", luma_flag);
 
 		len -= 4;
-		hanc_vanc_flag= buffered_get_le32(demux);
+		hanc_vanc_flag = buffered_get_le32(demux);
 		debug("hanc/vanc flag: %d\n", hanc_vanc_flag);
 
 		len -= 4;
@@ -1127,27 +1110,26 @@ static int parse_ad_field(struct ccx_demuxer *demux, int len, struct demuxer_dat
 		{
 			len -= pyld_len;
 			ret = parse_ad_pyld(demux, pyld_len, data);
-			if ( ret == CCX_EOF)
+			if (ret == CCX_EOF)
 				break;
 		}
 		else if (!strncmp(tag, "vbi ", 4))
 		{
 			len -= pyld_len;
 			ret = parse_ad_vbi(demux, pyld_len, data);
-			if ( ret == CCX_EOF)
+			if (ret == CCX_EOF)
 				break;
 		}
 		else
 		{
 			log("Warning: No pyld/vbi tag got %s tag\n", tag);
 		}
-
 	}
 
 	result = buffered_skip(demux, len);
 	demux->past += result;
 	if (result != len)
-		ret =  CCX_EOF;
+		ret = CCX_EOF;
 	return ret;
 }
 
@@ -1186,7 +1168,7 @@ static void set_data_timebase(int32_t vid_format, struct demuxer_data *data)
 {
 	debug("LOG:Format Video %d\n", vid_format);
 
-	switch(vid_format)
+	switch (vid_format)
 	{
 		case 0:
 		case 7:
@@ -1247,7 +1229,7 @@ static int parse_mpeg_packet(struct ccx_demuxer *demux, int len, struct demuxer_
 	data->len += len;
 	demux->past += result;
 	if (result != len)
-		ret =  CCX_EOF;
+		ret = CCX_EOF;
 	return ret;
 }
 
@@ -1269,31 +1251,31 @@ static int parse_ad_packet(struct ccx_demuxer *demux, int len, struct demuxer_da
 	len -= 4;
 	result = buffered_read(demux, (unsigned char *)tag, 4);
 	demux->past += result;
-	if(strncmp(tag, "RIFF", 4))
+	if (strncmp(tag, "RIFF", 4))
 		log("Warning: No RIFF header\n");
 
 	len -= 4;
-	if(buffered_get_le32(demux) != 65528)
+	if (buffered_get_le32(demux) != 65528)
 		log("Warning: ADT packet with non trivial length\n");
 
 	len -= 4;
-	result = buffered_read(demux, (unsigned char*)tag, 4);
+	result = buffered_read(demux, (unsigned char *)tag, 4);
 	demux->past += result;
-	if(strncmp(tag, "rcrd", 4))
+	if (strncmp(tag, "rcrd", 4))
 		log("Warning: No rcrd tag\n");
 
 	len -= 4;
-	result = buffered_read(demux, (unsigned char*)tag, 4);
+	result = buffered_read(demux, (unsigned char *)tag, 4);
 	demux->past += result;
-	if(strncmp(tag, "desc", 4))
+	if (strncmp(tag, "desc", 4))
 		log("Warning: No desc tag\n");
 
 	len -= 4;
-	if(buffered_get_le32(demux) != 20)
+	if (buffered_get_le32(demux) != 20)
 		log("Warning: Unexpected desc length(!=20)\n");
 
 	len -= 4;
-	if(buffered_get_le32(demux) != 2)
+	if (buffered_get_le32(demux) != 2)
 		log("Warning: Unsupported version (!=2)\n");
 
 	len -= 4;
@@ -1302,7 +1284,7 @@ static int parse_ad_packet(struct ccx_demuxer *demux, int len, struct demuxer_da
 	 * definition ancillary data and 14 for standard definition ancillary data.
 	 */
 	val = buffered_get_le32(demux);
-	if(ad_track->nb_field != val)
+	if (ad_track->nb_field != val)
 		log("Warning: Ambiguous number of fields\n");
 
 	len -= 4;
@@ -1313,12 +1295,12 @@ static int parse_ad_packet(struct ccx_demuxer *demux, int len, struct demuxer_da
 	 * standard definition video formats.
 	 */
 	val = buffered_get_le32(demux);
-	if(ad_track->field_size != val)
+	if (ad_track->field_size != val)
 		log("Warning: Ambiguous field size\n");
 
 	len -= 4;
 	/* Read byte size of the complete ancillary media packet */
-	if(buffered_get_le32(demux) != 65536)
+	if (buffered_get_le32(demux) != 65536)
 		log("Warning: Unexpected buffer size (!=65536)\n");
 
 	len -= 4;
@@ -1326,24 +1308,23 @@ static int parse_ad_packet(struct ccx_demuxer *demux, int len, struct demuxer_da
 	set_data_timebase(val, data);
 
 	len -= 4;
-	result = buffered_read(demux, (unsigned char*)tag, 4);
+	result = buffered_read(demux, (unsigned char *)tag, 4);
 	demux->past += result;
-	if(strncmp(tag, "LIST", 4))
+	if (strncmp(tag, "LIST", 4))
 		log("Warning: No LIST tag\n");
 
 	len -= 4;
 	/* Read Byte size of the ancillary data field section vector */
-	if(buffered_get_le32(demux) != len)
+	if (buffered_get_le32(demux) != len)
 		log("Warning: Unexpected field sec  size (!=%d)\n", len);
 
 	len -= 4;
-	result = buffered_read(demux, (unsigned char*)tag, 4);
+	result = buffered_read(demux, (unsigned char *)tag, 4);
 	demux->past += result;
-	if(strncmp(tag, "fld ", 4))
+	if (strncmp(tag, "fld ", 4))
 		log("Warning: No fld tag\n");
 
-
-	for ( i = 0; i <  ad_track->nb_field; i++)
+	for (i = 0; i < ad_track->nb_field; i++)
 	{
 		len -= ad_track->field_size;
 		parse_ad_field(demux, ad_track->field_size, data);
@@ -1351,7 +1332,7 @@ static int parse_ad_packet(struct ccx_demuxer *demux, int len, struct demuxer_da
 	result = buffered_skip(demux, len);
 	demux->past += result;
 	if (result != len)
-		ret =  CCX_EOF;
+		ret = CCX_EOF;
 	return ret;
 }
 
@@ -1376,7 +1357,7 @@ static int parse_ad_packet(struct ccx_demuxer *demux, int len, struct demuxer_da
  */
 static void set_mpeg_frame_desc(struct ccx_gxf_video_track *vid_track, unsigned char mpeg_frame_desc_flag)
 {
-	vid_track->p_code   = mpeg_frame_desc_flag & 0x03;
+	vid_track->p_code = mpeg_frame_desc_flag & 0x03;
 	vid_track->p_struct = (mpeg_frame_desc_flag >> 2) & 0x03;
 }
 static int parse_media(struct ccx_demuxer *demux, int len, struct demuxer_data *data)
@@ -1408,8 +1389,8 @@ static int parse_media(struct ccx_demuxer *demux, int len, struct demuxer_data *
 	 * These values shall be sent starting with the ancillary data field from the lowest number video line continuing to
 	 * higher video line numbers. Within each line the ancillary data fields shall not be reordered.
 	 */
-	unsigned char first_field_nb;
-	unsigned char last_field_nb;
+	unsigned char first_field_nb = 0;
+	unsigned char last_field_nb = 0;
 
 	/**
 	 *  see description of set_mpeg_frame_desc for details
@@ -1466,26 +1447,25 @@ static int parse_media(struct ccx_demuxer *demux, int len, struct demuxer_data *
 	valid_time_field = buffered_get_byte(demux) & 0x01;
 	len -= 1;
 
-
 	result = buffered_skip(demux, 1);
 	demux->past += result;
 	len -= 1;
 
-	debug("track number%d\n",track_nb);
-	debug("field number %d\n",media_field_nb);
+	debug("track number%d\n", track_nb);
+	debug("field number %d\n", media_field_nb);
 	debug("first field number %d\n", first_field_nb);
 	debug("last field number %d\n", last_field_nb);
 	debug("Pyld len %d\n", len);
 	debug("\n");
 
-	if( media_type == TRACK_TYPE_ANCILLARY_DATA)
+	if (media_type == TRACK_TYPE_ANCILLARY_DATA)
 	{
 		if (!ctx->ad_track)
 		{
 			goto end;
 		}
 		ad_track = ctx->ad_track;
-		if(valid_time_field)
+		if (valid_time_field)
 		{
 			data->pts = time_field - ctx->first_field_nb;
 		}
@@ -1500,16 +1480,15 @@ static int parse_media(struct ccx_demuxer *demux, int len, struct demuxer_data *
 
 		parse_ad_packet(demux, ad_track->packet_size, data);
 		len -= ad_track->packet_size;
-
 	}
-	else if(media_type == TRACK_TYPE_MPEG2_525 && !ctx->ad_track)
+	else if (media_type == TRACK_TYPE_MPEG2_525 && !ctx->ad_track)
 	{
 		if (!ctx->vid_track)
 		{
 			goto end;
 		}
 		//vid_track = ctx->vid_track;
-		if(valid_time_field)
+		if (valid_time_field)
 		{
 			data->pts = time_field - ctx->first_field_nb;
 		}
@@ -1525,7 +1504,7 @@ static int parse_media(struct ccx_demuxer *demux, int len, struct demuxer_data *
 		parse_mpeg_packet(demux, mpeg_pic_size, data);
 		len -= mpeg_pic_size;
 	}
-	else if(media_type == TRACK_TYPE_TIME_CODE_525)
+	else if (media_type == TRACK_TYPE_TIME_CODE_525)
 	{
 		/* Need SMPTE 12M to follow parse time code */
 	}
@@ -1534,7 +1513,7 @@ end:
 	result = buffered_skip(demux, len);
 	demux->past += result;
 	if (result != len)
-		ret =  CCX_EOF;
+		ret = CCX_EOF;
 	return ret;
 }
 
@@ -1549,7 +1528,7 @@ static int parse_flt(struct ccx_demuxer *ctx, int len)
 	result = buffered_skip(ctx, len);
 	ctx->past += result;
 	if (result != len)
-		ret =  CCX_EOF;
+		ret = CCX_EOF;
 	return ret;
 }
 
@@ -1564,7 +1543,7 @@ static int parse_umf(struct ccx_demuxer *ctx, int len)
 	result = buffered_skip(ctx, len);
 	ctx->past += result;
 	if (result != len)
-		ret =  CCX_EOF;
+		ret = CCX_EOF;
 	return ret;
 }
 /**
@@ -1591,24 +1570,24 @@ static int parse_map(struct ccx_demuxer *ctx, int len, struct demuxer_data *data
 
 	len -= 2;
 	material_sec_len = buffered_get_be16(ctx);
-	if(material_sec_len > len)
+	if (material_sec_len > len)
 		goto error;
 
-	len -=  material_sec_len;
+	len -= material_sec_len;
 	parse_material_sec(ctx, material_sec_len);
 
 	len -= 2;
 	track_sec_len = buffered_get_be16(ctx);
-	if(track_sec_len > len)
+	if (track_sec_len > len)
 		goto error;
 
-	len -=  track_sec_len;
+	len -= track_sec_len;
 	parse_track_sec(ctx, track_sec_len, data);
 error:
 	result = buffered_skip(ctx, len);
 	ctx->past += result;
 	if (result != len)
-		ret =  CCX_EOF;
+		ret = CCX_EOF;
 	return ret;
 }
 
@@ -1631,7 +1610,7 @@ static int read_packet(struct ccx_demuxer *ctx, struct demuxer_data *data)
 
 	ret = parse_packet_header(ctx, &type, &len);
 
-	switch(type)
+	switch (type)
 	{
 		case PKT_MAP:
 			debug("pkt type Map %d\n", len);
@@ -1644,7 +1623,7 @@ static int read_packet(struct ccx_demuxer *ctx, struct demuxer_data *data)
 			ret = CCX_EOF;
 			break;
 		case PKT_FLT:
-			debug("pkt type FLT %d\n",len);
+			debug("pkt type FLT %d\n", len);
 			ret = parse_flt(ctx, len);
 			break;
 		case PKT_UMF:
@@ -1657,7 +1636,6 @@ static int read_packet(struct ccx_demuxer *ctx, struct demuxer_data *data)
 			ctx->past += result;
 			if (result != len || !len)
 				ret = CCX_EOF;
-
 	}
 
 	return ret;
@@ -1676,13 +1654,12 @@ static int read_packet(struct ccx_demuxer *ctx, struct demuxer_data *data)
 int ccx_gxf_probe(unsigned char *buf, int len)
 {
 	static const uint8_t startcode[] = {0, 0, 0, 0, 1, 0xbc};
-        if (len < sizeof(startcode))
+	if (len < sizeof(startcode))
 		return CCX_FALSE;
 
-	if (!memcmp(buf, startcode, sizeof(startcode)) )
+	if (!memcmp(buf, startcode, sizeof(startcode)))
 		return CCX_TRUE;
 	return CCX_FALSE;
-
 }
 
 int ccx_gxf_get_more_data(struct lib_ccx_ctx *ctx, struct demuxer_data **ppdata)
@@ -1690,10 +1667,10 @@ int ccx_gxf_get_more_data(struct lib_ccx_ctx *ctx, struct demuxer_data **ppdata)
 	int ret;
 	struct demuxer_data *data;
 
-	if(!*ppdata)
+	if (!*ppdata)
 	{
 		*ppdata = alloc_demuxer_data();
-		if(!*ppdata)
+		if (!*ppdata)
 			return -1;
 
 		data = *ppdata;
@@ -1701,7 +1678,7 @@ int ccx_gxf_get_more_data(struct lib_ccx_ctx *ctx, struct demuxer_data **ppdata)
 		//Complex GXF do have multiple program
 		data->program_number = 1;
 		data->stream_pid = 1;
-		data->codec  = CCX_CODEC_ATSC_CC;
+		data->codec = CCX_CODEC_ATSC_CC;
 	}
 	else
 	{
@@ -1715,9 +1692,9 @@ int ccx_gxf_get_more_data(struct lib_ccx_ctx *ctx, struct demuxer_data **ppdata)
 struct ccx_gxf *ccx_gxf_init(struct ccx_demuxer *arg)
 {
 	struct ccx_gxf *ctx = (struct ccx_gxf *)malloc(sizeof(struct ccx_gxf));
-	if(!ctx)
+	if (!ctx)
 	{
-		log ("Unable to allocate Gxf context\n");
+		log("Unable to allocate Gxf context\n");
 		return NULL;
 	}
 	memset(ctx, 0, sizeof(struct ccx_gxf));
