@@ -1,7 +1,6 @@
 #ifdef ENABLE_HARDSUBX
+#include <leptonica/allheaders.h>
 #include "hardsubx.h"
-#include "tesseract/capi.h"
-#include "allheaders.h"
 #include "ocr.h"
 #include "utility.h"
 
@@ -15,74 +14,72 @@ int hardsubx_process_data(struct lib_hardsubx_ctx *ctx)
 {
 	// Get the required media attributes and initialize structures
 	av_register_all();
-	
-	if(avformat_open_input(&ctx->format_ctx, ctx->inputfile[0], NULL, NULL)!=0)
+
+	if (avformat_open_input(&ctx->format_ctx, ctx->inputfile[0], NULL, NULL) != 0)
 	{
-		fatal (EXIT_READ_ERROR, "Error reading input file!\n");
+		fatal(EXIT_READ_ERROR, "Error reading input file!\n");
 	}
 
-	if(avformat_find_stream_info(ctx->format_ctx, NULL)<0)
+	if (avformat_find_stream_info(ctx->format_ctx, NULL) < 0)
 	{
-		fatal (EXIT_READ_ERROR, "Error reading input stream!\n");
+		fatal(EXIT_READ_ERROR, "Error reading input stream!\n");
 	}
 
 	// Important call in order to determine media information using ffmpeg
 	// TODO: Handle multiple inputs
 	av_dump_format(ctx->format_ctx, 0, ctx->inputfile[0], 0);
-	
 
 	ctx->video_stream_id = -1;
-	for(int i = 0; i < ctx->format_ctx->nb_streams; i++)
+	for (int i = 0; i < ctx->format_ctx->nb_streams; i++)
 	{
-		if(ctx->format_ctx->streams[i]->codec->codec_type == AVMEDIA_TYPE_VIDEO)
+		if (ctx->format_ctx->streams[i]->codec->codec_type == AVMEDIA_TYPE_VIDEO)
 		{
 			ctx->video_stream_id = i;
 			break;
 		}
 	}
-	if(ctx->video_stream_id == -1)
+	if (ctx->video_stream_id == -1)
 	{
-		fatal (EXIT_READ_ERROR, "Video Stream not found!\n");
+		fatal(EXIT_READ_ERROR, "Video Stream not found!\n");
 	}
 
 	ctx->codec_ctx = ctx->format_ctx->streams[ctx->video_stream_id]->codec;
 	ctx->codec = avcodec_find_decoder(ctx->codec_ctx->codec_id);
-	if(ctx->codec == NULL)
+	if (ctx->codec == NULL)
 	{
-		fatal (EXIT_READ_ERROR, "Input codec is not supported!\n");
+		fatal(EXIT_READ_ERROR, "Input codec is not supported!\n");
 	}
 
-	if(avcodec_open2(ctx->codec_ctx, ctx->codec, &ctx->options_dict) < 0)
+	if (avcodec_open2(ctx->codec_ctx, ctx->codec, &ctx->options_dict) < 0)
 	{
-		fatal (EXIT_READ_ERROR, "Error opening input codec!\n");
+		fatal(EXIT_READ_ERROR, "Error opening input codec!\n");
 	}
 
 	ctx->frame = av_frame_alloc();
 	ctx->rgb_frame = av_frame_alloc();
-	if(!ctx->frame || !ctx->rgb_frame)
+	if (!ctx->frame || !ctx->rgb_frame)
 	{
 		fatal(EXIT_NOT_ENOUGH_MEMORY, "Not enough memory to initialize frame!");
 	}
 
 	int frame_bytes = av_image_get_buffer_size(AV_PIX_FMT_RGB24, ctx->codec_ctx->width, ctx->codec_ctx->height, 16);
-	ctx->rgb_buffer = (uint8_t *)av_malloc(frame_bytes*sizeof(uint8_t));
-	
+	ctx->rgb_buffer = (uint8_t *)av_malloc(frame_bytes * sizeof(uint8_t));
+
 	ctx->sws_ctx = sws_getContext(
-			ctx->codec_ctx->width,
-			ctx->codec_ctx->height,
-			ctx->codec_ctx->pix_fmt,
-			ctx->codec_ctx->width,
-			ctx->codec_ctx->height,
-			AV_PIX_FMT_RGB24,
-			SWS_BILINEAR,
-			NULL,NULL,NULL
-		);
+	    ctx->codec_ctx->width,
+	    ctx->codec_ctx->height,
+	    ctx->codec_ctx->pix_fmt,
+	    ctx->codec_ctx->width,
+	    ctx->codec_ctx->height,
+	    AV_PIX_FMT_RGB24,
+	    SWS_BILINEAR,
+	    NULL, NULL, NULL);
 
 	av_image_fill_arrays(ctx->rgb_frame->data, ctx->rgb_frame->linesize, ctx->rgb_buffer, AV_PIX_FMT_RGB24, ctx->codec_ctx->width, ctx->codec_ctx->height, 1);
 
 	// int frame_bytes = av_image_get_buffer_size(AV_PIX_FMT_RGB24, 1280, 720, 16);
 	// ctx->rgb_buffer = (uint8_t *)av_malloc(frame_bytes*sizeof(uint8_t));
-	
+
 	// ctx->sws_ctx = sws_getContext(
 	// 		ctx->codec_ctx->width,
 	// 		ctx->codec_ctx->height,
@@ -99,10 +96,10 @@ int hardsubx_process_data(struct lib_hardsubx_ctx *ctx)
 	// Pass on the processing context to the appropriate functions
 	struct encoder_ctx *enc_ctx;
 	enc_ctx = init_encoder(&ccx_options.enc_cfg);
-	
+
 	mprint("Beginning burned-in subtitle detection...\n");
 
-	if(ctx->tickertext)
+	if (ctx->tickertext)
 		hardsubx_process_frames_tickertext(ctx, enc_ctx);
 	else
 		hardsubx_process_frames_linear(ctx, enc_ctx);
@@ -110,10 +107,12 @@ int hardsubx_process_data(struct lib_hardsubx_ctx *ctx)
 	dinit_encoder(&enc_ctx, 0); //TODO: Replace 0 with end timestamp
 
 	// Free the allocated memory for frame processing
-    av_free(ctx->rgb_buffer);
-    if(ctx->frame) av_frame_free(&ctx->frame);
-    if(ctx->rgb_frame) av_frame_free(&ctx->rgb_frame);
-    avcodec_close(ctx->codec_ctx);
+	av_free(ctx->rgb_buffer);
+	if (ctx->frame)
+		av_frame_free(&ctx->frame);
+	if (ctx->rgb_frame)
+		av_frame_free(&ctx->rgb_frame);
+	avcodec_close(ctx->codec_ctx);
 	avformat_close_input(&ctx->format_ctx);
 }
 
@@ -122,7 +121,7 @@ void _hardsubx_params_dump(struct ccx_s_options *options, struct lib_hardsubx_ct
 	// Print the relevant passed parameters onto the screen
 	mprint("Input : %s\n", ctx->inputfile[0]);
 
-	switch(ctx->subcolor)
+	switch (ctx->subcolor)
 	{
 		case HARDSUBX_COLOR_WHITE:
 			mprint("Subtitle Color : White\n");
@@ -146,13 +145,13 @@ void _hardsubx_params_dump(struct ccx_s_options *options, struct lib_hardsubx_ct
 			mprint("Subtitle Color : Red\n");
 			break;
 		case HARDSUBX_COLOR_CUSTOM:
-			mprint("Subtitle Color : Custom Hue - %0.2f\n",ctx->hue);
+			mprint("Subtitle Color : Custom Hue - %0.2f\n", ctx->hue);
 			break;
 		default:
-			fatal(EXIT_MALFORMED_PARAMETER,"Invalid Subtitle Color");
+			fatal(EXIT_MALFORMED_PARAMETER, "Invalid Subtitle Color");
 	}
 
-	switch(ctx->ocr_mode)
+	switch (ctx->ocr_mode)
 	{
 		case HARDSUBX_OCRMODE_WORD:
 			mprint("OCR Mode : Word-wise\n");
@@ -164,31 +163,31 @@ void _hardsubx_params_dump(struct ccx_s_options *options, struct lib_hardsubx_ct
 			mprint("OCR Mode : Frame-wise (simple)\n");
 			break;
 		default:
-			fatal(EXIT_MALFORMED_PARAMETER,"Invalid OCR Mode");
+			fatal(EXIT_MALFORMED_PARAMETER, "Invalid OCR Mode");
 	}
 
-	if(ctx->conf_thresh > 0)
+	if (ctx->conf_thresh > 0)
 	{
-		mprint("OCR Confidence Threshold : %.2f\n",ctx->conf_thresh);
+		mprint("OCR Confidence Threshold : %.2f\n", ctx->conf_thresh);
 	}
 	else
 	{
-		mprint("OCR Confidence Threshold : %.2f (Default)\n",ctx->conf_thresh);
+		mprint("OCR Confidence Threshold : %.2f (Default)\n", ctx->conf_thresh);
 	}
 
-	if(ctx->subcolor == HARDSUBX_COLOR_WHITE)
+	if (ctx->subcolor == HARDSUBX_COLOR_WHITE)
 	{
-		if(ctx->lum_thresh != 95.0)
+		if (ctx->lum_thresh != 95.0)
 		{
-			mprint("OCR Luminance Threshold : %.2f\n",ctx->lum_thresh);
+			mprint("OCR Luminance Threshold : %.2f\n", ctx->lum_thresh);
 		}
 		else
 		{
-			mprint("OCR Luminance Threshold : %.2f (Default)\n",ctx->lum_thresh);
+			mprint("OCR Luminance Threshold : %.2f (Default)\n", ctx->lum_thresh);
 		}
 	}
 
-	if(ctx->detect_italics == 1)
+	if (ctx->detect_italics == 1)
 	{
 		mprint("OCR Italic Detection : On\n");
 	}
@@ -197,78 +196,81 @@ void _hardsubx_params_dump(struct ccx_s_options *options, struct lib_hardsubx_ct
 		mprint("OCR Italic Detection : Off\n");
 	}
 
-	if(ctx->min_sub_duration == 0.5)
+	if (ctx->min_sub_duration == 0.5)
 	{
 		mprint("Minimum subtitle duration : 0.5 seconds (Default)\n");
 	}
 	else
 	{
-		mprint("Minimum subtitle duration : %0.2f seconds\n",ctx->min_sub_duration);
+		mprint("Minimum subtitle duration : %0.2f seconds\n", ctx->min_sub_duration);
 	}
 
 	mprint("FFMpeg Media Information:-\n");
-
 }
 
-struct lib_hardsubx_ctx* _init_hardsubx(struct ccx_s_options *options)
+struct lib_hardsubx_ctx *_init_hardsubx(struct ccx_s_options *options)
 {
 	// Initialize HardsubX data structures
 	struct lib_hardsubx_ctx *ctx = (struct lib_hardsubx_ctx *)malloc(sizeof(struct lib_hardsubx_ctx));
-	if(!ctx)
+	if (!ctx)
 		fatal(EXIT_NOT_ENOUGH_MEMORY, "Not enough memory for HardsubX data structures.");
 	memset(ctx, 0, sizeof(struct lib_hardsubx_ctx));
-	
+
 	ctx->tess_handle = TessBaseAPICreate();
-	char* pars_vec = strdup("debug_file");
-	char* pars_values = strdup("/dev/null");
-    char* tessdata_path = NULL;
+	char *pars_vec = strdup("debug_file");
+	char *pars_values = strdup("/dev/null");
+	char *tessdata_path = NULL;
 
-    char* lang = options->ocrlang;
-    if(!lang) lang = "eng"; // English is default language
+	char *lang = options->ocrlang;
+	if (!lang)
+		lang = "eng"; // English is default language
 
-    tessdata_path = probe_tessdata_location_string(lang);
-    if(!tessdata_path)
-    {
-        if (strcmp(lang, "eng") == 0)
-        {
-            mprint("eng.traineddata not found! No Switching Possible\n");
-            return NULL;
-        }
-        mprint("%s.traineddata not found! Switching to English\n", lang);
-        lang = "eng";
-        tessdata_path = probe_tessdata_location_string("eng");
-        if(!tessdata_path)
-        {
-            mprint("eng.traineddata not found! No Switching Possible\n");
-            return NULL;
-        }
-    }
+	tessdata_path = probe_tessdata_location(lang);
+	if (!tessdata_path)
+	{
+		if (strcmp(lang, "eng") == 0)
+		{
+			mprint("eng.traineddata not found! No Switching Possible\n");
+			return NULL;
+		}
+		mprint("%s.traineddata not found! Switching to English\n", lang);
+		lang = "eng";
+		tessdata_path = probe_tessdata_location("eng");
+		if (!tessdata_path)
+		{
+			mprint("eng.traineddata not found! No Switching Possible\n");
+			return NULL;
+		}
+	}
 
-    int ret = -1;
+	int ret = -1;
 
-    if (!strncmp("4.", TessVersion(), 2))
-    {
-        char tess_path [1024];
-        snprintf(tess_path, 1024, "%s%s%s", tessdata_path, "/", "tessdata");
-        //ccx_options.ocr_oem are deprecated and only supported mode is OEM_LSTM_ONLY
-        ret = TessBaseAPIInit4(ctx->tess_handle, tess_path, lang, 1, NULL, 0, &pars_vec,
-            &pars_values, 1, false);
-    }
-    else
-    {
-        ret = TessBaseAPIInit4(ctx->tess_handle, tessdata_path, lang, ccx_options.ocr_oem, NULL, 0, &pars_vec,
-            &pars_values, 1, false);
-    }
+	if (!strncmp("4.", TessVersion(), 2))
+	{
+		char tess_path[1024];
+		if (ccx_options.ocr_oem < 0)
+			ccx_options.ocr_oem = 1;
+		snprintf(tess_path, 1024, "%s%s%s", tessdata_path, "/", "tessdata");
+		ret = TessBaseAPIInit4(ctx->tess_handle, tess_path, lang, ccx_options.ocr_oem, NULL, 0, &pars_vec,
+				       &pars_values, 1, false);
+	}
+	else
+	{
+		if (ccx_options.ocr_oem < 0)
+			ccx_options.ocr_oem = 0;
+		ret = TessBaseAPIInit4(ctx->tess_handle, tessdata_path, lang, ccx_options.ocr_oem, NULL, 0, &pars_vec,
+				       &pars_values, 1, false);
+	}
 
 	free(pars_vec);
 	free(pars_values);
-	if(ret != 0)
+	if (ret != 0)
 	{
 		fatal(EXIT_NOT_ENOUGH_MEMORY, "Not enough memory to initialize Tesseract");
 	}
 
 	//Initialize attributes common to lib_ccx context
-	ctx->basefilename = get_basename(options->output_filename);//TODO: Check validity, add stdin, network
+	ctx->basefilename = get_basename(options->output_filename); //TODO: Check validity, add stdin, network
 	ctx->current_file = -1;
 	ctx->inputfile = options->inputfile;
 	ctx->num_input_files = options->num_input_files;
@@ -291,7 +293,7 @@ struct lib_hardsubx_ctx* _init_hardsubx(struct ccx_s_options *options)
 
 	//Initialize subtitle structure memory
 	ctx->dec_sub = (struct cc_subtitle *)malloc(sizeof(struct cc_subtitle));
-	memset (ctx->dec_sub, 0,sizeof(struct cc_subtitle));
+	memset(ctx->dec_sub, 0, sizeof(struct cc_subtitle));
 
 	return ctx;
 }
@@ -331,8 +333,8 @@ void hardsubx(struct ccx_s_options *options)
 
 	// Show statistics (time taken, frames processed, mode etc)
 	time(&end);
-	long processing_time=(long) (end-start);
-	mprint ("\rDone, processing time = %ld seconds\n", processing_time);
+	long processing_time = (long)(end - start);
+	mprint("\rDone, processing time = %ld seconds\n", processing_time);
 
 	// Free all allocated memory for the data structures
 	_dinit_hardsubx(&ctx);
