@@ -11,24 +11,26 @@
 #define DEBUG_OUT 0
 
 /* Protocol constants: */
-#define INT_LEN         10
-#define OK              1
-#define PASSWORD        2
-#define BIN_MODE        3
-#define CC_DESC         4
-#define BIN_HEADER      5
-#define BIN_DATA        6
-#define EPG_DATA        7
-#pragma warning( suppress : 4005)
-#define ERROR           51
+#define INT_LEN 10
+#define OK 1
+#define PASSWORD 2
+#define BIN_MODE 3
+#define CC_DESC 4
+#define BIN_HEADER 5
+#define BIN_DATA 6
+#define EPG_DATA 7
+#ifdef _MSC_VER
+#pragma warning(suppress : 4005)
+#endif
+#define ERROR 51
 #define UNKNOWN_COMMAND 52
-#define WRONG_PASSWORD  53
-#define CONN_LIMIT      54
-#define PING            55
+#define WRONG_PASSWORD 53
+#define CONN_LIMIT 54
+#define PING 55
 
 /* #include <time.h> */
 
-#define DFT_PORT "2048" /* Default port for server and client */
+#define DFT_PORT "2048"	       /* Default port for server and client */
 #define WRONG_PASSWORD_DELAY 2 /* Seconds */
 #define BUFFER_SIZE 50
 #define NO_RESPONCE_INTERVAL 20
@@ -71,7 +73,7 @@ ssize_t writen(int fd, const void *vptr, size_t n);
 ssize_t write_byte(int fd, char status);
 ssize_t read_byte(int fd, char *status);
 
-void init_sockets (void);
+void init_sockets(void);
 
 #if DEBUG_OUT
 void pr_command(char c);
@@ -171,10 +173,12 @@ void net_check_conn()
 	if (last_ping == 0)
 		last_ping = now;
 
-	do {
+	do
+	{
 		c = 0;
 		rc = read_byte(srv_sd, &c);
-		if (c == PING) {
+		if (c == PING)
+		{
 #if DEBUG_OUT
 			fprintf(stderr, "[S] Received PING\n");
 #endif
@@ -185,8 +189,8 @@ void net_check_conn()
 	if (now - last_ping > NO_RESPONCE_INTERVAL)
 	{
 		fprintf(stderr,
-				"[S] No PING received from the server in %u sec, reconnecting\n",
-				NO_RESPONCE_INTERVAL);
+			"[S] No PING received from the server in %u sec, reconnecting\n",
+			NO_RESPONCE_INTERVAL);
 		close(srv_sd);
 		srv_sd = -1;
 
@@ -210,13 +214,12 @@ void net_check_conn()
 }
 
 void net_send_epg(
-		const char *start,
-		const char *stop,
-		const char *title,
-		const char *desc,
-		const char *lang,
-		const char *category
-		)
+    const char *start,
+    const char *stop,
+    const char *title,
+    const char *desc,
+    const char *lang,
+    const char *category)
 {
 	size_t st;
 	size_t sp;
@@ -246,17 +249,17 @@ void net_send_epg(
 	if (desc != NULL)
 		d += strlen(desc);
 
-    l = 1;
-    if (lang != NULL)
-        l += strlen(lang);
+	l = 1;
+	if (lang != NULL)
+		l += strlen(lang);
 
-    c = 1;
-    if (category != NULL)
-        c += strlen(category);
+	c = 1;
+	if (category != NULL)
+		c += strlen(category);
 
-    len = st + sp + t + d + l + c;
+	len = st + sp + t + d + l + c;
 
-	epg = (char *) calloc(len, sizeof(char));
+	epg = (char *)calloc(len, sizeof(char));
 	if (NULL == epg)
 		return;
 
@@ -276,13 +279,13 @@ void net_send_epg(
 		memcpy(end, desc, d);
 	end += d;
 
-    if (lang != NULL)
-        memcpy(end, lang, l);
-    end += l;
+	if (lang != NULL)
+		memcpy(end, lang, l);
+	end += l;
 
-    if (category != NULL)
-        memcpy(end, category, c);
-    end += c;
+	if (category != NULL)
+		memcpy(end, category, c);
+	end += c;
 
 #if DEBUG_OUT
 	fprintf(stderr, "[C] Sending EPG: %u bytes\n", len);
@@ -291,7 +294,7 @@ void net_send_epg(
 	if (write_block(srv_sd, EPG_DATA, epg, len) <= 0)
 		fprintf(stderr, "Can't send EPG data\n");
 
-    	free(epg);
+	free(epg);
 
 	return;
 }
@@ -323,8 +326,7 @@ int net_tcp_read(int socket, void *buffer, size_t length)
 
 		if ((rc = read_block(socket, &c, buffer, &l)) <= 0)
 			return rc;
-	}
-	while (c != BIN_DATA && c != BIN_HEADER);
+	} while (c != BIN_DATA && c != BIN_HEADER);
 
 	return l;
 }
@@ -335,7 +337,8 @@ int net_udp_read(int socket, void *buffer, size_t length, const char *src_str, c
 	assert(length > 0);
 
 	int i;
-	char ip[50] = "";
+#ifdef _WIN32
+	char ip[INET_ADDRSTRLEN];
 	struct sockaddr_in source_addr;
 	socklen_t len = sizeof(source_addr);
 	/* Get address of host to check for udp network mutlicasting */
@@ -349,24 +352,24 @@ int net_udp_read(int socket, void *buffer, size_t length, const char *src_str, c
 	{
 		addr = INADDR_ANY;
 	}
-	#ifdef _WIN32
-	if (IN_MULTICAST(addr) && src_str != NULL)						  					/* We check if the case is of source multicast and we are in windowsOS */
+	if (IN_MULTICAST(addr) && src_str != NULL) /* We check if the case is of source multicast and we are in windowsOS */
 	{
-		do {
-			i = recvfrom(socket, (char *) buffer, length, 0, (struct sockaddr*)&source_addr, &len); /* peek at the data*/
-			inet_ntop(AF_INET, &(source_addr.sin_addr), ip, 50);
-		} while (strcmp(ip, src_str)!=0);												/* Loop till we find intended source */
+		do
+		{
+			i = recvfrom(socket, (char *)buffer, length, 0, (struct sockaddr *)&source_addr, &len); /* peek at the data*/
+			memset(ip, 0, sizeof(char) * INET_ADDRSTRLEN);
+			memcpy(ip, inet_ntoa(source_addr.sin_addr), sizeof(ip));
+		} while (strcmp(ip, src_str) != 0); /* Loop till we find intended source */
 	}
 	else
-		i = recvfrom(socket, (char *) buffer, length, 0, NULL, NULL); 								/*read normally if not source mutlicast case*/
-	#else
-	i = recvfrom(socket, (char *) buffer, length, 0, NULL, NULL); 									/*read normally if not windows*/
-	#endif
+		i = recvfrom(socket, (char *)buffer, length, 0, NULL, NULL); /*read normally if not source mutlicast case*/
+#else
+	i = recvfrom(socket, (char *)buffer, length, 0, NULL, NULL); /*read normally if not windows*/
+#endif
 
 	return i;
 }
 
-
 /*
  * command | length        | data         | \r\n
  * 1 byte  | INT_LEN bytes | length bytes | 2 bytes
@@ -409,7 +412,7 @@ ssize_t write_block(int fd, char command, const char *buf, size_t buf_len)
 	{
 		if ((rc = writen(fd, buf, buf_len)) < 0)
 			return -1;
-		else if (rc != (int) buf_len)
+		else if (rc != (int)buf_len)
 			return 0;
 		nwritten += rc;
 	}
@@ -459,7 +462,8 @@ int tcp_connect(const char *host, const char *port)
 
 	struct addrinfo *ai;
 	int rc = getaddrinfo(host, port, &hints, &ai);
-	if (rc != 0) {
+	if (rc != 0)
+	{
 		mprint("getaddrinfo() error: %s\n", gai_strerror(rc));
 		return -1;
 	}
@@ -468,10 +472,12 @@ int tcp_connect(const char *host, const char *port)
 	int sockfd;
 
 	/* Try each address until we successfully connect */
-	for (p = ai; p != NULL; p = p->ai_next) {
+	for (p = ai; p != NULL; p = p->ai_next)
+	{
 		sockfd = socket(p->ai_family, SOCK_STREAM, p->ai_protocol);
 
-		if (-1 == sockfd) {
+		if (-1 == sockfd)
+		{
 #if _WIN32
 			wprintf(L"socket() error: %ld\n", WSAGetLastError());
 #else
@@ -538,7 +544,7 @@ int start_tcp_srv(const char *port, const char *pwd)
 			clilen = sizeof(struct sockaddr_in);
 		else
 			clilen = sizeof(struct sockaddr_in6);
-		struct sockaddr *cliaddr = (struct sockaddr *) malloc(clilen);
+		struct sockaddr *cliaddr = (struct sockaddr *)malloc(clilen);
 		if (NULL == cliaddr)
 			fatal(EXIT_FAILURE, "In start_tcp_srv: Out of memory for client address. malloc() error: %s", strerror(errno));
 
@@ -546,7 +552,7 @@ int start_tcp_srv(const char *port, const char *pwd)
 		{
 			if (EINTR == errno) /* TODO not necessary */
 			{
-                		free(cliaddr);
+				free(cliaddr);
 				continue;
 			}
 			else
@@ -564,7 +570,7 @@ int start_tcp_srv(const char *port, const char *pwd)
 		char serv[NI_MAXSERV];
 		int rc;
 		if ((rc = getnameinfo(cliaddr, clilen,
-						host, sizeof(host), serv, sizeof(serv), 0)) != 0)
+				      host, sizeof(host), serv, sizeof(serv), 0)) != 0)
 		{
 			mprint("getnameinfo() error: %s\n", gai_strerror(rc));
 		}
@@ -610,7 +616,8 @@ int check_password(int fd, const char *pwd)
 	if (pwd == NULL)
 		return 1;
 
-	if (c == PASSWORD && strcmp(pwd, buf) == 0) {
+	if (c == PASSWORD && strcmp(pwd, buf) == 0)
+	{
 		return 1;
 	}
 
@@ -668,7 +675,7 @@ int tcp_bind(const char *port, int *family)
 		if (AF_INET6 == p->ai_family)
 		{
 			int no = 0;
-			if (setsockopt(sockfd, IPPROTO_IPV6, IPV6_V6ONLY, (char*)&no, sizeof(no)) < 0)
+			if (setsockopt(sockfd, IPPROTO_IPV6, IPV6_V6ONLY, (char *)&no, sizeof(no)) < 0)
 			{
 #if _WIN32
 				wprintf(L"setsockopt() error: %ld\n", WSAGetLastError());
@@ -735,7 +742,7 @@ ssize_t read_block(int fd, char *command, char *buf, size_t *buf_len)
 
 	if ((rc = readn(fd, command, 1)) < 0)
 		return -1;
-	else if ((size_t) rc != 1)
+	else if ((size_t)rc != 1)
 		return 0;
 	nread += rc;
 
@@ -766,20 +773,20 @@ ssize_t read_block(int fd, char *command, char *buf, size_t *buf_len)
 		{
 			ign_bytes = len - *buf_len;
 			mprint("read_block() warning: Buffer overflow, ignoring %d bytes\n",
-					ign_bytes);
+			       ign_bytes);
 			len = *buf_len;
 		}
 
 		if ((rc = readn(fd, buf, len)) < 0)
 			return -1;
-		else if ((size_t) rc != len)
+		else if ((size_t)rc != len)
 			return 0;
 		nread += rc;
 		*buf_len = len;
 
 		if ((rc = readn(fd, 0, ign_bytes)) < 0)
 			return -1;
-		else if ((size_t) rc != ign_bytes)
+		else if ((size_t)rc != ign_bytes)
 			return 0;
 		nread += rc;
 
@@ -795,7 +802,7 @@ ssize_t read_block(int fd, char *command, char *buf, size_t *buf_len)
 	char end[2] = {0};
 	if ((rc = readn(fd, end, sizeof(end))) < 0)
 		return -1;
-	else if ((size_t) rc != sizeof(end))
+	else if ((size_t)rc != sizeof(end))
 		return 0;
 	nread += rc;
 
@@ -815,11 +822,10 @@ ssize_t read_block(int fd, char *command, char *buf, size_t *buf_len)
 	return nread;
 }
 
-
 #if DEBUG_OUT
 void pr_command(char c)
 {
-	switch(c)
+	switch (c)
 	{
 		case OK:
 			fprintf(stderr, "OK");
@@ -855,7 +861,7 @@ void pr_command(char c)
 			fprintf(stderr, "PING");
 			break;
 		default:
-			fprintf(stderr, "UNKNOWN (%d)", (int) c);
+			fprintf(stderr, "UNKNOWN (%d)", (int)c);
 			break;
 	}
 }
@@ -872,13 +878,14 @@ ssize_t readn(int fd, void *vptr, size_t n)
 	nleft = n;
 	while (nleft > 0)
 	{
-		if (NULL == vptr) {
+		if (NULL == vptr)
+		{
 			char c;
 			nread = recv(fd, &c, 1, 0);
 		}
 		else
 		{
-			nread = recv(fd, (void*)ptr, nleft, 0);
+			nread = recv(fd, (void *)ptr, nleft, 0);
 		}
 
 		if (nread < 0)
@@ -976,12 +983,12 @@ int start_upd_srv(const char *src_str, const char *addr_str, unsigned port)
 		if (NULL == host)
 		{
 			fatal(EXIT_MALFORMED_PARAMETER, "Cannot look up udp network address: %s\n",
-					src_str);
+			      src_str);
 		}
 		else if (host->h_addrtype != AF_INET)
 		{
 			fatal(EXIT_MALFORMED_PARAMETER, "No support for non-IPv4 network addresses: %s\n",
-					src_str);
+			      src_str);
 		}
 
 		src = ntohl(((struct in_addr *)host->h_addr_list[0])->s_addr);
@@ -994,12 +1001,12 @@ int start_upd_srv(const char *src_str, const char *addr_str, unsigned port)
 		if (NULL == host)
 		{
 			fatal(EXIT_MALFORMED_PARAMETER, "Cannot look up udp network address: %s\n",
-					addr_str);
+			      addr_str);
 		}
 		else if (host->h_addrtype != AF_INET)
 		{
 			fatal(EXIT_MALFORMED_PARAMETER, "No support for non-IPv4 network addresses: %s\n",
-					addr_str);
+			      addr_str);
 		}
 
 		addr = ntohl(((struct in_addr *)host->h_addr_list[0])->s_addr);
@@ -1010,7 +1017,8 @@ int start_upd_srv(const char *src_str, const char *addr_str, unsigned port)
 	}
 
 	int sockfd = socket(AF_INET, SOCK_DGRAM, 0);
-	if (-1 == sockfd) {
+	if (-1 == sockfd)
+	{
 #if _WIN32
 		wprintf(L"socket() error: %ld\n", WSAGetLastError());
 		exit(EXIT_FAILURE);
@@ -1055,9 +1063,11 @@ int start_upd_srv(const char *src_str, const char *addr_str, unsigned port)
 #endif
 	}
 
-	if (IN_MULTICAST(addr)) {
+	if (IN_MULTICAST(addr))
+	{
 		int setsockopt_return = 0;
-		if (src_str != NULL) {
+		if (src_str != NULL)
+		{
 			struct ip_mreq_source multicast_req;
 			multicast_req.imr_sourceaddr.s_addr = htonl(src);
 			multicast_req.imr_multiaddr.s_addr = htonl(addr);
@@ -1092,13 +1102,13 @@ int start_upd_srv(const char *src_str, const char *addr_str, unsigned port)
 	{
 		struct in_addr source;
 		struct in_addr group;
-		char src_ip[15];
-		char addr_ip[15];
+		char src_ip[INET_ADDRSTRLEN];
+		char addr_ip[INET_ADDRSTRLEN];
 		source.s_addr = htonl(src);
-		memset(src_ip, 0, sizeof(char) * 15);
+		memset(src_ip, 0, sizeof(char) * INET_ADDRSTRLEN);
 		memcpy(src_ip, inet_ntoa(source), sizeof(src_ip));
 		group.s_addr = htonl(addr);
-		memset(addr_ip, 0, sizeof(char) * 15);
+		memset(addr_ip, 0, sizeof(char) * INET_ADDRSTRLEN);
 		memcpy(addr_ip, inet_ntoa(group), sizeof(addr_ip));
 
 		mprint("\rReading from UDP socket %s@%s:%u\n", src_ip, addr_ip, port);
@@ -1113,7 +1123,7 @@ int start_upd_srv(const char *src_str, const char *addr_str, unsigned port)
 	return sockfd;
 }
 
-void init_sockets (void)
+void init_sockets(void)
 {
 	static int socket_inited = 0;
 	if (!socket_inited)
@@ -1146,7 +1156,8 @@ void handle_write_error()
 
 	char c = 0;
 	int rc;
-	do {
+	do
+	{
 		c = 0;
 		rc = read_byte(srv_sd, &c);
 		if (rc < 0)
@@ -1185,18 +1196,18 @@ void handle_write_error()
 
 int set_nonblocking(int fd)
 {
-    int f;
+	int f;
 #ifdef O_NONBLOCK
-    if ((f = fcntl(fd, F_GETFL, 0)) < 0)
-        f = 0;
+	if ((f = fcntl(fd, F_GETFL, 0)) < 0)
+		f = 0;
 
-    return fcntl(fd, F_SETFL, f | O_NONBLOCK);
+	return fcntl(fd, F_SETFL, f | O_NONBLOCK);
 #else
-    f = 1;
-	#if _WIN32
-		return ioctlsocket(fd, FIONBIO, &f);
-	#else
-		return ioctl(fd, FIONBIO, &f);
-	#endif
+	f = 1;
+#if _WIN32
+	return ioctlsocket(fd, FIONBIO, &f);
+#else
+	return ioctl(fd, FIONBIO, &f);
+#endif
 #endif
 }
