@@ -1,6 +1,7 @@
 #ifndef OCR_H
 #define OCR_H
 #include <png.h>
+#include "ccx_encoders_common.h"
 
 struct image_copy //A copy of the original OCR image, used for color detection
 {
@@ -12,10 +13,10 @@ struct image_copy //A copy of the original OCR image, used for color detection
 };
 
 void delete_ocr (void** arg);
-char* probe_tessdata_location_string(char* lang);
+char* probe_tessdata_location(const char *lang);
 void* init_ocr(int lang_index);
 char* ocr_bitmap(void* arg, png_color *palette,png_byte *alpha, unsigned char* indata,int w, int h, struct image_copy *copy);
 int ocr_rect(void* arg, struct cc_bitmap *rect, char **str, int bgcolor, int ocr_quantmode);
-char *paraof_ocrtext(struct cc_subtitle *sub, const char *crlf, unsigned crlf_length);
+char *paraof_ocrtext(struct cc_subtitle *sub, struct encoder_ctx *context);
 
 #endif
