@@ -9,8 +9,7 @@
 int temp_debug = 0; // This is a convenience variable used to enable/disable debug on variable conditions. Find references to understand.
 volatile sig_atomic_t change_filename_requested = 0;
 
-
-static uint32_t crc32_table [] = {
+static uint32_t crc32_table[] = {
     0x00000000, 0x04c11db7, 0x09823b6e, 0x0d4326d9,
     0x130476dc, 0x17c56b6b, 0x1a864db2, 0x1e475005,
     0x2608edb8, 0x22c9f00f, 0x2f8ad6d6, 0x2b4bcb61,
@@ -74,8 +73,7 @@ static uint32_t crc32_table [] = {
     0x89b8fd09, 0x8d79e0be, 0x803ac667, 0x84fbdbd0,
     0x9abc8bd5, 0x9e7d9662, 0x933eb0bb, 0x97ffad0c,
     0xafb010b1, 0xab710d06, 0xa6322bdf, 0xa2f33668,
-    0xbcb4666d, 0xb8757bda, 0xb5365d03, 0xb1f740b4
-};
+    0xbcb4666d, 0xb8757bda, 0xb5365d03, 0xb1f740b4};
 
 int verify_crc32(uint8_t *buf, int len)
 {
@@ -83,37 +81,37 @@ int verify_crc32(uint8_t *buf, int len)
 	int32_t crc = -1;
 	for (i = 0; i < len; i++)
 		crc = (crc << 8) ^ crc32_table[((crc >> 24) ^ (buf[i] & 0xff)) & 0xff];
-	return crc?CCX_FALSE:CCX_TRUE;
+	return crc ? CCX_FALSE : CCX_TRUE;
 }
 
-int stringztoms (const char *s, struct ccx_boundary_time *bt)
+int stringztoms(const char *s, struct ccx_boundary_time *bt)
 {
-	unsigned ss=0, mm=0, hh=0;
-	int value=-1;
-	int colons=0;
-	const char *c=s;
+	unsigned ss = 0, mm = 0, hh = 0;
+	int value = -1;
+	int colons = 0;
+	const char *c = s;
 	while (*c)
 	{
-		if (*c==':')
+		if (*c == ':')
 		{
-			if (value==-1) // : at the start, or ::, etc
+			if (value == -1) // : at the start, or ::, etc
 				return -1;
 			colons++;
-			if (colons>2) // Max 2, for HH:MM:SS
+			if (colons > 2) // Max 2, for HH:MM:SS
 				return -1;
-			hh=mm;
-			mm=ss;
-			ss=value;
-			value=-1;
+			hh = mm;
+			mm = ss;
+			ss = value;
+			value = -1;
 		}
 		else
 		{
-			if (!isdigit (*c)) // Only : or digits, so error
+			if (!isdigit(*c)) // Only : or digits, so error
 				return -1;
-			if (value==-1)
-				value=*c-'0';
+			if (value == -1)
+				value = *c - '0';
 			else
-				value=value*10+*c-'0';
+				value = value * 10 + *c - '0';
 		}
 		c++;
 	}
@@ -127,17 +125,17 @@ int stringztoms (const char *s, struct ccx_boundary_time *bt)
 	bt->mm = mm;
 	bt->ss = ss;
 	LLONG secs = (hh * 3600 + mm * 60 + ss);
-	bt->time_in_ms = secs*1000;
+	bt->time_in_ms = secs * 1000;
 	return 0;
 }
 void timestamp_to_srttime(uint64_t timestamp, char *buffer)
 {
 	uint64_t p = timestamp;
-	uint8_t h = (uint8_t) (p / 3600000);
-	uint8_t m = (uint8_t) (p / 60000 - 60 * h);
-	uint8_t s = (uint8_t) (p / 1000 - 3600 * h - 60 * m);
-	uint16_t u = (uint16_t) (p - 3600000 * h - 60000 * m - 1000 * s);
-	sprintf(buffer, "%02"PRIu8":%02"PRIu8":%02"PRIu8",%03"PRIu16, h, m, s, u);
+	uint8_t h = (uint8_t)(p / 3600000);
+	uint8_t m = (uint8_t)(p / 60000 - 60 * h);
+	uint8_t s = (uint8_t)(p / 1000 - 3600 * h - 60 * m);
+	uint16_t u = (uint16_t)(p - 3600000 * h - 60000 * m - 1000 * s);
+	sprintf(buffer, "%02" PRIu8 ":%02" PRIu8 ":%02" PRIu8 ",%03" PRIu16, h, m, s, u);
 }
 void timestamp_to_vtttime(uint64_t timestamp, char *buffer)
 {
@@ -146,83 +144,83 @@ void timestamp_to_vtttime(uint64_t timestamp, char *buffer)
 	uint8_t m = (uint8_t)(p / 60000 - 60 * h);
 	uint8_t s = (uint8_t)(p / 1000 - 3600 * h - 60 * m);
 	uint16_t u = (uint16_t)(p - 3600000 * h - 60000 * m - 1000 * s);
-	sprintf(buffer, "%02"PRIu8":%02"PRIu8":%02"PRIu8".%03"PRIu16, h, m, s, u);
+	sprintf(buffer, "%02" PRIu8 ":%02" PRIu8 ":%02" PRIu8 ".%03" PRIu16, h, m, s, u);
 }
 
 #define MIN3(a, b, c) ((a) < (b) ? ((a) < (c) ? (a) : (c)) : ((b) < (c) ? (b) : (c)))
 
-int levenshtein_dist (const uint64_t *s1, const uint64_t *s2, unsigned s1len, unsigned s2len)
+int levenshtein_dist(const uint64_t *s1, const uint64_t *s2, unsigned s1len, unsigned s2len)
 {
 	unsigned int x, y, v, lastdiag, olddiag;
-	unsigned int *column = (unsigned *) malloc ((s1len+1)*sizeof (unsigned int));
+	unsigned int *column = (unsigned *)malloc((s1len + 1) * sizeof(unsigned int));
 	for (y = 1; y <= s1len; y++)
 		column[y] = y;
 	for (x = 1; x <= s2len; x++)
 	{
 		column[0] = x;
-		for (y = 1, lastdiag = x-1; y <= s1len; y++)
+		for (y = 1, lastdiag = x - 1; y <= s1len; y++)
 		{
 			olddiag = column[y];
-			column[y] = MIN3(column[y] + 1, column[y-1] + 1, lastdiag + (s1[y-1] == s2[x-1] ? 0 : 1));
+			column[y] = MIN3(column[y] + 1, column[y - 1] + 1, lastdiag + (s1[y - 1] == s2[x - 1] ? 0 : 1));
 			lastdiag = olddiag;
 		}
 	}
 	v = column[s1len];
-	free (column);
+	free(column);
 	return v;
 }
 
-int levenshtein_dist_char (const char *s1, const char *s2, unsigned s1len, unsigned s2len)
+int levenshtein_dist_char(const char *s1, const char *s2, unsigned s1len, unsigned s2len)
 {
 	unsigned int x, y, v, lastdiag, olddiag;
-	unsigned int *column = (unsigned *) malloc ((s1len+1)*sizeof (unsigned int));
+	unsigned int *column = (unsigned *)malloc((s1len + 1) * sizeof(unsigned int));
 	for (y = 1; y <= s1len; y++)
 		column[y] = y;
 	for (x = 1; x <= s2len; x++)
 	{
 		column[0] = x;
-		for (y = 1, lastdiag = x-1; y <= s1len; y++)
+		for (y = 1, lastdiag = x - 1; y <= s1len; y++)
 		{
 			olddiag = column[y];
-			column[y] = MIN3(column[y] + 1, column[y-1] + 1, lastdiag + (s1[y-1] == s2[x-1] ? 0 : 1));
+			column[y] = MIN3(column[y] + 1, column[y - 1] + 1, lastdiag + (s1[y - 1] == s2[x - 1] ? 0 : 1));
 			lastdiag = olddiag;
 		}
 	}
 	v = column[s1len];
-	free (column);
+	free(column);
 	return v;
 }
 
-void millis_to_date (uint64_t timestamp, char *buffer, enum ccx_output_date_format date_format, char millis_separator)
+void millis_to_date(uint64_t timestamp, char *buffer, enum ccx_output_date_format date_format, char millis_separator)
 {
 	time_t secs;
 	unsigned int millis;
 	char c_temp[80];
-	struct tm *time_struct=NULL;
+	struct tm *time_struct = NULL;
 	switch (date_format)
 	{
 		case ODF_NONE:
 			buffer[0] = 0;
 			break;
 		case ODF_HHMMSS:
-			timestamp_to_srttime (timestamp, buffer);
+			timestamp_to_srttime(timestamp, buffer);
 			buffer[8] = 0;
 			break;
 		case ODF_HHMMSSMS:
-			timestamp_to_srttime (timestamp, buffer);
+			timestamp_to_srttime(timestamp, buffer);
 			break;
 		case ODF_SECONDS:
-			secs = (time_t) (timestamp/1000);
-			millis = (time_t) (timestamp%1000);
-			sprintf (buffer, "%lu%c%03u", (unsigned long) secs,
-					millis_separator, (unsigned) millis);
+			secs = (time_t)(timestamp / 1000);
+			millis = (time_t)(timestamp % 1000);
+			sprintf(buffer, "%lu%c%03u", (unsigned long)secs,
+				millis_separator, (unsigned)millis);
 			break;
 		case ODF_DATE:
-			secs = (time_t) (timestamp/1000);
-			millis = (unsigned int) (timestamp%1000);
+			secs = (time_t)(timestamp / 1000);
+			millis = (unsigned int)(timestamp % 1000);
 			time_struct = gmtime(&secs);
 			strftime(c_temp, sizeof(c_temp), "%Y%m%d%H%M%S", time_struct);
-			sprintf (buffer, "%s%c%03u", c_temp, millis_separator, millis);
+			sprintf(buffer, "%s%c%03u", c_temp, millis_separator, millis);
 			break;
 
 		default:
@@ -242,25 +240,38 @@ bool_t in_array(uint16_t *array, uint16_t length, uint16_t element)
 	return r;
 }
 
-void print_error (int mode, const char *fmt, ...)
+void print_error(int mode, const char *fmt, ...)
 {
 	va_list args;
 	va_start(args, fmt);
 	if (mode)
-		fprintf(stderr,"###MESSAGE#");
+		fprintf(stderr, "###MESSAGE#");
 	else
 		fprintf(stderr, "\rError: ");
 	vfprintf(stderr, fmt, args);
 	fprintf(stderr, "\n");
 	va_end(args);
 }
+
+void write_wrapped(int fd, const char *buf, size_t count)
+{
+	while (count)
+	{
+		ssize_t written = write(fd, buf, count);
+		if (written == -1)
+			fatal(1, "writing to file");
+		buf += written;
+		count -= written;
+	}
+}
+
 /* Write formatted message to stderr and then exit. */
 void fatal(int exit_code, const char *fmt, ...)
 {
 	va_list args;
 	va_start(args, fmt);
 	if (ccx_options.gui_mode_reports)
-		fprintf(stderr,"###MESSAGE#");
+		fprintf(stderr, "###MESSAGE#");
 	else
 		fprintf(stderr, "\rError: ");
 	vfprintf(stderr, fmt, args);
@@ -272,22 +283,22 @@ void fatal(int exit_code, const char *fmt, ...)
 
 /* General output, replacement for printf so we can control globally where messages go.
    mprint => Message print */
-void mprint (const char *fmt, ...)
+void mprint(const char *fmt, ...)
 {
 	va_list args;
 	if (!ccx_options.messages_target)
 		return;
 	activity_header(); // Brag about writing it :-)
 	va_start(args, fmt);
-	if (ccx_options.messages_target==CCX_MESSAGES_STDOUT)
+	if (ccx_options.messages_target == CCX_MESSAGES_STDOUT)
 	{
 		vfprintf(stdout, fmt, args);
-		fflush (stdout);
+		fflush(stdout);
 	}
 	else
 	{
 		vfprintf(stderr, fmt, args);
-		fflush (stderr);
+		fflush(stderr);
 	}
 	va_end(args);
 }
@@ -301,52 +312,52 @@ void dbg_print(LLONG mask, const char *fmt, ...)
 		return;
 	t = temp_debug ? (ccx_options.debug_mask_on_debug | ccx_options.debug_mask) : ccx_options.debug_mask; // Mask override?
 
-	if(mask & t)
+	if (mask & t)
 	{
 		va_start(args, fmt);
-		if (ccx_options.messages_target==CCX_MESSAGES_STDOUT)
+		if (ccx_options.messages_target == CCX_MESSAGES_STDOUT)
 		{
 			vfprintf(stdout, fmt, args);
-			fflush (stdout);
+			fflush(stdout);
 		}
 		else
 		{
 			vfprintf(stderr, fmt, args);
-			fflush (stderr);
+			fflush(stderr);
 		}
 		va_end(args);
 	}
 }
 
-void dump (LLONG mask, unsigned char *start, int l, unsigned long abs_start, unsigned clear_high_bit)
+void dump(LLONG mask, unsigned char *start, int l, unsigned long abs_start, unsigned clear_high_bit)
 {
-	LLONG t=temp_debug ? (ccx_options.debug_mask_on_debug | ccx_options.debug_mask) : ccx_options.debug_mask; // Mask override?
-	if(! (mask & t))
+	LLONG t = temp_debug ? (ccx_options.debug_mask_on_debug | ccx_options.debug_mask) : ccx_options.debug_mask; // Mask override?
+	if (!(mask & t))
 		return;
 
-	for (int x=0; x<l; x=x+16)
+	for (int x = 0; x < l; x = x + 16)
 	{
-		mprint ("%08ld | ",x+abs_start);
-		for (int j=0; j<16; j++)
+		mprint("%08ld | ", x + abs_start);
+		for (int j = 0; j < 16; j++)
 		{
-			if (x+j<l)
-				mprint ("%02X ",start[x+j]);
+			if (x + j < l)
+				mprint("%02X ", start[x + j]);
 			else
-				mprint ("   ");
+				mprint("   ");
 		}
-		mprint (" | ");
-		for (int j=0; j<16; j++)
+		mprint(" | ");
+		for (int j = 0; j < 16; j++)
 		{
-			if (x+j<l && start[x+j]>=' ')
-				mprint ("%c", start[x+j] & (clear_high_bit ? 0x7F : 0xFF)); // 0x7F < remove high bit, convenient for visual CC inspection
+			if (x + j < l && start[x + j] >= ' ')
+				mprint("%c", start[x + j] & (clear_high_bit ? 0x7F : 0xFF)); // 0x7F < remove high bit, convenient for visual CC inspection
 			else
-				mprint (" ");
+				mprint(" ");
 		}
-		mprint ("\n");
+		mprint("\n");
 	}
 }
 
-void init_boundary_time (struct ccx_boundary_time *bt)
+void init_boundary_time(struct ccx_boundary_time *bt)
 {
 	bt->hh = 0;
 	bt->mm = 0;
@@ -355,8 +366,7 @@ void init_boundary_time (struct ccx_boundary_time *bt)
 	bt->time_in_ms = 0;
 }
 
-
-void sleep_secs (int secs)
+void sleep_secs(int secs)
 {
 #ifdef _WIN32
 	Sleep(secs * 1000);
@@ -365,37 +375,38 @@ void sleep_secs (int secs)
 #endif
 }
 
-int hex_to_int (char high, char low)
+int hex_to_int(char high, char low)
 {
-	unsigned char h,l;
+	unsigned char h, l;
 	if (high >= '0' && high <= '9')
-		h = high-'0';
+		h = high - '0';
 	else if (high >= 'a' && high <= 'f')
-		h = high-'a'+10;
+		h = high - 'a' + 10;
 	else
 		return -1;
 	if (low >= '0' && low <= '9')
 		l = low - '0';
 	else if (low >= 'a' && low <= 'f')
-		l = low - 'a'+10;
+		l = low - 'a' + 10;
 	else
 		return -1;
-	return h * 16+l;
+	return h * 16 + l;
 }
-int hex_string_to_int(char* string, int len)
+int hex_string_to_int(char *string, int len)
 {
-  int total_return = 0;
-  while(*string && len-- > 0 && total_return >= 0){
-    unsigned char c = *string;
-    if(c >= '0' && c <= '9')
-      total_return = total_return * 16 + (c - '0');
-    else if(*string >= 'a' && *string <= 'f')
-      total_return = total_return * 16 + (c - 'a' + 10);
-    else
-      total_return = -1;
-    string++;
-  }
-  return total_return;
+	int total_return = 0;
+	while (*string && len-- > 0 && total_return >= 0)
+	{
+		unsigned char c = *string;
+		if (c >= '0' && c <= '9')
+			total_return = total_return * 16 + (c - '0');
+		else if (*string >= 'a' && *string <= 'f')
+			total_return = total_return * 16 + (c - 'a' + 10);
+		else
+			total_return = -1;
+		string++;
+	}
+	return total_return;
 }
 
 #ifndef _WIN32
@@ -416,7 +427,7 @@ void m_signal(int sig, void (*func)(int))
 
 struct encoder_ctx *change_filename(struct encoder_ctx *enc_ctx)
 {
-	if(change_filename_requested == 0)
+	if (change_filename_requested == 0)
 	{
 		return enc_ctx;
 	}
@@ -426,44 +437,42 @@ struct encoder_ctx *change_filename(struct encoder_ctx *enc_ctx)
 	{
 		if (enc_ctx->out->fh > 0)
 			close(enc_ctx->out->fh);
-		enc_ctx->out->fh=-1;
+		enc_ctx->out->fh = -1;
 		int iter;
 		char str_number[15];
-		char *current_name = malloc(sizeof(char)*(strlen(enc_ctx->out->filename)+10));
-		strcpy(current_name,enc_ctx->out->filename);
-		mprint ("Creating %s\n", enc_ctx->out->filename);
-		if(enc_ctx->out->renaming_extension)
+		char *current_name = malloc(sizeof(char) * (strlen(enc_ctx->out->filename) + 10));
+		strcpy(current_name, enc_ctx->out->filename);
+		mprint("Creating %s\n", enc_ctx->out->filename);
+		if (enc_ctx->out->renaming_extension)
 		{
-			strcat(current_name,".");
+			strcat(current_name, ".");
 			sprintf(str_number, "%d", enc_ctx->out->renaming_extension);
-			strcat(current_name,str_number);
+			strcat(current_name, str_number);
 		}
 		enc_ctx->out->renaming_extension++;
 		for (iter = enc_ctx->out->renaming_extension; iter >= 1; iter--)
 		{
 			int ret;
 			char new_extension[6];
-			sprintf(new_extension, ".%d", iter); 
-			char *newname = malloc(sizeof(char)*(strlen(enc_ctx->out->filename)+10));
-			strcpy(newname,enc_ctx->out->filename);
-			strcat(newname,new_extension);
+			sprintf(new_extension, ".%d", iter);
+			char *newname = malloc(sizeof(char) * (strlen(enc_ctx->out->filename) + 10));
+			strcpy(newname, enc_ctx->out->filename);
+			strcat(newname, new_extension);
 			ret = rename(current_name, newname);
-			if(ret)
+			if (ret)
 			{
 				mprint("Failed to rename the file\n");
-
 			}
-			mprint ("Creating %s\n", newname);
-			strcpy(current_name,enc_ctx->out->filename);
-			
-			if(iter-2>0)
+			mprint("Creating %s\n", newname);
+			strcpy(current_name, enc_ctx->out->filename);
+
+			if (iter - 2 > 0)
 			{
-				strcat(current_name,".");
-				sprintf(str_number, "%d", iter-2);
-				strcat(current_name,str_number);
+				strcat(current_name, ".");
+				sprintf(str_number, "%d", iter - 2);
+				strcat(current_name, str_number);
 			}
 			free(newname);
-		
 		}
 
 		enc_ctx->out->fh = open(enc_ctx->out->filename, O_RDWR | O_CREAT | O_TRUNC | O_BINARY, S_IREAD | S_IWRITE);
@@ -473,73 +482,84 @@ struct encoder_ctx *change_filename(struct encoder_ctx *enc_ctx)
 			mprint("Failed to create a new rotation file\n");
 			return temp_encoder;
 		}
-		free(temp_encoder);		
+		free(temp_encoder);
 		change_filename_requested = 0;
 		return enc_ctx;
-		
 	}
 	return temp_encoder;
 }
+
+/*
+ * RETURN VALUE: the return value should be free(3)-ed
+ */
 char *get_basename(char *filename)
 {
 	char *c;
 	int len;
 	char *basefilename;
 
-	if(!filename)
-		return NULL;	
+	if (!filename)
+		return NULL;
 
 	len = strlen(filename);
-	basefilename = (char *) malloc(len+1);
+	basefilename = (char *)malloc(len + 1);
 	if (basefilename == NULL)
 	{
 		return NULL;
 	}
 
-	strcpy (basefilename, filename);
+	strcpy(basefilename, filename);
 
 	for (c = basefilename + len; c > basefilename && *c != '.'; c--)
-	{;} // Get last .
+	{
+		;
+	} // Get last .
 	if (*c == '.')
 		*c = 0;
 
 	return basefilename;
 }
 
-char *get_file_extension(enum ccx_output_format write_format)
+const char *get_file_extension(const enum ccx_output_format write_format)
 {
 	switch (write_format)
 	{
+		case CCX_OF_CCD:
+			return ".ccd";
 		case CCX_OF_RAW:
-			return strdup(".raw");
+			return ".raw";
+		case CCX_OF_SCC:
+			return ".scc";
 		case CCX_OF_SRT:
-			return strdup(".srt");
+			return ".srt";
 		case CCX_OF_SSA:
-			return strdup(".ass");
+			return ".ass";
 		case CCX_OF_WEBVTT:
-			return strdup (".vtt");
+			return ".vtt";
 		case CCX_OF_SAMI:
-			return strdup(".smi");
+			return ".smi";
 		case CCX_OF_SMPTETT:
-			return strdup(".ttml");
+			return ".ttml";
 		case CCX_OF_TRANSCRIPT:
-			return strdup(".txt");
+			return ".txt";
 		case CCX_OF_RCWT:
-			return strdup(".bin");
+			return ".bin";
 		case CCX_OF_SPUPNG:
-			return strdup(".xml");
+			return ".xml";
 		case CCX_OF_DVDRAW:
-			return strdup(".dvdraw");
+			return ".dvdraw";
 		case CCX_OF_SIMPLE_XML:
-			return strdup(".xml");
+			return ".xml";
 		case CCX_OF_G608:
-			return strdup(".g608");
+			return ".g608";
+		case CCX_OF_MCC:
+			return ".mcc";
 		case CCX_OF_NULL:
 			return NULL;
 		case CCX_OF_CURL:
 			return NULL;
 		default:
-			fatal (CCX_COMMON_EXIT_BUG_BUG, "write_format doesn't have any legal value. Please report this bug on Github.com\n");
+			fatal(CCX_COMMON_EXIT_BUG_BUG, "write_format doesn't have any legal value. Please report this bug on Github.com\n");
 			errno = EINVAL;
 			return NULL;
 	}
@@ -551,58 +571,57 @@ char *create_outfilename(const char *basename, const char *suffix, const char *e
 	char *ptr = NULL;
 	size_t blen, slen, elen;
 
-	if(basename)
+	if (basename)
 		blen = strlen(basename);
 	else
 		blen = 0;
 
-	if(suffix)
+	if (suffix)
 		slen = strlen(suffix);
 	else
 		slen = 0;
 
-	if(extension)
+	if (extension)
 		elen = strlen(extension);
 	else
 		elen = 0;
-	if ( (elen + slen + blen) <= 0)
+	if ((elen + slen + blen) <= 0)
 		return NULL;
 
 	ptr = malloc(elen + slen + blen + 1);
-	if(!ptr)
+	if (!ptr)
 		return NULL;
 
 	ptr[0] = '\0';
 
-	if(basename)
+	if (basename)
 		strcat(ptr, basename);
-	if(suffix)
+	if (suffix)
 		strcat(ptr, suffix);
-	if(extension)
+	if (extension)
 		strcat(ptr, extension);
 	return ptr;
 }
 
 size_t utf16_to_utf8(unsigned short utf16_char, unsigned char *out)
 {
-	if (utf16_char < 0x80) {
+	if (utf16_char < 0x80)
+	{
 		out[0] = (unsigned char)((utf16_char >> 0 & 0x7F) | 0x00);
 		return 1;
-	} else if (utf16_char < 0x0800) {
+	}
+	else if (utf16_char < 0x0800)
+	{
 		out[0] = (unsigned char)((utf16_char >> 6 & 0x1F) | 0xC0);
 		out[1] = (unsigned char)((utf16_char >> 0 & 0x3F) | 0x80);
 		return 2;
-	} else if (utf16_char < 0x010000) {
+	}
+	else
+	{
 		out[0] = (unsigned char)((utf16_char >> 12 & 0x0F) | 0xE0);
 		out[1] = (unsigned char)((utf16_char >> 6 & 0x3F) | 0x80);
 		out[2] = (unsigned char)((utf16_char >> 0 & 0x3F) | 0x80);
 		return 3;
-	} else if (utf16_char < 0x110000) {
-		out[0] = (unsigned char)((utf16_char >> 18 & 0x07) | 0xF0);
-		out[1] = (unsigned char)((utf16_char >> 12 & 0x3F) | 0x80);
-		out[2] = (unsigned char)((utf16_char >> 6 & 0x3F) | 0x80);
-		out[3] = (unsigned char)((utf16_char >> 0 & 0x3F) | 0x80);
-		return 4;
 	}
 	return 0;
 }
@@ -611,13 +630,13 @@ LLONG change_timebase(LLONG val, struct ccx_rational cur_tb, struct ccx_rational
 {
 	/* val = (value * current timebase) / destination timebase */
 	val = val * cur_tb.num * dest_tb.den;
-	val = val / ( cur_tb.den * dest_tb.num);
+	val = val / (cur_tb.den * dest_tb.num);
 	return val;
 }
 
 char *str_reallocncat(char *dst, char *src)
-{	
-	int nl = dst==NULL? (strlen (src)+1) : (strlen(dst) + strlen(src) + 1);
+{
+	int nl = dst == NULL ? (strlen(src) + 1) : (strlen(dst) + strlen(src) + 1);
 	char *orig = dst;
 	dst = (char *)realloc(dst, nl);
 	if (!dst)
@@ -671,7 +690,8 @@ int vasprintf(char **strp, const char *fmt, va_list ap)
 #else
 	ret = vsnprintf(*strp, size, fmt, ap);
 #endif
-	if (ret == -1) {
+	if (ret == -1)
+	{
 		free(*strp);
 		return -1;
 	}
